<?php
//
// Copyright (c) 2008-2011 Nagios Enterprises, LLC.  All rights reserved.
// 
// IMPORTANT: SOURCE CODE MAY NOT BE DISCLOSED OR DISTRIBUTED IN UNENCODED FORM
//            WITHOUT EXPLICIT PERMISSION FROM NAGIOS ENTERPRISES, AS IT CONTAINS
//			  CODE LICENSED FROM THIRD PARTIES.
//
// $Id: monitoringwizard.php 622 2011-03-16 19:15:14Z mguthrie $

require_once(dirname(__FILE__).'/../includes/common.inc.php');

require_once(dirname(__FILE__).'/../includes/configwizards.inc.php');


// initialization stuff
pre_init();

// start session
init_session();

// grab GET or POST variables 
grab_request_vars();
decode_request_vars();

// check prereqs
check_prereqs();

// check authentication
check_authentication(false);


// route request
route_request();


function route_request(){
	global $request;
	
	if(is_authorized_to_configure_objects()==false)
		header("Location: ".get_base_url());

	$nextstep=grab_request_var("nextstep","");
	
	//echo "NEXTSTEP: $nextstep";
	
	
	switch($nextstep){
		case "commit":
			validate_final_step();
			do_commit();
			break;
		case "final":
			validate_step6();
			show_final_step();
			break;
		case "6":
			validate_step5();
			show_step6();
			break;
		case "5":
			validate_step4();
			show_step5();
			break;
		case "4":
			validate_step3();
			show_step4();
			break;
		case "3":
			validate_step2();
			show_step3();
			break;
		case "2":
			validate_step1();
			show_step2();
			break;
		default:
			show_step1();
			break;
			}
	exit;
	}
	
	
function show_step1($error=false,$msg=""){
	global $configwizards;
	global $request;
	global $lstr;
	
	// get defaults

	
	// get global variables

	
	do_page_start(array("page_title"=>$lstr['MonitoringWizardStep1PageTitle']),true);
?>

	<h1><?php echo $lstr['MonitoringWizardStep1PageHeader'];?></h1>
	

<?php
	display_message($error,false,$msg);
?>

	<form id="configWizardForm" method="post" action="<?php echo htmlentities($_SERVER['PHP_SELF']);?>" onSubmit="show_child_content_throbber();">
	<?php echo get_nagios_session_protector();?>
	<input type="hidden" name="update" value="1" />
	<input type="hidden" name="nextstep" value="2" />
	
	
	<div class="sectionTitle"><?php echo $lstr['MonitoringWizardStep1SectionTitle'];?></div>
	
	<p><?php echo $lstr['MonitoringWizardStep1Notes'];?></p>
	
<?php
	if(is_admin()==true){
?>
	<p>
	<div class="bluebutton" style="width: 150px; float: right;">
	<a href="http://exchange.nagios.org/directory/Addons/Configuration/Configuration-Wizards" target="_blank">Get More Wizards</a>
	</div>
	 You can find additional configuration wizards for Nagios XI at <a href='http://exchange.nagios.org/directory/Addons/Configuration/Configuration-Wizards' target='_blank'>Nagios Exchange</a>.  Need a custom configuration wizard created for your organization?  No problem!  <a href='http://www.nagios.com/contact/' target='_blank'>Contact us</a> for pricing information.
	</p>
	<br clear="all">
	<br clear="all">	
	
<?php
		}
?>

	<table>


<?php

	$base_url="?update=1&nextstep=2&nsp=".get_nagios_session_protector_id()."&wizard=";
	
	foreach($configwizards as $cw){
		
		// only show monitoring wizards
		if($cw[CONFIGWIZARD_TYPE]!=CONFIGWIZARD_TYPE_MONITORING)
			continue;
			
		// should this be displayed?
		$display=grab_array_var($cw,CONFIGWIZARD_SHOWASAVAILABLE,true);
		if($display==false)
			continue;
			
		// check if there is a display function
		$func=grab_array_var($cw,CONFIGWIZARD_DISPLAYFUNCTION,"");
		if($func!=""){
			// only show this wizard if the function returns true
			if($func()!=true)
				continue;
			}
			
		$wizard_url=$base_url.urlencode($cw[CONFIGWIZARD_NAME]);
?>
		<tr>
		<td>
		<input type="radio" name="wizard" value="<?php echo $cw[CONFIGWIZARD_NAME];?>" />
		</td>
		<td>
		<?php 
		$img=$cw[CONFIGWIZARD_PREVIEWIMAGE];
		if($img!=""){
			echo "<a href='".$wizard_url."'><img src='".get_object_icon_url($img)."'></a>";
			}
		?>
		</td>
		<td>
		<b><a href="<?php echo $wizard_url;?>"><?php echo $cw[CONFIGWIZARD_DISPLAYTITLE];?></a></b><br>
		<?php echo $cw[CONFIGWIZARD_DESCRIPTION];?>
		</td>
		</tr>
<?php
		}
?>

	</table>

	<!--<div class="sectionTitle">-->
	<div id="formButtons">
	<input type="submit" class="submitbutton" name="submitButton" value="<?php echo $lstr['NextButton'];?>"/>
	<!--</div>-->
	
	<!--</fieldset>-->
	</form>

	
	
<?php

	do_page_end(true);
	exit();
	}

function validate_step1(){
	global $request;
	global $lstr;
	
	// check session
	check_nagios_session_protector();
	
	$w=grab_request_var("wizard","");

	// check for errors
	$errors=0;
	$errmsg="";
	if(have_value($w)==false)
		$errmsg[$errors++]=$lstr['NoConfigWizardSelectedError'];
		
	// handle errors
	if($errors>0){
		show_step1(true,$errmsg);
		}
		
	}
	

function show_step2($error=false,$msg=""){
	global $request;
	global $lstr;
	

	// get variables
	$wizard=grab_request_var("wizard","");

	// find the wizard
	$w=get_configwizard_by_name($wizard);
	$wt=$w[CONFIGWIZARD_DISPLAYTITLE];
	
	$inargs=$request;
	$outargs=array();
	$result=0;
	$wo=make_configwizard_callback($wizard,CONFIGWIZARD_MODE_GETSTAGE1HTML,$inargs,$outargs,$result);

	
	do_page_start(array("page_title"=>$wt." ".$lstr['MonitoringWizardStep2PageTitle']),true);
	
?>

	<h1><?php echo $wt." ".$lstr['MonitoringWizardStep2PageHeader'];?></h1>
	
	<?php 
	$img=$w[CONFIGWIZARD_PREVIEWIMAGE];
	if($img!=""){
		echo "<img src='".get_base_url()."includes/components/nagioscore/ui/images/logos/".$img."'>";
		}
	?>

<?php
	display_message($error,false,$msg);
?>

	<form id="configWizardForm" method="post" action="<?php echo htmlentities($_SERVER['PHP_SELF']);?>" onSubmit="show_child_content_throbber();">
	<input type="hidden" name="update" value="1" />
	<?php echo get_nagios_session_protector();?>
	<input type="hidden" name="nextstep" value="3" />
	<input type="hidden" name="wizard" value="<?php echo encode_form_val($wizard);?>" />
	
<?php
	echo $wo;
?>

	<!--<div class="sectionTitle">-->
	<div id="formButtons">
	<input type="submit" class="submitbutton" name="submitButton" value="<?php echo $lstr['NextButton'];?>" style="visibility: hidden; display: none;" />
	<input type="submit" class="submitbutton" name="backButton" value="<?php echo $lstr['BackButton'];?>"/>
	<input type="submit" class="submitbutton" name="submitButton2" value="<?php echo $lstr['NextButton'];?>"/>
	<!--<input type="submit" class="submitbutton" name="cancelButton" value="<?php echo $lstr['CancelButton'];?>"/>-->
	<!--</div>-->
	
	<!--</fieldset>-->
	</form>

	
	
<?php

	do_page_end(true);
	exit();
	}

function validate_step2(){
	global $request;
	global $lstr;
	global $passback_data;
	
	// user cancelled wizard
	if(isset($request["cancelButton"]))
		show_step1();
	// user wants to go back a step
	if(isset($request["backButton"])){
		unset($request["backButton"]);
		show_step1();
		}
	
	
	// check session
	check_nagios_session_protector();

	$wizard=grab_request_var("wizard","");
	
	clean_configwizard_request_vars();
	
	// verify input with config wizard
	$inargs=$request;
	$outargs=array();
	$result=0;
	$wo=make_configwizard_callback($wizard,CONFIGWIZARD_MODE_VALIDATESTAGE1DATA,$inargs,$outargs,$result);
	
	// initialzie the passback args we got from the wizard - we need them in the next step
	$passback_data=$outargs[CONFIGWIZARD_PASSBACK_DATA];
	
	/*
	echo "RESULT: $result<BR>\n";
	echo "OUTPUT: $wo<BR>\n";
	echo "OUTARGS: <BR>\n";
	print_r($outargs);
	*/
	
	// handle errors
	if($result!=0){
		$errmsg=$outargs[CONFIGWIZARD_ERROR_MESSAGES];
		show_step2(true,$errmsg);
		}
	
	//exit();
	}
		

function show_step3($error=false,$msg=""){
	global $request;
	global $lstr;
	global $passback_data;
	
	// get variables
	$wizard=grab_request_var("wizard","");

	// find the wizard
	$w=get_configwizard_by_name($wizard);
	$wt=$w[CONFIGWIZARD_DISPLAYTITLE];
	
	$inargs=$passback_data;
	$outargs=array();
	$result=0;
	$wo=make_configwizard_callback($wizard,CONFIGWIZARD_MODE_GETSTAGE2HTML,$inargs,$outargs,$result);
	
	// TODO - if no output, redirect to next step...

	
	do_page_start(array("page_title"=>$wt." ".$lstr['MonitoringWizardStep3PageTitle']),true);

	//echo "<BR>TEST!<BR>";
	
	//echo "REQUEST:";
	//print_r($request);
	//exit();
?>

	<h1><?php echo $wt." ".$lstr['MonitoringWizardStep3PageHeader'];?></h1>
	

	<?php 
	$img=$w[CONFIGWIZARD_PREVIEWIMAGE];
	if($img!=""){
		echo "<img src='".get_base_url()."includes/components/nagioscore/ui/images/logos/".$img."'>";
		}
	?>

<?php
	display_message($error,false,$msg);
?>

	<form id="configWizardForm" method="post" action="<?php echo htmlentities($_SERVER['PHP_SELF']);?>" onSubmit="show_child_content_throbber();">
	<input type="hidden" name="update" value="1" />
	<?php echo get_nagios_session_protector();?>
	<input type="hidden" name="nextstep" value="4" />
	<input type="hidden" name="wizard" value="<?php echo encode_form_val($wizard);?>" />
	
	
<?php
	echo $wo;
?>

	<!--<div class="sectionTitle">-->
	<div id="formButtons">
	<input type="submit" class="submitbutton" name="submitButton" value="<?php echo $lstr['NextButton'];?>" style="visibility: hidden; display: none;" />
	<input type="submit" class="submitbutton" name="backButton" value="<?php echo $lstr['BackButton'];?>"/>
	<input type="submit" class="submitbutton" name="submitButton2" value="<?php echo $lstr['NextButton'];?>"/>
	<!--<input type="submit" class="submitbutton" name="cancelButton" value="<?php echo $lstr['CancelButton'];?>"/>-->
	<!--</div>-->
	
	<!--</fieldset>-->
	</form>

	
	
<?php

	do_page_end(true);
	exit();
	}

	
function validate_step3(){
	global $request;
	global $lstr;
	global $passback_data;
	
	// user cancelled wizard
	if(isset($request["cancelButton"]))
		show_step1();
	// user wants to go back a step
	if(isset($request["backButton"])){
		unset($request["backButton"]);
		validate_step1();
		show_step2();
		}
	
	
	// check session
	check_nagios_session_protector();

	$wizard=grab_request_var("wizard","");
	
	clean_configwizard_request_vars();
	
	// verify input with config wizard
	$inargs=$request;
	$outargs=array();
	$result=0;
	$wo=make_configwizard_callback($wizard,CONFIGWIZARD_MODE_VALIDATESTAGE2DATA,$inargs,$outargs,$result);
	
	// initialzie the passback args we got from the wizard - we need them in the next step
	$passback_data=$outargs[CONFIGWIZARD_PASSBACK_DATA];
	
	/*
	echo "RESULT: $result<BR>\n";
	echo "OUTPUT: $wo<BR>\n";
	echo "OUTARGS: <BR>\n";
	print_r($outargs);
	*/
	
	// handle errors
	if($result!=0){
		$errmsg=$outargs[CONFIGWIZARD_ERROR_MESSAGES];
		show_step3(true,$errmsg);
		}
	
	//echo "OK!";
	//exit();
	}
		

function show_step4($error=false,$msg=""){
	global $request;
	global $lstr;
	global $passback_data;
	
	//print_r($request);

	// defaults
	$check_interval=5;
	$retry_interval=1;
	$max_check_attempts=5;

	//print_r($request);

	// get variables
	$wizard=grab_request_var("wizard","");

	// find the wizard
	$w=get_configwizard_by_name($wizard);
	$wt=$w[CONFIGWIZARD_DISPLAYTITLE];
	
	// get stage options from wizard (wizard might wish to hide/change options presented to user)
	$inargs=array();
	$outargs=array();
	$result=0;
	$wo=make_configwizard_callback($wizard,CONFIGWIZARD_MODE_GETSTAGE3OPTS,$inargs,$outargs,$result);
	// see if we should hide options
	$hideopts=false;
	$hidemsg="";
	if($result==CONFIGWIZARD_HIDE_OPTIONS){
		$hideopts=true;
		$hidemsg=$wo;
		}
	// see if variables should be overriden
	if(array_key_exists(CONFIGWIZARD_OVERRIDE_OPTIONS,$outargs)){
		if(array_key_exists("check_interval",$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]))
			$check_interval=$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]["check_interval"];
		if(array_key_exists("retry_interval",$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]))
			$retry_interval=$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]["retry_interval"];
		if(array_key_exists("max_check_attempts",$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]))
			$max_check_attempts=$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]["max_check_attempts"];
		}
	

	// get html output from the wizard
	$inargs=$passback_data;
	$outargs=array();
	$result=0;
	$wo=make_configwizard_callback($wizard,CONFIGWIZARD_MODE_GETSTAGE3HTML,$inargs,$outargs,$result);
	
	
	
	do_page_start(array("page_title"=>$wt." ".$lstr['MonitoringWizardStep4PageTitle']),true);
?>

	<h1><?php echo $wt." ".$lstr['MonitoringWizardStep4PageHeader'];?></h1>
	

	<?php 
	$img=$w[CONFIGWIZARD_PREVIEWIMAGE];
	if($img!=""){
		echo "<img src='".get_base_url()."includes/components/nagioscore/ui/images/logos/".$img."'>";
		}
	?>

<?php
	display_message($error,false,$msg);
?>

	<form id="configWizardForm" method="post" action="<?php echo htmlentities($_SERVER['PHP_SELF']);?>" onSubmit="show_child_content_throbber();">
	<input type="hidden" name="update" value="1" />
	<?php echo get_nagios_session_protector();?>
	<input type="hidden" name="nextstep" value="5" />
	<input type="hidden" name="wizard" value="<?php echo encode_form_val($wizard);?>" />
	
	<input type="hidden" name="wizardoutput" value="<?php echo base64_encode(serialize($wo));?>" />
	
<?php
	echo $wo;
?>
	
	<div class="sectionTitle">Monitoring Settings</div>
	
<?php
	if($hideopts==true){

		echo $hidemsg;
?>
	<input type='hidden' name='check_interval' value='<?php echo encode_form_val($check_interval);?>'>
	<input type='hidden' name='retry_interval' value='<?php echo encode_form_val($retry_interval);?>'>
	<input type='hidden' name='max_check_attempts' value='<?php echo encode_form_val($max_check_attempts);?>'>
<?php
		}
	else{
?>
	<p>Define basic parameters that determine how the host and service(s) should be monitored.</p>
	
	<table>

	
	<tr>
	<td><b>Under normal circumstances...</b><br>Monitor the host and service(s) every <input type="text" size="2" name="check_interval" id="check_interval" value="<?php echo encode_form_val($check_interval);?>" class="textfield" /> minutes.</td>
	</tr>
	
	<tr>
	<td><b>When a potential problem is first detected...</b><br>Re-check the host and service(s) every <input type="text" size="2" name="retry_interval" id="retry_interval" value="<?php echo encode_form_val($retry_interval);?>" class="textfield" /> minutes up to <input type="text" size="2" name="max_check_attempts" id="max_check_attempts" value="<?php echo encode_form_val($max_check_attempts);?>" class="textfield" /> times before generating an alert.</td>
	</tr>
	
	</table>
<?php
		}
?>
	
	
	<!--<div class="sectionTitle">-->
	<div id="formButtons">
	<input type="submit" class="submitbutton" name="submitButton" value="<?php echo $lstr['NextButton'];?>" style="visibility: hidden; display: none;" />
	<input type="submit" class="submitbutton" name="backButton" value="<?php echo $lstr['BackButton'];?>"/>
	<input type="submit" class="submitbutton" name="submitButton2" value="<?php echo $lstr['NextButton'];?>"/>
	<!--<input type="submit" class="submitbutton" name="cancelButton" value="<?php echo $lstr['CancelButton'];?>"/>-->
	<!--</div>-->
	
	<!--</fieldset>-->
	</form>

	
	
<?php

	do_page_end(true);
	exit();
	}


function validate_step4(){
	global $request;
	global $lstr;
	global $passback_data;
	
	//echo "VALIDATE STEP4";
	//print_r($request);
	
	// user cancelled wizard
	if(isset($request["cancelButton"]))
		show_step1();
	// user wants to go back a step
	if(isset($request["backButton"])){
		unset($request["backButton"]);
		//echo "BACK BUTTON<BR>";
		validate_step2();
		//exit();
		show_step3();
		}
		
	//exit();
	
	
	// check session
	check_nagios_session_protector();

	$wizard=grab_request_var("wizard","");
	
	clean_configwizard_request_vars();
	
	// verify input with config wizard
	$inargs=$request;
	$outargs=array();
	$result=0;
	$wo=make_configwizard_callback($wizard,CONFIGWIZARD_MODE_VALIDATESTAGE3DATA,$inargs,$outargs,$result);
	
	// initialize the passback args we got from the wizard - we need them in the next step
	$passback_data=$outargs[CONFIGWIZARD_PASSBACK_DATA];
	
	// get other data
	$check_interval=grab_request_var("check_interval",5);
	$retry_interval=grab_request_var("retry_interval",1);
	$max_check_attempts=grab_request_var("max_check_attempts",5);
	
	/*
	echo "RESULT: $result<BR>\n";
	echo "OUTPUT: $wo<BR>\n";
	echo "OUTARGS: <BR>\n";
	print_r($outargs);
	*/
	
	// check for errors
	$errors=0;
	$errmsg=array();
	if($result!=0){
		$errmsg=$outargs[CONFIGWIZARD_ERROR_MESSAGES];
		$errors++;
		}
	if(intval($check_interval<=0))
		$errmsg[$errors++]="Invalid check interval.";
	if(intval($retry_interval<=0))
		$errmsg[$errors++]="Invalid retry interval.";
	if(intval($max_check_attempts<=0))
		$errmsg[$errors++]="Invalid maximum check attempts.";
		
	// handle errors
	if($errors>0){
		//echo "ERRORS!";
		//exit();
		show_step4(true,$errmsg);
		}

	
	//echo "OK!";
	//exit();
	}
		
		

function show_step5($error=false,$msg=""){
	global $request;
	global $lstr;
	global $passback_data;

	// defaults
	$notification_interval=60;
	$first_notification_delay=15;
	$notification_options="immediate";

	// get variables
	$wizard=grab_request_var("wizard","");
	$wizardoutput=grab_request_var("wizardoutput","");
	$check_interval=grab_request_var("check_interval",5);
	$retry_interval=grab_request_var("retry_interval",1);
	$max_check_attempts=grab_request_var("max_check_attempts",5);

	$notification_targets=grab_request_var("notification_targets",array());
	$contact_id=grab_request_var("contact_id",array());
	$contacts=grab_request_var("contacts",array());
	$contactgroup_id=grab_request_var("contactgroup_id",array());
	$contactgroups=grab_request_var("contactgroups",array());
	
	// unserialize arrays (this happens if user pressed back button in next step)
	if(!is_array($notification_targets))
		$notification_targets=unserialize(base64_decode($notification_targets));
	if(!is_array($contact_id))
		$contact_id=unserialize(base64_decode($contact_id));
	if(!is_array($contacts))
		$contacts=unserialize(base64_decode($contacts));
	if(!is_array($contactgroup_id))
		$contactgroup_id=unserialize(base64_decode($contactgroup_id));
	if(!is_array($contactgroups))
		$contactgroups=unserialize(base64_decode($contactgroups));
		
	// defaults
	if(!array_key_exists("myself",$notification_targets))
		$notification_targets["myself"]="on";
	if(!array_key_exists("contacts",$notification_targets))
		$notification_targets["contacts"]="on";
		//$notification_targets["contacts"]="";
	if(!array_key_exists("contactgroups",$notification_targets))
		$notification_targets["contactgroups"]="on";
		//$notification_targets["contactgroups"]="";
		
	//print_r($notification_targets);

	
	// find the wizard
	$w=get_configwizard_by_name($wizard);
	$wt=$w[CONFIGWIZARD_DISPLAYTITLE];

	// get stage options from wizard (wizard might wish to hide/overrride options presented to user)
	$inargs=array();
	$outargs=array();
	$result=0;
	$wo=make_configwizard_callback($wizard,CONFIGWIZARD_MODE_GETSTAGE4OPTS,$inargs,$outargs,$result);
	// see if we should hide options
	$hideopts=false;
	$hopts=array();
	$hidemsg="";
	if($result==CONFIGWIZARD_HIDE_OPTIONS){
		$hideopts=true;
		$hidemsg=$wo;
		$hopts=$outargs[CONFIGWIZARD_HIDDEN_OPTIONS];
		//print_r($hopts);
		}
	// see if variables should be overriden
	if(array_key_exists(CONFIGWIZARD_OVERRIDE_OPTIONS,$outargs)){
		if(array_key_exists("notification_interval",$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]))
			$notification_interval=$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]["notification_interval"];
		if(array_key_exists("first_notification_delay",$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]))
			$first_notification_delay=$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]["first_notification_delay"];
		if(array_key_exists("notification_options",$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]))
			$notification_options=$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]["notification_options"];
		if(array_key_exists("notification_targets",$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]))
			$notification_targets=$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]["notification_targets"];
		if(array_key_exists("contact_id",$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]))
			$contact_id=$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]["contact_id"];
		if(array_key_exists("contacts",$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]))
			$contacts=$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]["contacts"];
		if(array_key_exists("contactgroup_id",$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]))
			$contactgroup_id=$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]["contactgroup_id"];
		if(array_key_exists("contactgroups",$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]))
			$contactgroups=$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]["contactgroups"];
		}
	//print_r($outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]);

		
	do_page_start(array("page_title"=>$wt." ".$lstr['MonitoringWizardStep5PageTitle']),true);
?>

	<h1><?php echo $wt." ".$lstr['MonitoringWizardStep5PageHeader'];?></h1>
	

	<?php 
	$img=$w[CONFIGWIZARD_PREVIEWIMAGE];
	if($img!=""){
		echo "<img src='".get_base_url()."includes/components/nagioscore/ui/images/logos/".$img."'>";
		}
	?>

<?php
	display_message($error,false,$msg);
?>

	<form id="configWizardForm" method="post" action="<?php echo htmlentities($_SERVER['PHP_SELF']);?>" onSubmit="show_child_content_throbber();">
	<input type="hidden" name="update" value="1" />
	<?php echo get_nagios_session_protector();?>
	<input type="hidden" name="nextstep" value="6" />
	<input type="hidden" name="wizard" value="<?php echo encode_form_val($wizard);?>" />
	
	<input type="hidden" name="wizardoutput" value="<?php echo $wizardoutput;?>" />
	<input type="hidden" name="passbackdata" value="<?php echo base64_encode(serialize($passback_data));?>" />
	
	<input type="hidden" name="check_interval" value="<?php echo encode_form_val($check_interval);?>" />
	<input type="hidden" name="retry_interval" value="<?php echo encode_form_val($retry_interval);?>" />
	<input type="hidden" name="max_check_attempts" value="<?php echo encode_form_val($max_check_attempts);?>" />
	
<?php
	$wo=unserialize(base64_decode($wizardoutput));
	echo $wo;
?>
	

	
	<div class="sectionTitle">Notification Settings</div>
	
<?php
	// wizard is hiding everything, so change the message displayed...
	if(in_array(CONFIGWIZARD_HIDE_NOTIFICATION_OPTIONS,$hopts) && in_array(CONFIGWIZARD_HIDE_NOTIFICATION_TARGETS,$hopts)){
		echo $hidemsg;
		}
	else{
?>

	<p>Define basic parameters that determine how notifications should be sent for the host and service(s).</p>
	
	<table>
<?php
		}
?>
	
	<?php
	//echo "OPTS: '$notification_options'<BR>";
	?>
	
<?php
	if(!in_array(CONFIGWIZARD_HIDE_NOTIFICATION_OPTIONS,$hopts)){
?>
	<tr>
	<td>
	<b>When a problem is detected...</b><br>
	<input type="radio" name="notification_options" value="none" <?php echo is_checked($notification_options,"none");?>>Don't send any notifications<br>
	<input type="radio" name="notification_options" value="immediate" <?php echo is_checked($notification_options,"immediate");?>>Send a notification immediately<br>
<?php
		if(!in_array(CONFIGWIZARD_HIDE_NOTIFICATION_DELAY,$hopts)){
?>
	<input type="radio" name="notification_options" value="delayed" <?php echo is_checked($notification_options,"delayed");?>>Wait <input type="text" size="2" name="first_notification_delay" id="first_notification_delay" value="<?php echo encode_form_val($first_notification_delay);?>" class="textfield" /> minutes before sending a notification
<?php
			}
		else{		
?>	
	<input type='hidden' name='notification_options' value='<?php echo encode_form_val($notification_options);?>'>
<?php
			}
?>
	<br>
	</td>
	</tr>
<?php
		}
	else{
?>
	<input type='hidden' name='notification_options' value='<?php echo encode_form_val($notification_options);?>'>
	<input type='hidden' name='first_notification_delay' value='<?php echo encode_form_val($first_notification_delay);?>'>
<?php
		}
?>


<?php
	if(!in_array(CONFIGWIZARD_HIDE_NOTIFICATION_INTERVAL,$hopts)){
?>
	<tr>
	<td><b>If problems persist...</b><br>Send a notification every <input type="text" size="2" name="notification_interval" id="notification_interval" value="<?php echo encode_form_val($notification_interval);?>" class="textfield" /> minutes until the problem is resolved.</td>
<?php
		}
	else{		
?>
	<input type='hidden' name='notification_interval' value='<?php echo encode_form_val($notification_interval);?>'>
<?php
		}
?>

	
<?php
	if(!in_array(CONFIGWIZARD_HIDE_NOTIFICATION_TARGETS,$hopts)){
?>
	<tr>
	<td><b>Send alert notifications to...</b><br>

	<script type="text/javascript">
	function check_contacts(){
		$('#notification_targets_contacts').attr('checked',true);
		}
	function check_contactgroups(){
		$('#notification_targets_contactgroups').attr('checked',true);
		}
	</script>
	

	<input type="checkbox" name="notification_targets[myself]" id="notification_targets_myself" <?php echo is_checked($notification_targets["myself"],"on");?>>Myself (<a href="<?php echo get_base_url()."account/?xiwindow=notifyprefs.php";?>" target="_blank">Adjust settings</a>)<br>
	
	<input type="checkbox" name="notification_targets[contacts]" id="notification_targets_contacts" <?php echo is_checked($notification_targets["contacts"],"on");?>>Other individual contacts<br>
	<div style="overflow: auto; width: 275px; height: 80px; border: 1px solid gray; margin: 0 0 0 35px;">
	<?php
	$xml=get_xml_contact_objects(array("is_active"=>1,"orderby"=>"contact_name:a"));
	//print_r($xml);
	$username=get_user_attr(0,'username');
	foreach($xml->contact as $c){

		// skip the same contact as the current user - this is taken care of by the "myself" option above
		if(!strcmp(strval($c->contact_name),$username))
			continue;
			
		if(array_key_exists(strval($c->attributes()->id),$contact_id))
			$ischecked="CHECKED";
		else if(array_key_exists(strval($c->contact_name),$contacts))
			$ischecked="CHECKED";
		else
			$ischecked="";
		
		echo "<input type='checkbox' name='contact_id[".$c->attributes()->id."]' ".$ischecked." onclick='check_contacts()'>".$c->alias." (".$c->contact_name.")<br>";
		}
	?>
	</div>
	
	<input type="checkbox" name="notification_targets[contactgroups]" id="notification_targets_contactgroups" <?php echo is_checked($notification_targets["contactgroups"],"on");?>>Specific contact groups<br>
	<div style="overflow: auto; width: 275px; height: 80px; border: 1px solid gray; margin: 0 0 0 35px;">
	<?php
	$xml=get_xml_contactgroup_objects(array("is_active"=>1,"orderby"=>"contactgroup_name:a"));
	//print_r($xml);
	foreach($xml->contactgroup as $c){

		if(array_key_exists(strval($c->attributes()->id),$contactgroup_id))
			$ischecked="CHECKED";
		else if(array_key_exists(strval($c->contactgroup_name),$contactgroups))
			$ischecked="CHECKED";
		else
			$ischecked="";
		
		echo "<input type='checkbox' name='contactgroup_id[".$c->attributes()->id."]' ".$ischecked." onclick='check_contactgroups()'>".$c->alias." (".$c->contactgroup_name.")<br>";
		}
	?>
	</div>
	
	</td>
	</tr>
<?php
		}
	else{
?>
	<input type='hidden' name='notification_targets[myself]' value='<?php echo encode_form_val($notification_targets["myself"]);?>'>
	<input type='hidden' name='notification_targets[contacts]' value='<?php echo encode_form_val($notification_targets["contacts"]);?>'>
	<input type='hidden' name='notification_targets[contactgroups]' value='<?php echo encode_form_val($notification_targets["contactgroups"]);?>'>
<?php
		$xml=get_xml_contact_objects(array("is_active"=>1,"orderby"=>"contact_name:a"));
		$username=get_user_attr(0,'username');
		foreach($xml->contact as $c){
			$ischecked="";
			// skip the same contact as the current user - this is taken care of by the "myself" option above
			if(!strcmp(strval($c->contact_name),$username))
				continue;		
			if(array_key_exists(strval($c->attributes()->id),$contact_id))
				$ischecked="CHECKED";
			else if(array_key_exists(strval($c->contact_name),$contacts))
				$ischecked="CHECKED";
			else
				$ischecked="";
			if($ischecked!="")
				echo "<input type='hidden' name='contact_id[".$c->attributes()->id."]' value='on'>";
			}
			
		$xml=get_xml_contactgroup_objects(array("is_active"=>1,"orderby"=>"contactgroup_name:a"));
		foreach($xml->contactgroup as $c){
			$ischecked="";
			if(array_key_exists(strval($c->attributes()->id),$contactgroup_id))
				$ischecked="CHECKED";
			else if(array_key_exists(strval($c->contactgroup_name),$contactgroups))
				$ischecked="CHECKED";
			else
				$ischecked="";
			if($ischecked!="")
				echo "<input type='hidden' name='contactgroup_id[".$c->attributes()->id."]' value='on'>";
			}

		}
?>
	
	</table>
	
	<!--<div class="sectionTitle">-->
	<div id="formButtons">
	<input type="submit" class="submitbutton" name="submitButton" value="<?php echo $lstr['NextButton'];?>" style="visibility: hidden; display: none;" />
	<input type="submit" class="submitbutton" name="backButton" value="<?php echo $lstr['BackButton'];?>"/>
	<input type="submit" class="submitbutton" name="submitButton2" value="<?php echo $lstr['NextButton'];?>"/>
	<!--<input type="submit" class="submitbutton" name="cancelButton" value="<?php echo $lstr['CancelButton'];?>"/>-->
	<!--</div>-->
	
	<!--</fieldset>-->
	</form>

	
	
<?php

	do_page_end(true);
	exit();
	}



function validate_step5(){
	global $request;
	global $lstr;
	global $passback_data;
	
	//echo "VALIDATE STEP5";
	
	// user cancelled wizard
	if(isset($request["cancelButton"]))
		show_step1();
	// user wants to go back a step
	if(isset($request["backButton"])){
		unset($request["backButton"]);
		//echo "BACK BUTTON<BR>";
		validate_step3();
		//exit();
		show_step4();
		}
		
	//exit();
	
	
	// check session
	check_nagios_session_protector();

	// get other data
	$notification_interval=grab_request_var("notification_interval",60);
	$first_notification_delay=grab_request_var("first_notification_delay",15);
	$notification_targets=grab_request_var("notification_targets",array());
	$contact_id=grab_request_var("contact_id",array());
	$contactgroup_id=grab_request_var("contactgroup_id",array());
	
	/*
	echo "RESULT: $result<BR>\n";
	echo "OUTPUT: $wo<BR>\n";
	echo "OUTARGS: <BR>\n";
	print_r($outargs);
	*/
	
	// check for errors
	$errors=0;
	$errmsg=array();
	if(intval($notification_interval<=0))
		$errmsg[$errors++]="Invalid notification interval.";
	if(intval($first_notification_delay<=0))
		$errmsg[$errors++]="Invalid notification delay.";
	//if(array_key_exists("contacts",$notification_targets) && count($contact_id)==0)
	//	$errmsg[$errors++]="No contacts selected.";
	//if(array_key_exists("contactgroups",$notification_targets) && count($contactgroup_id)==0)
	//	$errmsg[$errors++]="No contact groups selected.";
		
	// handle errors
	if($errors>0){
		show_step5(true,$errmsg);
		}

	
	//print_r($request);
	
	//echo "OK!";
	//exit();
	}
		




		
		

function show_step6($error=false,$msg=""){
	global $request;
	global $lstr;
	global $passback_data;

	// defaults

	// get variables
	$wizard=grab_request_var("wizard","");
	$wizardoutput=grab_request_var("wizardoutput","");
	$passback_data=grab_request_var("passbackdata","");

	$check_interval=grab_request_var("check_interval",5);
	$retry_interval=grab_request_var("retry_interval",1);
	$max_check_attempts=grab_request_var("max_check_attempts",5);
	$notification_interval=grab_request_var("notification_interval",60);
	$first_notification_delay=grab_request_var("first_notification_delay",15);
	$notification_options=grab_request_var("notification_options","immediate");
	$notification_targets=grab_request_var("notification_targets",array());
	$contact_id=grab_request_var("contact_id",array());
	$contactgroup_id=grab_request_var("contactgroup_id",array());
	$parenthost_id=grab_request_var("parenthost_id",array());
	$parenthosts=grab_request_var("parenthosts",array());
	$hostgroup_id=grab_request_var("hostgroup_id",array());
	$hostgroups=grab_request_var("hostgroups",array());
	$servicegroup_id=grab_request_var("servicegroup_id",array());
	$servicegroups=grab_request_var("servicegroups",array());

	// unserialize arrays (this happens if user pressed back button in next step)
	if(!is_array($parenthost_id))
		$parenthost_id=unserialize(base64_decode($parenthost_id));
	if(!is_array($parenthosts))
		$parenthosts=unserialize(base64_decode($parenthosts));
	if(!is_array($hostgroup_id))
		$hostgroup_id=unserialize(base64_decode($hostgroup_id));
	if(!is_array($hostgroups))
		$hostgroups=unserialize(base64_decode($hostgroups));
	if(!is_array($servicegroup_id))
		$servicegroup_id=unserialize(base64_decode($servicegroup_id));
	if(!is_array($servicegroups))
		$servicegroups=unserialize(base64_decode($servicegroups));
	if(!is_array($notification_targets))
		$notification_targets=unserialize(base64_decode($notification_targets));
	if(!is_array($contact_id))
		$contact_id=unserialize(base64_decode($contact_id));
	if(!is_array($contactgroup_id))
		$contactgroup_id=unserialize(base64_decode($contactgroup_id));
	
	/*
	echo "NT:<BR>";
	print_r($notification_targets);
	echo "CI:<BR>";
	print_r($contact_id);
	echo "CGI:<BR>";
	print_r($contactgroup_id);
	*/
	
	// defaults
		

	
	// find the wizard
	$w=get_configwizard_by_name($wizard);
	$wt=$w[CONFIGWIZARD_DISPLAYTITLE];

	// get stage options from wizard (wizard might wish to hide/overrride options presented to user)
	$inargs=array();
	$outargs=array();
	$result=0;
	$wo=make_configwizard_callback($wizard,CONFIGWIZARD_MODE_GETSTAGE5OPTS,$inargs,$outargs,$result);
	// see if we should hide options
	$hideopts=false;
	$hopts=array();
	$hidemsg="";
	if($result==CONFIGWIZARD_HIDE_OPTIONS){
		$hideopts=true;
		$hidemsg=$wo;
		$hopts=$outargs[CONFIGWIZARD_HIDDEN_OPTIONS];
		//print_r($hopts);
		}
	// see if variables should be overriden
	if(array_key_exists(CONFIGWIZARD_OVERRIDE_OPTIONS,$outargs)){
		if(array_key_exists("parenthost_id",$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]))
			$parenthost_id=$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]["parenthost_id"];
		if(array_key_exists("parenthosts",$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]))
			$parenthosts=$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]["parenthosts"];
		if(array_key_exists("hostgroup_id",$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]))
			$hostgroup_id=$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]["hostgroup_id"];
		if(array_key_exists("hostgroups",$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]))
			$hostgroups=$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]["hostgroups"];
		if(array_key_exists("servicegroup_id",$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]))
			$servicegroup_id=$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]["servicegroup_id"];
		if(array_key_exists("servicegroups",$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]))
			$servicegroups=$outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]["servicegroups"];
		}
	//print_r($outargs[CONFIGWIZARD_OVERRIDE_OPTIONS]);

		
	do_page_start(array("page_title"=>$wt." ".$lstr['MonitoringWizardStep6PageTitle']),true);
?>

	<h1><?php echo $wt." ".$lstr['MonitoringWizardStep6PageHeader'];?></h1>
	

	<?php 
	$img=$w[CONFIGWIZARD_PREVIEWIMAGE];
	if($img!=""){
		echo "<img src='".get_base_url()."includes/components/nagioscore/ui/images/logos/".$img."'>";
		}
	?>

<?php
	display_message($error,false,$msg);
?>

	<form id="configWizardForm" method="post" action="<?php echo htmlentities($_SERVER['PHP_SELF']);?>" onSubmit="show_child_content_throbber();">
	<input type="hidden" name="update" value="1" />
	<?php echo get_nagios_session_protector();?>
	<input type="hidden" name="nextstep" value="final" />
	<input type="hidden" name="wizard" value="<?php echo encode_form_val($wizard);?>" />
	
	<input type="hidden" name="wizardoutput" value="<?php echo $wizardoutput;?>" />
	<input type="hidden" name="passbackdata" value="<?php echo $passback_data;?>" />
	
	<input type="hidden" name="check_interval" value="<?php echo encode_form_val($check_interval);?>" />
	<input type="hidden" name="retry_interval" value="<?php echo encode_form_val($retry_interval);?>" />
	<input type="hidden" name="max_check_attempts" value="<?php echo encode_form_val($max_check_attempts);?>" />
	<input type="hidden" name="notification_interval" value="<?php echo encode_form_val($notification_interval);?>" />
	<input type="hidden" name="first_notification_delay" value="<?php echo encode_form_val($first_notification_delay);?>" />
	<input type="hidden" name="notification_options" value="<?php echo encode_form_val($notification_options);?>" />
	<input type="hidden" name="notification_targets" value="<?php echo base64_encode(serialize($notification_targets));?>" />
	<input type="hidden" name="contact_id" value="<?php echo base64_encode(serialize($contact_id));?>" />
	<input type="hidden" name="contactgroup_id" value="<?php echo base64_encode(serialize($contactgroup_id));?>" />
	
<?php
	$wo=unserialize(base64_decode($wizardoutput));
	echo $wo;
?>


	
	<div class="sectionTitle">Host Groups</div>
	
	<p>Define which hostgroup(s) the monitored host should belong to (if any).</p>
	
	
	<div style="overflow: auto; width: 275px; height: 80px; border: 1px solid gray; margin: 0 0 0 35px;">
	<?php
	$xml=get_xml_hostgroup_objects(array("is_active"=>1,"orderby"=>"hostgroup_name:a"));
	//print_r($xml);
	foreach($xml->hostgroup as $c){

		if(array_key_exists(strval($c->attributes()->id),$hostgroup_id))
			$ischecked="CHECKED";
		else if(array_key_exists(strval($c->hostgroup_name),$hostgroups))
			$ischecked="CHECKED";
		else
			$ischecked="";
		
		echo "<input type='checkbox' name='hostgroup_id[".$c->attributes()->id."]' ".$ischecked." >".$c->alias." (".$c->hostgroup_name.")<br>";
		}
	?>
	</div>
	

	
	<div class="sectionTitle">Service Groups</div>
	
	<p>Define which servicegroup(s) the monitored service(s) should belong to (if any).</p>
	
	
	<div style="overflow: auto; width: 275px; height: 80px; border: 1px solid gray; margin: 0 0 0 35px;">
	<?php
	$xml=get_xml_servicegroup_objects(array("is_active"=>1,"orderby"=>"servicegroup_name:a"));
	//print_r($xml);
	foreach($xml->servicegroup as $c){

		if(array_key_exists(strval($c->attributes()->id),$servicegroup_id))
			$ischecked="CHECKED";
		else if(array_key_exists(strval($c->servicegroup_name),$servicegroups))
			$ischecked="CHECKED";
		else
			$ischecked="";
		
		echo "<input type='checkbox' name='servicegroup_id[".$c->attributes()->id."]' ".$ischecked." >".$c->alias." (".$c->servicegroup_name.")<br>";
		}
	?>
	</div>

<?php
	if(is_advanced_user()==true){
?>
	<div class="sectionTitle">Parent Host</div>
	
	<p>Define which host(s) are considered the parents of the the monitored host (if any). Note: Typically only one (1) host is specified as a parent.</p>
	
	
	<div style="overflow: auto; width: 275px; height: 80px; border: 1px solid gray; margin: 0 0 0 35px;">
	<?php
	$xml=get_xml_host_objects(array("is_active"=>1,"orderby"=>"host_name:a"));
	//print_r($xml);
	foreach($xml->host as $c){

		if(array_key_exists(strval($c->attributes()->id),$parenthost_id))
			$ischecked="CHECKED";
		else if(array_key_exists(strval($c->host_name),$parenthosts))
			$ischecked="CHECKED";
		else
			$ischecked="";
		
		echo "<input type='checkbox' name='parenthost_id[".$c->attributes()->id."]' ".$ischecked." >".$c->host_name." (".$c->address.")<br>";
		}
	?>
	</div>
	
<?php
		}
?>
	
	
	<!--<div class="sectionTitle">-->
	<div id="formButtons">
	<input type="submit" class="submitbutton" name="submitButton" value="<?php echo $lstr['NextButton'];?>" style="visibility: hidden; display: none;" />
	<input type="submit" class="submitbutton" name="backButton" value="<?php echo $lstr['BackButton'];?>"/>
	<input type="submit" class="submitbutton" name="submitButton2" value="<?php echo $lstr['NextButton'];?>"/>
	<!--<input type="submit" class="submitbutton" name="cancelButton" value="<?php echo $lstr['CancelButton'];?>"/>-->
	<!--</div>-->
	
	<!--</fieldset>-->
	</form>

	
	
<?php

	do_page_end(true);
	exit();
	}



function validate_step6(){
	global $request;
	global $lstr;
	global $passback_data;
	
	//echo "VALIDATE STEP6";
	
	// user cancelled wizard
	if(isset($request["cancelButton"]))
		show_step1();
	// user wants to go back a step
	if(isset($request["backButton"])){
		unset($request["backButton"]);
		//echo "BACK BUTTON<BR>";
		validate_step4();
		//exit();
		show_step5();
		}
		
	//exit();
	
	
	// check session
	check_nagios_session_protector();

	// get other data
	$parenthost_id=grab_request_var("parenthost_id",0);
	$hostgroup_id=grab_request_var("hostgroup_id",array());
	$servicegroup_id=grab_request_var("servicegroup_id",array());
	
	
	// check for errors
	$errors=0;
	$errmsg=array();
		
	// handle errors
	if($errors>0){
		show_step6(true,$errmsg);
		}

	
	//print_r($request);
	//echo "OK!";
	//exit();
	}
		
		

function show_final_step($error=false,$msg=""){
	global $request;
	global $lstr;
	global $passback_data;
	
	// get variables
	$wizard=grab_request_var("wizard","");
	$wizardoutput=grab_request_var("wizardoutput","");
	$passback_data=grab_request_var("passbackdata","");
	
	$check_interval=grab_request_var("check_interval",5);
	$retry_interval=grab_request_var("retry_interval",1);
	$max_check_attempts=grab_request_var("max_check_attempts",5);
	$notification_interval=grab_request_var("notification_interval",60);
	$first_notification_delay=grab_request_var("first_notification_delay",15);
	$notification_options=grab_request_var("notification_options","immediate");
	$notification_targets=grab_request_var("notification_targets",array());
	$contact_id=grab_request_var("contact_id",array());
	$contactgroup_id=grab_request_var("contactgroup_id",array());
	$parenthost_id=grab_request_var("parenthost_id",array());
	$hostgroup_id=grab_request_var("hostgroup_id",array());
	$servicegroup_id=grab_request_var("servicegroup_id",array());

	// unserialize arrays (this happens if user pressed back button in next step)
	if(!is_array($parenthost_id))
		$parenthost_id=unserialize(base64_decode($parenthost_id));
	if(isset($parenthosts) && !is_array($parenthosts))  //undefined// 
		$parenthosts=unserialize(base64_decode($parenthosts)); //undefined //
	if(!is_array($hostgroup_id))
		$hostgroup_id=unserialize(base64_decode($hostgroup_id));
	if(isset($hostgroups) && !is_array($hostgroups)) //undefined //
		$hostgroups=unserialize(base64_decode($hostgroups)); //undefined //
	if(!is_array($servicegroup_id))
		$servicegroup_id=unserialize(base64_decode($servicegroup_id));
	if(isset($servicegroups) && !is_array($servicegroups)) //undefined 
		$servicegroups=unserialize(base64_decode($servicegroups)); //undefined// 
	if(!is_array($notification_targets))
		$notification_targets=unserialize(base64_decode($notification_targets));
	if(!is_array($contact_id))
		$contact_id=unserialize(base64_decode($contact_id));
	if(!is_array($contactgroup_id))
		$contactgroup_id=unserialize(base64_decode($contactgroup_id));
	/*
	echo "NT:<BR>";
	print_r($notification_targets);
	echo "CI:<BR>";
	print_r($contact_id);
	echo "CGI:<BR>";
	print_r($contactgroup_id);
	*/

	// find the wizard
	$w=get_configwizard_by_name($wizard);
	$wt=$w[CONFIGWIZARD_DISPLAYTITLE];

	$inargs=array();
	$outargs=array();
	$result=0;
	$wfo=make_configwizard_callback($wizard,CONFIGWIZARD_MODE_GETFINALSTAGEHTML,$inargs,$outargs,$result);
	
	do_page_start(array("page_title"=>$wt." ".$lstr['MonitoringWizardStepFinalPageTitle']),true);
	
	//print_r($request);
?>

	<h1><?php echo $wt." ".$lstr['MonitoringWizardStepFinalPageHeader'];?></h1>
	

	<?php 
	$img=$w[CONFIGWIZARD_PREVIEWIMAGE];
	if($img!=""){
		echo "<img src='".get_base_url()."includes/components/nagioscore/ui/images/logos/".$img."'>";
		}
	?>

<?php
	display_message($error,false,$msg);
?>

	<form id="configWizardForm" method="post" action="<?php echo htmlentities($_SERVER['PHP_SELF']);?>" onSubmit="show_child_content_throbber();">
	<input type="hidden" name="update" value="1" />
	<?php echo get_nagios_session_protector();?>
	<input type="hidden" name="nextstep" value="commit" />
	<input type="hidden" name="wizard" value="<?php echo encode_form_val($wizard);?>" />
	
	<input type="hidden" name="wizardoutput" value="<?php echo $wizardoutput;?>" />
	<input type="hidden" name="passbackdata" value="<?php echo $passback_data;?>" />
	
	<input type="hidden" name="check_interval" value="<?php echo encode_form_val($check_interval);?>" />
	<input type="hidden" name="retry_interval" value="<?php echo encode_form_val($retry_interval);?>" />
	<input type="hidden" name="max_check_attempts" value="<?php echo encode_form_val($max_check_attempts);?>" />
	<input type="hidden" name="notification_interval" value="<?php echo encode_form_val($notification_interval);?>" />
	<input type="hidden" name="first_notification_delay" value="<?php echo encode_form_val($first_notification_delay);?>" />
	<input type="hidden" name="notification_options" value="<?php echo encode_form_val($notification_options);?>" />
	<input type="hidden" name="notification_targets" value="<?php echo base64_encode(serialize($notification_targets));?>" />
	<input type="hidden" name="contact_id" value="<?php echo base64_encode(serialize($contact_id));?>" />
	<input type="hidden" name="contactgroup_id" value="<?php echo base64_encode(serialize($contactgroup_id));?>" />
	<input type="hidden" name="parenthost_id" value="<?php echo base64_encode(serialize($parenthost_id));?>" />
	<input type="hidden" name="hostgroup_id" value="<?php echo base64_encode(serialize($hostgroup_id));?>" />
	<input type="hidden" name="servicegroup_id" value="<?php echo base64_encode(serialize($servicegroup_id));?>" />
	
<?php
	$wo=unserialize(base64_decode($wizardoutput));
	echo $wo;
?>
	

	
	<div class="sectionTitle">Final Settings</div>

<?php
	echo $wfo;
?>
	
	<p>Click <b>Apply</b> to add your new configuration.</p>

	

	
	<!--<div class="sectionTitle">-->
	<div id="formButtons">
	<input type="submit" class="submitbutton" name="submitButton" value="<?php echo $lstr['NextButton'];?>" style="visibility: hidden; display: none;" />
	<input type="submit" class="submitbutton" name="backButton" value="<?php echo $lstr['BackButton'];?>"/>
	<input type="submit" class="submitbutton" name="submitButton2" value="<?php echo $lstr['ApplyButton'];?>"/>
	<!--<input type="submit" class="submitbutton" name="cancelButton" value="<?php echo $lstr['CancelButton'];?>"/>-->
	<!--</div>-->
	
	<!--</fieldset>-->
	</form>

	
	
<?php

	do_page_end(true);
	exit();
	}



function validate_final_step(){
	global $request;
	global $lstr;
	global $passback_data;
	
	// user cancelled wizard
	if(isset($request["cancelButton"]))
		show_step1();
	// user wants to go back a step
	if(isset($request["backButton"])){
		unset($request["backButton"]);
		//echo "BACK BUTTON<BR>";
		validate_step5();
		//exit();
		show_step6();
		}

	
	// check session
	check_nagios_session_protector();		
	
	//echo "FINAL STEP!";
	//echo "OK!";
	//exit();
	}
	
		
	
function do_commit(){
	global $request;
	global $lstr;
	global $passback_data;
	global $firsthost;
	
	// user cancelled wizard
	if(isset($request["cancelButton"]))
		show_step1();
	// user wants to go back a step
	if(isset($request["backButton"])){
		unset($request["backButton"]);
		//echo "BACK BUTTON<BR>";
		validate_step5();
		//exit();
		show_final_step();
		}
		
	
	// check session
	check_nagios_session_protector();

	// get variables
	$wizard=grab_request_var("wizard","");
	$wizardoutput=grab_request_var("wizardoutput","");
	$passbackdata=grab_request_var("passbackdata","");
	$check_interval=grab_request_var("check_interval",5);
	$retry_interval=grab_request_var("retry_interval",1);
	$max_check_attempts=grab_request_var("max_check_attempts",5);
	$notification_interval=grab_request_var("notification_interval",60);
	$first_notification_delay=grab_request_var("first_notification_delay",15);
	$notification_options=grab_request_var("notification_options","");
	$notification_targets=grab_request_var("notification_targets","");
	$contact_id=grab_request_var("contact_id","");
	$contactgroup_id=grab_request_var("contactgroup_id","");
	$parenthost_id=grab_request_var("parenthost_id","");
	$hostgroup_id=grab_request_var("hostgroup_id","");
	$servicegroup_id=grab_request_var("servicegroup_id","");

	// decode data
	$nt=unserialize(base64_decode($notification_targets));
	$ci=unserialize(base64_decode($contact_id));
	$cgi=unserialize(base64_decode($contactgroup_id));
	$passback_data=unserialize(base64_decode($passbackdata));
	$wo=unserialize(base64_decode($wizardoutput));
	$phi=unserialize(base64_decode($parenthost_id));
	$hgi=unserialize(base64_decode($hostgroup_id));
	$sgi=unserialize(base64_decode($servicegroup_id));

	/*
	print_r($request);
	echo "<BR>";
	echo "NOTIFICATION OPTIONS: $notification_options<BR>";
	*/
	/*
	echo "<BR>";
	echo "COMMITTING!";
	echo "<BR>";
	echo "NOTIFICATION TARGETS:<BR>";
	print_r($nt);
	echo "<BR>";
	echo "CONTACT IDS:<BR>";
	print_r($ci);
	echo "<BR>";
	echo "CONTACTGROUP IDS:<BR>";
	print_r($cgi);
	echo "<BR>";
	echo "PASSBACK: <BR>";
	print_r($passback_data);
	echo "<BR>";
	echo "WIZARDOUTPUT: <BR>";
	print_r($wo);
	*/
	
	$contact_names="";
	$contactgroup_names="";
	
	if(is_array($nt)){
	
		// resolve contact names
		$contact_names="";
		$total_contacts=0;
		
		// this user
		if(array_key_exists("myself",$nt)){
			$contact_names.=get_user_attr(0,"username");
			$total_contacts++;
			}
		
		// additional individual contacts
		if(array_key_exists("contacts",$nt)){
			$ids="";
			foreach($ci as $id => $val){
				$ids.=",".$id;
				}
			if($ids!=""){
				$args=array(
					"is_active" => 1,
					"contact_id" => "in:".$ids,
					);
				//echo "IDS: $ids<BR>";
				//print_r($args);	
				$xml=get_xml_contact_objects($args);
				foreach($xml->contact as $c){
					if($total_contacts>0)
						$contact_names.=",";
					$contact_names.=$c->contact_name;
					$total_contacts++;
					}
				}
			}

		//echo "<BR>CONTACTS: $contact_names<BR>";

		// resolve contactgroup names
		$contactgroup_names="";
		$total_contactgroups=0;
		
		// additional individual contactgroups
		if(array_key_exists("contactgroups",$nt)){
			$ids="";
			foreach($cgi as $id => $val){
				$ids.=",".$id;
				}
			if($ids!=""){
				$args=array(
					"is_active" => 1,
					"contactgroup_id" => "in:".$ids,
					);
				//echo "IDS: $ids<BR>";
				//print_r($args);	
				$xml=get_xml_contactgroup_objects($args);
				foreach($xml->contactgroup as $cg){
					if($total_contactgroups>0)
						$contactgroup_names.=",";
					$contactgroup_names.=$cg->contactgroup_name;
					$total_contactgroups++;
					}
				}
			}

		//echo "<BR>CONTACTGROUPS: $contactgroup_names<BR>";
		}

	// resolve parent host names
	$parenthost_names="";
	$total_parenthosts=0;
	$ids="";
	if(is_array($phi)){
		foreach($phi as $id => $val){
			$ids.=",".$id;
			}
		if($ids!=""){
			$args=array(
				"is_active" => 1,
				"host_id" => "in:".$ids,
				);
			//echo "IDS: $ids<BR>";
			//print_r($args);	
			$xml=get_xml_host_objects($args);
			foreach($xml->host as $h){
				if($total_parenthosts>0)
					$parenthost_names.=",";
				$parenthost_names.=$h->host_name;
				$total_parenthosts++;
				}
			}
		}
	//echo "<BR>PARENTHOSTS: $parenthost_names<BR>";
	
	// resolve hostgroup names
	$hostgroup_names="";
	$total_hostgroups=0;
	$ids="";
	if(is_array($hgi)){
		foreach($hgi as $id => $val){
			$ids.=",".$id;
			}
		if($ids!=""){
			$args=array(
				"is_active" => 1,
				"hostgroup_id" => "in:".$ids,
				);
			//echo "IDS: $ids<BR>";
			//print_r($args);	
			$xml=get_xml_hostgroup_objects($args);
			foreach($xml->hostgroup as $hg){
				if($total_hostgroups>0)
					$hostgroup_names.=",";
				$hostgroup_names.=$hg->hostgroup_name;
				$total_hostgroups++;
				}
			}
		}
	//echo "<BR>HOSTGROUPS: $hostgroup_names<BR>";
	
	// resolve servicegroup names
	$servicegroup_names="";
	$total_servicegroups=0;
	$ids="";
	if(is_array($sgi)){
		foreach($sgi as $id => $val){
			$ids.=",".$id;
			}
		if($ids!=""){
			$args=array(
				"is_active" => 1,
				"servicegroup_id" => "in:".$ids,
				);
			//echo "IDS: $ids<BR>";
			//print_r($args);	
			$xml=get_xml_servicegroup_objects($args);
			foreach($xml->servicegroup as $sg){
				if($total_servicegroups>0)
					$servicegroup_names.=",";
				$servicegroup_names.=$sg->servicegroup_name;
				$total_servicegroups++;
				}
			}
		}
	//echo "<BR>SERVICEGROUPS: $servicegroup_names<BR>";
	
	//exit();

	// get objects from the wizard
	$inargs=$passback_data;
	$outargs=array();
	$result=0;
	$wo=make_configwizard_callback($wizard,CONFIGWIZARD_MODE_GETOBJECTS,$inargs,$outargs,$result);
	
	// initialize the nagios objects we got from the wizard - we need them in the next step
	$objects=$outargs[CONFIGWIZARD_NAGIOS_OBJECTS];
	
	//echo "<BR>OBJECTS1:<BR>";
	//print_r($objects);
	
	// apply monitoring and notification data
	foreach($objects as $oid => $obj){
	
		// hosts and services
		if($obj["type"]==OBJECTTYPE_HOST || $obj["type"]==OBJECTTYPE_SERVICE){
		
			// monitoring intervals, check attempts
			if(!array_key_exists("check_interval",$objects[$oid]))
				$objects[$oid]["check_interval"]=$check_interval;
			if(!array_key_exists("retry_interval",$objects[$oid]))
				$objects[$oid]["retry_interval"]=$retry_interval;
			if(!array_key_exists("max_check_attempts",$objects[$oid]))
				$objects[$oid]["max_check_attempts"]=$max_check_attempts;
			
			// check and notification timeperiods
			$tp="xi_timeperiod_24x7";
			if(!array_key_exists("check_period",$objects[$oid]))
				$objects[$oid]["check_period"]=$tp;
			if(!array_key_exists("notification_period",$objects[$oid]))
				$objects[$oid]["notification_period"]=$tp;
				
			// hostgroups and parent host
			if($obj["type"]==OBJECTTYPE_HOST){
			
				// hostgroups
				if($hostgroup_names!="")
					$objects[$oid]["hostgroups"]=$hostgroup_names;
				else
					$objects[$oid]["hostgroups"]="null";
					
				// parents
				if($parenthost_names!="")
					$objects[$oid]["parents"]=$parenthost_names;
				else
					$objects[$oid]["parents"]="null";
				}
		
			// servicegroups
			if($obj["type"]==OBJECTTYPE_SERVICE){
			
				// servicegroups
				if($servicegroup_names!="")
					$objects[$oid]["servicegroups"]=$servicegroup_names;
				else
					$objects[$oid]["servicegroups"]="null";
				}
					
			// contacts
			if(!array_key_exists("contacts",$objects[$oid])){
				if($contact_names!="")
					$objects[$oid]["contacts"]=$contact_names;
				else
					$objects[$oid]["contacts"]="null";
				}

			// contactgroups
			if(!array_key_exists("contact_groups",$objects[$oid])){
				if($contactgroup_names!="")
					$objects[$oid]["contact_groups"]=$contactgroup_names;
				else
					$objects[$oid]["contact_groups"]="null";
				}

			// notification interval, delay
			if(!array_key_exists("notification_interval",$objects[$oid]))
				$objects[$oid]["notification_interval"]=$notification_interval;
			if($notification_options=="delayed"){
				if(!array_key_exists("first_notification_delay",$objects[$oid]))
					$objects[$oid]["first_notification_delay"]=$first_notification_delay;
				}
			else if($notification_options=="none"){
				if(!array_key_exists("notification_options",$objects[$oid]))
					$objects[$oid]["notification_options"]="n";
				}
				
			//echo "OBJECT:<BR>\n";
			//print_r($objects[$oid]);
				
			// unset NULL variables that user wants to have inherited from a template
			$nullvars=array(
				"check_interval",
				"retry_interval",
				"max_check_attempts",
				"check_period",
				"notification_period",
				"contacts",
				"contact_groups",
				"notification_interval",
				"first_notification_delay",
				"notification_options",
				"servicegroups",
				"hostgroups",
				"parents",
				);
			foreach($nullvars as $nv){
				if(!array_key_exists($nv,$objects[$oid]))
					continue;
				if($objects[$oid][$nv]=="null")
					unset($objects[$oid][$nv]);
				}
			}
		}

	//echo "<BR>OBJECTS2:<BR>";
	//print_r($objects);
	//exit();
	
	// check permissions
	if(check_configwizard_object_perms($objects)==false){
		show_commit_perms_error();
		}
	// commit the objects
	else{
		commit_configwizard_objects($objects,$firsthost);
		show_commit_complete();
		}
	}

	
	
function commit_configwizard_objects($objects,&$firsthost){

	$have_first_host=false;

	// FIRST PROCESS NON-SERVICES

	// create the import file
	$fname="";
	$fh=create_nagioscore_import_file($fname);
	
	foreach($objects as $oid => $obj){
	
		// get the object type
		$oname="";
		switch($obj["type"]){
			case OBJECTTYPE_HOST:
				$oname="host";
				break;
			case OBJECTTYPE_HOSTGROUP:
				$oname="hostgroup";
				break;
			case OBJECTTYPE_SERVICEGROUP: 
				$oname="servicegroup";
				break;
			case OBJECTTYPE_COMMAND:
				$oname="command";
				break;
			default:
				break;
			}
			
		// unhandled object types
		if($oname=="")
			continue;

		// write the object definition to file
		fprintf($fh,"define ".$oname."{\n");
		
		foreach($obj as $var => $val){
			if($var=="type")
				continue;
			fprintf($fh,$var."\t".$val."\n");
			
			if($oname=="host" && $have_first_host==false && $var=="host_name"){
				$have_first_host=true;
				$firsthost=$val;
				
				// preload ndoutils with host
				$hid=add_ndoutils_object(OBJECTTYPE_HOST,$firsthost);
				//echo "HID: $hid, HOST=".$obj["host_name"]."<BR>";
				/* this is now handled elsewhere */
				/*
				if($hid>0)
					$hsid=add_ndoutils_hoststatus($hid,STATE_UP,STATETYPE_HARD,"Host check is pending...");
				*/
				//echo "HSID: $hsid<BR>";
				}
			}
		fprintf($fh,"}\n");
		}
	
	// commit the import file
	fclose($fh);
	commit_nagioscore_import_file($fname);	

	
	// PROCESS SERVICES
	$openfile=false;
	$importfiles=array();
	$multihost=false;
	foreach($objects as $oid => $obj){
	
		if($have_first_host==false){
			$have_first_host=true;
			$firsthost=$obj["host_name"];
			}
		else{
			if($firsthost!=$obj["host_name"])
				$multihost=true;
			}

		// get the object type
		$oname="";
		switch($obj["type"]){
			case OBJECTTYPE_SERVICE:
				$oname="service";

				// preload ndoutils with service
				$sid=add_ndoutils_object(OBJECTTYPE_SERVICE,$obj["host_name"],$obj["service_description"]);
				//echo "SID: $sid, HOST=".$obj["host_name"].", SVC=".$obj["service_description"]."<BR>";
				/* this is now handled elsewhere */
				/*
				if($sid>0)
					$ssid=add_ndoutils_servicestatus($sid,STATE_OK,STATETYPE_HARD,"Service check is pending...");
				*/
				//echo "SSID: $ssid<BR>";

				break;
			default:
				break;
			}
			
		// unhandled object types
		if($oname=="")
			continue;

		// create the import file
		if($openfile==false){
			$fname=$obj["host_name"];
			$fh=create_nagioscore_import_file($fname);
			$openfile=true;
			}
		
		// write the object definition to file
		fprintf($fh,"define ".$oname."{\n");
		
		foreach($obj as $var => $val){
			if($var=="type")
				continue;
			fputs($fh,$var."\t".$val."\n");
			}
		fprintf($fh,"}\n");
		
		// close file now, commit the import file later
		if($openfile==true){
			$openfile=false;
			fclose($fh);
			// add this to the import files to commit (if it isn't already in there)
			if(!in_array($fname,$importfiles))
				$importfiles[]=$fname;
			}
		}
			
	// commit all import files
	foreach($importfiles as $if){
		commit_nagioscore_import_file($if);	
		}
		
	// multiple hosts
	if($multihost==true)
		$firsthost="";

	// THIS IS NOW DONE ELSEWHERE
	// reconfigure nagios
	//reconfigure_nagioscore();
	}
		

function show_commit_complete($error=false,$msg=""){
	global $configwizards;
	global $request;
	global $lstr;
	global $firsthost;
	
	$wizard=grab_request_var("wizard","");
	
	// find the wizard
	$w=get_configwizard_by_name($wizard);
	$wt=$w[CONFIGWIZARD_DISPLAYTITLE];

	
	do_page_start(array("page_title"=>$lstr['MonitoringWizardCommitCompletePageTitle']),true);
?>

	<h1><?php echo $wt." ".$lstr['MonitoringWizardCommitCompletePageHeader'];?></h1>
	

<?php
	display_message($error,false,$msg);
?>

<ul class="commandresult">
<?php
	$error=false;
	$id=submit_command(COMMAND_NAGIOSCORE_APPLYCONFIG);
	//echo "COMMAND ID: $id<BR>";
	if($id>0){
		echo "<li class='commandresultok'>"."Configuration submitted for processing..."."</li>\n";
	
		echo "<li class='commandresultwaiting' id='commandwaiting'>"."Waiting for configuration verification...</li>"."</li>\n";
		}
	else{
		echo "<li class='commandresulterror'>"."An error occurred during command submission.  If this problem persists, contact your Nagios administrator."."</li>\n";

		// make config wizard callback
		$inargs=$request;
		$outargs=array();
		$result=0;
		$wo=make_configwizard_callback($wizard,CONFIGWIZARD_MODE_COMMITERROR,$inargs,$outargs,$result);

		$error=true;
		}
?>
</ul>

	

<div id="commandsuccesscontent" style="visibility: hidden;">
	
	<div class="sectionTitle"><?php echo $lstr['MonitoringWizardCommitSuccessSectionTitle'];?></div>
	
	<p><?php echo $lstr['MonitoringWizardCommitSuccessNotes'];?></p>

	<p><a href="<?php echo htmlspecialchars($_SERVER['PHP_SELF']);?>"><?php echo $lstr['RunWizardAgainButton'];?></a></p>

<?php
	if($firsthost!="")
		$hoststatus_link=get_host_status_link($firsthost);
?>
	<p>
	Other Options:
	</p>
	<ul>
<?php
	if($firsthost!=""){
?>
	<li><a href="<?php echo $hoststatus_link;?>" target="_blank">View status details for <?php echo htmlentities($firsthost);?></a></li>
<?php
		}
?>
<?php
	if(is_admin()==true){
?>
	<li><a href="<?php echo get_base_url();?>admin/?xiwindow=coreconfigsnapshots.php" target="_top">View the latest configuration snapshots</a></li>
<?php
		}
?>
	</ul>
</div>

<div id="commanderrorcontent" style="visibility: hidden;">

	<div class="sectionTitle"><?php echo $lstr['MonitoringWizardCommitErrorSectionTitle'];?></div>
	
	<p><?php echo $lstr['MonitoringWizardCommitErrorNotes'];?></p>

	<p><a href="<?php echo htmlspecialchars($_SERVER['PHP_SELF']);?>"><?php echo $lstr['RunWizardAgainButton'];?></a></p>

<?php
	if(is_admin()==true){
?>
	<p><a href="<?php echo get_base_url();?>admin/?xiwindow=coreconfigsnapshots.php" target="_top">View the latest configuration snapshots</a></p>
<?php
		}
?>
</div>

<script type="text/javascript">

get_apply_config_result(<?php echo $id;?>);

function get_apply_config_result(command_id){

	$(this).everyTime(1 * 1000, "commandstatustimer", function(i) {
	
		$(".commandresultwaiting").append(".");

		var csdata=get_ajax_data("getcommandstatus",command_id);
		eval('var csobj='+csdata);
		if(csobj.status_code==2){
			if(csobj.result_code==0){
				$('.commandresultwaiting').each(function(){
					$(this).removeClass("commandresultwaiting");
					$(this).addClass("commandresultok");
					});
				$('#commandsuccesscontent').each(function(){
					$(this).css("visibility","visible");
					});
				$('ul.commandresult').append("<li class='commandresultok'>Configuration applied successfully.</li>");
				
				var optsarr = {
					"wizard": "<?php echo $wizard;?>",
					"request": <?php echo json_encode($request);?>,
					"result": 0
					};
				var opts=array2json(optsarr);		
				get_ajax_data("doconfigwizardinstallpostback",opts);
				
				}
			else{
				$('.commandresultwaiting').each(function(){
					$(this).removeClass("commandresultwaiting");
					$(this).addClass("commandresulterror");
					});
				$('#commandsuccesscontent').each(function(){
					$(this).css("display","none")
					});
				$('#commanderrorcontent').each(function(){
					$(this).css("visibility","visible")
					});
				$('ul.commandresult').append("<li class='commandresulterror'>Configuration verification failed.</li>");

				var optsarr = {
					"wizard": "<?php echo $wizard;?>",
					"request": <?php echo json_encode($request);?>,
					"result": 1
					};
				var opts=array2json(optsarr);		
				get_ajax_data("doconfigwizardinstallpostback",opts);
				
				}
			$(this).stopTime("commandstatustimer");
			}
		});
		
	}
</script>

	
	
<?php

	do_page_end(true);
	exit();
	}


function check_configwizard_object_perms($objects){

	foreach($objects as $oid => $obj){

		// checks perms on hosts and services
		switch($obj["type"]){
			case OBJECTTYPE_HOST:
				$hostname=$obj["host_name"];
				//echo "CHECKING HST: $hostname<BR>";
				if(host_exists($hostname)==true && is_authorized_to_configure_host(0,$hostname)==false)
					return false;
				break;
			case OBJECTTYPE_SERVICE:
				$hostname=$obj["host_name"];
				$servicename=$obj["service_description"];
				//echo "CHECKING SVC: $hostname/$servicename<BR>";
				if(service_exists($hostname,$servicename)==true && is_authorized_to_configure_service(0,$hostname,$servicename)==false)
					return false;					
				break;
			default:
				continue; // skip other objects
				break;
			}
		}
		
	//echo "CHECKED OUT OKAY!<BR>";
		
//	return false;

	return true;
	}
		

function show_commit_perms_error($error=false,$msg=""){
	global $configwizards;
	global $request;
	global $lstr;
	
	$wizard=grab_request_var("wizard","");
	
	// find the wizard
	$w=get_configwizard_by_name($wizard);
	$wt=$w[CONFIGWIZARD_DISPLAYTITLE];


	$wizard=grab_request_var("wizard","");
	
	// make config wizard callback
	$inargs=$request;
	$outargs=array();
	$result=0;
	$wo=make_configwizard_callback($wizard,CONFIGWIZARD_MODE_COMMITPERMSERROR,$inargs,$outargs,$result);
	
	do_page_start(array("page_title"=>$lstr['MonitoringWizardPermissionsErrorPageTitle']),true);
?>

	<h1><?php echo $wt." ".$lstr['MonitoringWizardPermissionsErrorPageHeader'];?></h1>
	

<?php
	display_message($error,false,$msg);
?>

	
	<div class="sectionTitle"><?php echo $lstr['MonitoringWizardPermissionsErrorSectionTitle'];?></div>
	
	<p><?php echo $lstr['MonitoringWizardPermissionsErrorNotes'];?></p>

	
<?php

	do_page_end(true);
	exit();
	}
?>