<?php
// NAGIOS CORE CGI PROXY
//
// Copyright (c) 2008-2009 Nagios Enterprises, LLC.  All rights reserved.
//  
// $Id: coreuiproxy.inc.php 273 2010-08-13 21:28:51Z egalstad $

require_once(dirname(__FILE__).'/../componenthelper.inc.php');

function coreui_do_proxy($c){
	global $cfg;
	global $request;

	// initialization stuff
	pre_init();

	// start session
	init_session();

	// grab GET or POST variables 
	grab_request_vars();

	// check prereqs
	check_prereqs();

	// check authentication
	check_authentication(false);
	
	// reports require a valid license for everyone
	$licensed_cgis=array("history.cgi","trends.cgi","avail.cgi","histogram.cgi","summary.cgi");
	if(in_array($c,$licensed_cgis)){
		licensed_feature_check(true,false);
		}
	// other cgis require a non-expired trial (overextended customers can still see them)
	else{
		licensed_feature_check(true,true);
		}

	$valid_cgis=array("status.cgi","extinfo.cgi","history.cgi","statusmap.cgi","trends.cgi","avail.cgi","extinfo.cgi","showlog.cgi","notifications.cgi","histogram.cgi","tac.cgi","cmd.cgi","config.cgi","summary.cgi","outages.cgi");
	
	// cgi must be valid - security reasons
	if(!in_array($c,$valid_cgis)){
		echo "INVALID CGI";
		exit();
		}
		
	// build query string
	$q="";
	foreach($request as $var => $val){
		$q.=$var."=".$val."&";
		}
	

	$cgi=$c;
	$query_string=$q;
	
	//$cgi="statusmap.cgi";
	//$query_string="host=all&createimage&time=1252882489&canvas_x=0&canvas_y=0&canvas_width=100&canvas_height=197&max_width=0&max_height=0&layout=5&layermode=exclude";

	if(isset($_SESSION["username"]))
		$username=$_SESSION["username"];
	else if(isset($request["uid"]))
		$username=get_user_attr($request["uid"],"username");
	else
		$username="UNKNOWN_USER";
	
	putenv("REQUEST_METHOD=GET");
	putenv("REMOTE_USER=".$username);
	putenv("QUERY_STRING=".$query_string);
	
	$binpath=$cfg['component_info']['nagioscore']['cgi_dir']."/$cgi";
	
	$rawoutput="";
	$fp=popen($binpath,"r");
	while(!feof($fp)){
        $rawoutput.=fread($fp,1024);
		}
	$returnval=pclose($fp);
	
	// separate HTTP headers from content
	$a=strpos($rawoutput,"Content-type:");
	$pos=strpos($rawoutput,"\r\n\r\n",$a);
	if($pos===false){
		$pos=strpos($rawoutput,"\n\n",$a);
		}
	$output="";
	$headers=substr($rawoutput,0,$pos);
	if($cgi=="trends.cgi")
		$output=substr($rawoutput,$pos+4); // hack
	else if($cgi=="histogram.cgi")
		$output=substr($rawoutput,$pos+4); // hack
	else if($cgi=="trends.cgi")
		$output=substr($rawoutput,$pos+4); // hack
	else
		$output=substr($rawoutput,$pos+2);
		
	
	// turn headers into array
	$headerarray=explode("\n",$headers);

	/*
	echo "USERNAME: $username;<BR>";
	echo "CGI: $cgi;<BR>";
	echo "QUERYSTRING: $query_string;<BR>";
	echo "RETURN VAL: $returnval<BR>";
	echo "HEADERS: $headers<BR>";
	echo "HEADER ARRAY: <BR>";
	print_r($headerarray);
	*/
	
	//output headers
	$contenttype="";
	foreach($headerarray as $h){
		$show=false;
		if(substr($h,"Content-type:")==true){
			$show=true;
			$contenttype=$h;
			}
		if($show==true)
			header($h);
		}
	
	// alter output
	$text=false;
	if(strstr($contenttype,"Content-type: text/html"))
		$text=true;
	if(strstr($contenttype,"Content-Type: text/html"))
		$text=true;
	else if($contenttype=="")
		$text=true;
	if($text==true){
	
		// uri path to component pieces
		$p=nagioscore_get_ui_url();
		
		// replace links to CGIs with their php equivalents
		$output=str_replace("avail.cgi",$p."avail.php",$output);
		$output=str_replace("cmd.cgi",$p."cmd.php",$output);
		$output=str_replace("config.cgi",$p."config.php",$output);
		$output=str_replace("extinfo.cgi",$p."extinfo.php",$output);
		$output=str_replace("histogram.cgi",$p."histogram.php",$output);
		$output=str_replace("history.cgi",$p."history.php",$output);
		$output=str_replace("notifications.cgi",$p."notifications.php",$output);
		$output=str_replace("outages.cgi",$p."outages.php",$output);
		$output=str_replace("showlog.cgi",$p."showlog.php",$output);
		$output=str_replace("status.cgi",$p."status.php",$output);
		$output=str_replace("statusmap.cgi",$p."statusmap.php",$output);
		$output=str_replace("summary.cgi",$p."summary.php",$output);
		$output=str_replace("tac.cgi",$p."tac.php",$output);
		$output=str_replace("trends.cgi",$p."trends.php",$output);
		
		$usecoreui=grab_request_var("usecoreui",0);
		
		// SESSION PROTECTION FOR CMD.CGI
		if($cgi=="cmd.cgi"){
		
			$output=str_replace("<TABLE CELLSPACING=0 CELLPADDING=0 CLASS='optBox'>","<input type='hidden' name='nsp' value='".get_nagios_session_protector_id()."'<TABLE CELLSPACING=0 CELLPADDING=0 CLASS='optBox'>",$output);
			}
		
		/////////////////////////////////////////
		// USE NEW UI FOR SOME SCREENS
		/////////////////////////////////////////
		$newui="../../xicore/status.php";
		if(!$usecoreui){

			// status cgi - lots of options to parse and redirect
			// do this before serice and host detail page replacements (extinfo.php) below
			$optsmatch="[a-zA-Z0-9 =&+.\:_-]*";
			$anchormatch="'|\"";
			$output=preg_replace_callback("/status.php\?(".$optsmatch.")('|\">)/","coreuiproxy_get_status_cgi_opts",$output);

			// service detail page
			$output=str_replace("extinfo.php?type=2&",$newui."?show=servicedetail&",$output);

			// host detail page
			$output=str_replace("extinfo.php?type=1&",$newui."?show=hostdetail&",$output);
			}

		
		// replace image paths
		$output=str_replace("/nagios/images/",$p."images/",$output);
		$output=str_replace("/nagios/stylesheets/",$p."css/",$output);
		
		// add javascript
		$s="<LINK REL='stylesheet' TYPE='text/css' HREF='".$p."css/common.css'>";
		$j="<script type='text/javascript' src='".$p."js/coreui.js'></script>\n";
		$output=str_replace($s,$j.$s,$output);
		}
		
	// output  body
	//echo "OUTPUT:<BR>";
	//echo "ABC";
	echo $output;
	
	//echo "RAW:<BR>";
	//echo $rawoutput;
	}
	
function coreuiproxy_get_status_cgi_opts($matches){
	//print_r($matches);
	
	$newui="../../xicore/status.php";
	$redirect_to_xi=false;

	// get the url options in an array so we can modify them easily
	$urlopts=array();
	$optsarr=explode("&",$matches[1]);
	foreach($optsarr as $oa){
		$optarr=explode("=",$oa);
		if(count($optarr)==1)
			$urlopts[$optarr[0]]="";
		else
			$urlopts[$optarr[0]]=$optarr[1];
		}
		
	// check for possible redirects to new ui
	$type=grab_array_var($urlopts,"type","");  // used in TAC CGI
	$style=grab_array_var($urlopts,"style","");
	$host=grab_array_var($urlopts,"host","");
	$hostgroup=grab_array_var($urlopts,"hostgroup","");
	$servicegroup=grab_array_var($urlopts,"servicegroup","");
	$hostprops=grab_array_var($urlopts,"hostprops","");
	$serviceprops=grab_array_var($urlopts,"serviceprops","");
	// service detail
	if($style=="detail"){
		$redirect_to_xi=true;
		$newurl=$newui."?show=services";
		unset($urlopts["style"]);
		}
	// host detail
	else if($style=="hostdetail"){
		$redirect_to_xi=true;
		$newurl=$newui."?show=hosts";
		unset($urlopts["style"]);
		}
	// hostgroup overview
	else if($style=="overview" && $hostgroup!=""){
		$redirect_to_xi=true;
		$newurl=$newui."?show=hostgroups";
		if($hostgroup=="all")
			unset($urlopts["hostgroup"]);
		}
	// servicegroup overview
	else if($style=="overview" && $servicegroup!=""){
		$redirect_to_xi=true;
		$newurl=$newui."?show=servicegroups";
		if($servicegroup=="all")
			unset($urlopts["servicegroup"]);
		}
	// single host status view - exception
	else if($host!=""){
		$redirect_to_xi=true;
		$newurl=$newui."?show=services";
		}
		
	// support for old URI tags
	unset($urlopts["hostprops"]);
	unset($urlopts["serviceprops"]);
	if($hostprops!="")
		$urlopts["hostattr"]=$hostprops;
	if($serviceprops!="")
		$urlopts["serviceattr"]=$serviceprops;
	
	// what should we go?
	if($redirect_to_xi==false){
		// OLD
		$newurl="status.php?notransform";
		}
	
	// add all options to the url
	foreach($urlopts as $var => $val)
		$newurl.="&".$var."=".$val;
		
	$newurl.=$matches[2];


	//$newurl=$newloc.$newopts.$matches[1].$matches[2];
	
	return $newurl;
	}
	
function coreui_get_raw_cgi_output($c,$args){
	global $request;
	global $cfg;

	// build query string
	$q="";
	foreach($args as $var => $val){
		$q.=$var."=".$val."&";
		}
	

	$cgi=$c;
	$query_string=$q;
	
	//$cgi="statusmap.cgi";
	//$query_string="host=all&createimage&time=1252882489&canvas_x=0&canvas_y=0&canvas_width=100&canvas_height=197&max_width=0&max_height=0&layout=5&layermode=exclude";

	if(isset($_SESSION["username"]))
		$username=$_SESSION["username"];
	else if(isset($request["uid"]))
		$username=get_user_attr($request["uid"],"username");
	else
		$username="UNKNOWN_USER";
	
	putenv("REQUEST_METHOD=GET");
	putenv("REMOTE_USER=".$username);
	putenv("QUERY_STRING=".$query_string);
	
	$binpath=$cfg['component_info']['nagioscore']['cgi_dir']."/$cgi";
	
	$rawoutput="";
	$fp=popen($binpath,"r");
	while(!feof($fp)){
        $rawoutput.=fread($fp,1024);
		}
	$returnval=pclose($fp);
	
	// separate HTTP headers from content
	$a=strpos($rawoutput,"Content-type:");
	$pos=strpos($rawoutput,"\r\n\r\n",$a);
	if($pos===false){
		$pos=strpos($rawoutput,"\n\n",$a);
		}
	$output="";
	$headers=substr($rawoutput,0,$pos);
	if($cgi=="trends.cgi")
		$output=substr($rawoutput,$pos+4); // hack
	else if($cgi=="histogram.cgi")
		$output=substr($rawoutput,$pos+4); // hack
	else if($cgi=="trends.cgi")
		$output=substr($rawoutput,$pos+4); // hack
	else
		$output=substr($rawoutput,$pos+2);
		
	
	// turn headers into array
	$headerarray=explode("\n",$headers);

	/*
	echo "USERNAME: $username;<BR>";
	echo "CGI: $cgi;<BR>";
	echo "QUERYSTRING: $query_string;<BR>";
	echo "RETURN VAL: $returnval<BR>";
	echo "HEADERS: $headers<BR>";
	echo "HEADER ARRAY: <BR>";
	print_r($headerarray);
	*/
	
			
	// output  body
	//echo "OUTPUT:<BR>";
	//echo "ABC";
	return $output;
	
	//echo "RAW:<BR>";
	//echo $rawoutput;
	}
	
	


function coreuiproxy_transform_status_cgi_opt($var,$val=""){

	$newvar=$var;
	$newval=$val;

	if($var=="serviceprops")
		$newvar="serviceattr";
	else if($var=="hostprops")
		$newvar="hostattr";
	
	//$newpair="{".$newvar."}={".$newval."}";
	$newpair="&".$newvar."=".$newval;

	return $newpair;
	}

	
function coreuiproxy_get_embedded_cgi_output($baseurl){
	global $request;

	$url=nagioscore_get_ui_url().$baseurl;
	
	// add backend ticket info to url
	$url.="&uid=".$_SESSION["user_id"];
	$url.="&ticket=".get_user_attr(0,"backend_ticket");
	
	//echo "FETCHING $url<BR>\n";
	
	$args=array(
		"cmd" => "geturlhtml",
		"url" => $url,
		);

	// add most request args
	foreach($request as $var => $val){
		if($var=="show")
			continue;
		if($var=="cmd" && $val=="getxicoreajax")  // needed for ajax calls - will this cause a problem with command CGI?
			continue;
		$args[$var]=$val;
		}
		
	//echo "ARGS:";
	//print_r($args);
	//echo "<BR><BR>";
	
	// have the backend fetch the CGIs using backend authentication (uid and ticket)
	$html=get_backend_data($args);
	
	return $html;
	}
?>