<?php
// NAGIOSQL COMPONENT
//
// Copyright (c) 2008-2009 Nagios Enterprises, LLC.  All rights reserved.
//  
// $Id: nagiosql.inc.php 585 2011-02-23 21:08:41Z egalstad $

require_once(dirname(__FILE__).'/../componenthelper.inc.php');


// run the initialization function
nagiosql_component_init();

////////////////////////////////////////////////////////////////////////
// COMPONENT INIT FUNCTIONS
////////////////////////////////////////////////////////////////////////

function nagiosql_component_init(){

	$name="nagiosql";
	
	$args=array(

		// need a name
		COMPONENT_NAME => $name,
		
		// informative information
		//COMPONENT_VERSION => "1.1",
		//COMPONENT_DATE => "11-27-2009",
		COMPONENT_TITLE => "NagiosQL Integration",
		COMPONENT_AUTHOR => "Nagios Enterprises, LLC",
		COMPONENT_DESCRIPTION => "Provides core integration with NagiosQL.",
		//COMPONENT_COPYRIGHT => "Copyright (c) 2009 Nagios Enterprises",
		//COMPONENT_HOMEPAGE => "http://www.nagios.com",
		
		// do not delete
		COMPONENT_PROTECTED => true,
		COMPONENT_TYPE => COMPONENT_TYPE_CORE,

		// configuration function (optional)
		//COMPONENT_CONFIGFUNCTION => "nagiosql_component_config_func",
		);
		
	register_component($name,$args);
	}
	


///////////////////////////////////////////////////////////////////////////////////////////
// URL FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////

// gets url used to access nagiosql
function nagiosql_get_base_url(){
	global $cfg;
	
	$url=$cfg['component_info']['nagiosql']['direct_url'];
	
	return $url;
	}
	

///////////////////////////////////////////////////////////////////////////////////////////
// PERMISSIONS FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////

function nagiosql_check_setuid_files(&$result,&$goodfiles,&$badfiles){

	$badfiles=array();
	$goodfiles=array();
	$result=true;

	// can't check perms if functions are missing...
	if(function_exists('posix_getpwuid')==false){
		return true;
		}

	$mainfiles=array(
		"reset_config_perms",
		"reset_config_perms.sh",
		);

	foreach($mainfiles as $mf){
		$f="/usr/local/nagiosxi/scripts/".$mf;
		
		//echo "CHECKING $f<BR>";
		
		// get perms
		$permsok=false;
		$fperms=fileperms($f);
		if( ($fperms & 0x0800) && ($fperms & 0x0040)){
			//echo "PERMS OK<BR>";
			$permsok=true;
			}
			
		// get owner
		$ownerok=false;
		//the fileowner function returns 0 if the owner is root, OR if the file doesn't exist at all
		//if the fileowner function fails, it will return a 0, and the posix function will return the root user info since it's uid=0
		$owner=posix_getpwuid(@fileowner($f)); 
		if($owner["name"]=="root" && file_exists($f)){
			//echo "OWNER OK (".$owner["name"].")<BR>";
			$ownerok=true;
			}
		
		if($permsok==false || $ownerok==false){
			$badfiles[]=$f;
			$result=false;
			}
		else{
			$goodfiles[]=$f;
			}
		}

	return $result;
	}

function nagiosql_check_file_perms(&$result,&$goodfiles,&$badfiles){

	$mainfiles=array(
		"commands",
		"contactgroups",
		"contacts",
		"contacttemplates",
		"hostdependencies",
		"hostescalations",
		"hostextinfo",
		"hostgroups",
		"hosttemplates",
		"servicedependencies",
		"serviceescalations",
		"serviceextinfo",
		"servicegroups",
		"servicetemplates",
		"timeperiods",
		);
		
	$badfiles=array();
	$goodfiles=array();
	$result=true;
		
	foreach($mainfiles as $mf){
		$f="/usr/local/nagios/etc/".$mf.".cfg";
		if(!is_writable($f)){
			$badfiles[]=$f;
			$result=false;
			}
		else{
			$goodfiles[]=$f;
			}
		}

	return $result;
	}
	
///////////////////////////////////////////////////////////////////////////////////////////
// USER FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////

function nagiosql_update_user_password($username,$password){
	global $db_tables;

	$sql="UPDATE ".$db_tables[DB_NAGIOSQL]["user"]." SET password=MD5('".escape_sql_param($password,DB_NAGIOSQL)."') WHERE username='".escape_sql_param($username,DB_NAGIOSQL)."'";
	//echo "SQL: $sql\n";
	//exit();
	if(!($rs=exec_sql_query(DB_NAGIOSQL,$sql)))
		return false;
		
	return true;
	}


///////////////////////////////////////////////////////////////////////////////////////////
// CONTACT FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////

function nagiosql_get_contact_id($contactname){
	global $db_tables;
	$sql="SELECT * FROM ".$db_tables[DB_NAGIOSQL]["contact"]." WHERE contact_name='".escape_sql_param($contactname,DB_NAGIOSQL)."'";
	//echo "SQL: $sql\n";
	if(($rs=exec_sql_query(DB_NAGIOSQL,$sql))){
		if(!$rs->EOF){
			return intval($rs->fields["id"]);
			}
		}
	return 0;
	}
	
function nagiosql_get_contact_record($contactname){
	global $db_tables;
	$sql="SELECT * FROM ".$db_tables[DB_NAGIOSQL]["contact"]." WHERE contact_name='".escape_sql_param($contactname,DB_NAGIOSQL)."'";
	//echo "SQL: $sql\n";
	if(($rs=exec_sql_query(DB_NAGIOSQL,$sql))){
		if(!$rs->EOF){
			return $rs->fields;
			}
		}
	return null;
	}
	
function nagiosql_update_contact($id,$args){
	global $db_tables;

	if($id<=0)
		return false;
		
	$set="";
	$x=0;
	foreach($args as $var => $val){
		if($x>0)
			$set.=",";
		$set.=$var."='".escape_sql_param($val,DB_NAGIOSQL)."'";
		$x++;
		}
		
	$sql="UPDATE ".$db_tables[DB_NAGIOSQL]["contact"]." SET ".$set." WHERE id='".escape_sql_param($id,DB_NAGIOSQL)."'";
	//echo "SQL: $sql\n";
	//exit();
	if(($rs=exec_sql_query(DB_NAGIOSQL,$sql))){
		if(!$rs->EOF){
			return intval($rs->fields["id"]);
			}
		}
		
	return true;
	}
	

function nagiosql_rename_contact($oldname,$newname){
	global $db_tables;
	
	$id=nagiosql_get_contact_id($oldname);
	if($id<=0)
		return 1;
	
	$sql="UPDATE ".$db_tables[DB_NAGIOSQL]["contact"]." SET contact_name='".escape_sql_param($newname,DB_NAGIOSQL)."' WHERE id='".escape_sql_param($id)."'";
	//echo "SQL: $sql\n";
	if(($rs=exec_sql_query(DB_NAGIOSQL,$sql))){
		if(!$rs->EOF){
			return intval($rs->fields["id"]);
			}
		}
	return 0;
	}
	
	

///////////////////////////////////////////////////////////////////////////////////////////
// TIMEPERIOD FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////

function nagiosql_get_timeperiod_id($timeperiodname){
	global $db_tables;
	$sql="SELECT * FROM ".$db_tables[DB_NAGIOSQL]["timeperiod"]." WHERE timeperiod_name='".escape_sql_param($timeperiodname,DB_NAGIOSQL)."'";
	//echo "SQL: $sql\n";
	if(($rs=exec_sql_query(DB_NAGIOSQL,$sql))){
		if(!$rs->EOF){
			return intval($rs->fields["id"]);
			}
		}
	return 0;
	}
	
	

function nagiosql_rename_timeperiod($oldname,$newname){
	global $db_tables;
	
	$id=nagiosql_get_timeperiod_id($oldname);
	if($id<=0)
		return 1;
	
	$sql="UPDATE ".$db_tables[DB_NAGIOSQL]["timeperiod"]." SET timeperiod_name='".escape_sql_param($newname,DB_NAGIOSQL)."' WHERE id='".escape_sql_param($id)."'";
	//echo "SQL: $sql\n";
	if(($rs=exec_sql_query(DB_NAGIOSQL,$sql))){
		if(!$rs->EOF){
			return intval($rs->fields["id"]);
			}
		}
	return 0;
	}
	
	

function nagiosql_update_timeperiod_times($id,$definition,$args){
	global $db_tables;

	if($id<=0)
		return false;
		
	$set="";
	$x=0;
	foreach($args as $var => $val){
		if($x>0)
			$set.=",";
		$set.=$var."='".escape_sql_param($val,DB_NAGIOSQL)."'";
		$x++;
		}
		
	$sql="UPDATE ".$db_tables[DB_NAGIOSQL]["timedefinition"]." SET ".$set." WHERE tipId='".escape_sql_param($id,DB_NAGIOSQL)."' AND definition='".escape_sql_param($definition,DB_NAGIOSQL)."'";
	//echo "SQL: $sql\n";
	//exit();
	if(($rs=exec_sql_query(DB_NAGIOSQL,$sql))){
		if(!$rs->EOF){
			return intval($rs->fields["id"]);
			}
		}
		
	return true;
	}

function nagiosql_get_weekday_name($day){
	$weekdays=nagiosql_get_weekday_names();
	return $weekdays[$day];
	}

function nagiosql_get_weekday_names(){
	$weekdays=array(
		0 => "sunday",
		1 => "monday",
		2 => "tuesday",
		3 => "wednesday",
		4 => "thursday",
		5 => "friday",
		6 => "saturday",
		);
	return $weekdays;
	}
	
	

///////////////////////////////////////////////////////////////////////////////////////////
// HOST FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////

function nagiosql_get_host_id($hostname){
	global $db_tables;
	
	$sql="SELECT * FROM ".$db_tables[DB_NAGIOSQL]["host"]." WHERE host_name='".escape_sql_param($hostname,DB_NAGIOSQL)."'";
	//echo "SQL: $sql\n";
	if(($rs=exec_sql_query(DB_NAGIOSQL,$sql))){
		if(!$rs->EOF){
			return intval($rs->fields["id"]);
			}
		}
	return 0;
	}
	
	
function nagiosql_host_is_in_dependency($hostname){
	global $db_tables;
	
	// get the host id
	$hostid=nagiosql_get_host_id($hostname,$hostname);
	if($hostid<=0)
		return false;
		
	// see if host is a master host in a dependency
	$sql="SELECT  * FROM ".$db_tables[DB_NAGIOSQL]["lnkHostdependencyToHost_H"]." WHERE idSlave='".escape_sql_param($hostid,DB_NAGIOSQL)."'";
	//echo "SQL: $sql\n";
	if(($rs=exec_sql_query(DB_NAGIOSQL,$sql))){
		if($rs->RecordCount()!=0)
			return true;
		}

	// see if host is a dependent host in a dependency
	$sql="SELECT  * FROM ".$db_tables[DB_NAGIOSQL]["lnkHostdependencyToHost_DH"]." WHERE idSlave='".escape_sql_param($hostid,DB_NAGIOSQL)."'";
	//echo "SQL: $sql\n";
	if(($rs=exec_sql_query(DB_NAGIOSQL,$sql))){
		if($rs->RecordCount()!=0)
			return true;
		}

	return false;
	}

function nagiosql_host_has_services($hostname){
	global $db_tables;
	
	// get the host id
	$hostid=nagiosql_get_host_id($hostname,$hostname);
	if($hostid<=0)
		return false;
		
	// see if host has services associated with it
	$sql="SELECT  * FROM ".$db_tables[DB_NAGIOSQL]["lnkServiceToHost"]." WHERE idSlave='".escape_sql_param($hostid,DB_NAGIOSQL)."'";
	//echo "SQL: $sql\n";
	if(($rs=exec_sql_query(DB_NAGIOSQL,$sql))){
		if($rs->RecordCount()!=0)
			return true;
		}

	return false;
	}

function nagiosql_host_is_related_to_other_hosts($hostname){
	global $db_tables;
	
	// get the host id
	$hostid=nagiosql_get_host_id($hostname,$hostname);
	if($hostid<=0)
		return false;
		
	// see if host is related to other hosts
	$sql="SELECT  * FROM ".$db_tables[DB_NAGIOSQL]["lnkHostToHost"]." WHERE idMaster='".escape_sql_param($hostid,DB_NAGIOSQL)."' OR  idSlave='".escape_sql_param($hostid,DB_NAGIOSQL)."'";
	//echo "SQL: $sql\n";
	if(($rs=exec_sql_query(DB_NAGIOSQL,$sql))){
		if($rs->RecordCount()!=0)
			return true;
		}

	return false;
	}


	
///////////////////////////////////////////////////////////////////////////////////////////
// SERVICE FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////

function nagiosql_get_service_id($hostname,$servicename){
	global $db_tables;
	
	// first get host id
	//$hostid=nagiosql_get_host_id($hostname);
	//if($hostid<=0)
		//return 0;

	$sql="SELECT 
".$db_tables[DB_NAGIOSQL]["lnkServiceToHost"].".idMaster as service_id,
".$db_tables[DB_NAGIOSQL]["host"].".id as host_id,
".$db_tables[DB_NAGIOSQL]["host"].".host_name as host_name,
".$db_tables[DB_NAGIOSQL]["service"].".service_description
FROM ".$db_tables[DB_NAGIOSQL]["service"]."
LEFT JOIN ".$db_tables[DB_NAGIOSQL]["lnkServiceToHost"]." ON ".$db_tables[DB_NAGIOSQL]["service"].".id=".$db_tables[DB_NAGIOSQL]["lnkServiceToHost"].".idMaster
LEFT JOIN ".$db_tables[DB_NAGIOSQL]["host"]." ON ".$db_tables[DB_NAGIOSQL]["lnkServiceToHost"].".idSlave=".$db_tables[DB_NAGIOSQL]["host"].".id
 WHERE ".$db_tables[DB_NAGIOSQL]["host"].".host_name='".escape_sql_param($hostname,DB_NAGIOSQL)."' AND ".$db_tables[DB_NAGIOSQL]["service"].".service_description='".escape_sql_param($servicename,DB_NAGIOSQL)."'";
		
	//echo "SQL: $sql\n";
	if(($rs=exec_sql_query(DB_NAGIOSQL,$sql))){
		if(!$rs->EOF){
			return intval($rs->fields["service_id"]);
			}
		}
	return 0;
	}
	
function nagiosql_is_service_unique($hostname,$servicename){
	global $db_tables;
	
	// get the service id
	$serviceid=nagiosql_get_service_id($hostname,$servicename);
	if($serviceid<=0)
		return false;
		
	// check flags in service definition to see if there are wildcards used for host or hostgroup
	$sql="SELECT  * FROM ".$db_tables[DB_NAGIOSQL]["lnkServiceToHostgroup"]." WHERE idMaster='".escape_sql_param($serviceid,DB_NAGIOSQL)."'";
	//echo "SQL: $sql\n";
	if(($rs=exec_sql_query(DB_NAGIOSQL,$sql))){
		if(!$rs->EOF){

			$host_flag=intval($rs->fields["host_name"]);
			$hostgroup_flag=intval($rs->fields["hostgroup_name"]);
			
			// service is associated with one or more ( or wildcard) hostgroups, so its not unique
			if($hostgroup_flag!=0)
				return false;
				
			// service is associated with no( or wildcard) hosts, so its probably not unique
			if($host_flag!=1)
				return false;
			}
		}
		
	// see if service is associated with multiple hosts (or no hosts)
	$sql="SELECT  * FROM ".$db_tables[DB_NAGIOSQL]["lnkServiceToHost"]." WHERE idMaster='".escape_sql_param($serviceid,DB_NAGIOSQL)."'";
	//echo "SQL: $sql\n";
	if(($rs=exec_sql_query(DB_NAGIOSQL,$sql))){
		if($rs->RecordCount()!=1)
			return false;
		}
	
	// next see if service is associated with one or more hostgroups
	// NOTE - already taken care of by checking hostgroup_flag above...
	/*
	$sql="SELECT  * FROM ".$db_tables[DB_NAGIOSQL]["lnkServiceToHostgroup"]." WHERE idMaster='".escape_sql_param($serviceid,DB_NAGIOSQL)."'";
	if(($rs=exec_sql_query(DB_NAGIOSQL,$sql))){
		if($rs->RecordCount()>0)
			return false;
		}
	*/
	
	return true;
	}

	
function nagiosql_service_is_in_dependency($hostname,$servicename){
	global $db_tables;
	
	// get the service id
	$serviceid=nagiosql_get_service_id($hostname,$servicename);
	if($serviceid<=0)
		return false;
		
	// see if service is a master service in a dependency
	$sql="SELECT  * FROM ".$db_tables[DB_NAGIOSQL]["lnkServicedependencyToService_S"]." WHERE idSlave='".escape_sql_param($serviceid,DB_NAGIOSQL)."'";
	//echo "SQL: $sql\n";
	if(($rs=exec_sql_query(DB_NAGIOSQL,$sql))){
		if($rs->RecordCount()!=0)
			return true;
		}

	// see if service is a dependent service in a dependency
	$sql="SELECT  * FROM ".$db_tables[DB_NAGIOSQL]["lnkServicedependencyToService_DS"]." WHERE idSlave='".escape_sql_param($serviceid,DB_NAGIOSQL)."'";
	//echo "SQL: $sql\n";
	if(($rs=exec_sql_query(DB_NAGIOSQL,$sql))){
		if($rs->RecordCount()!=0)
			return true;
		}

	return false;
	}
	


///////////////////////////////////////////////////////////////////////////////////////////
// CONFIG FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////

function nagiosql_read_host_config_from_file($hostname){

	$hostarr=array();
	$have_host=false;
	$in_host=false;

	$fname="/usr/local/nagios/etc/hosts/".$hostname.".cfg";
	
	$fh=fopen($fname,"r");
	if($fh){
		while(!feof($fh)){
			$buf=fgets($fh,4096);
			$buf=trim($buf);
			
			// skip blank lines and comments
			if(strstr($buf,'#')==$buf)
				continue;
			if($buf=="")
				continue;
			
			// start of host definition
			if(!strcmp($buf,"define host {")){
				$in_host=true;
				}
				
			// end of host definition
			else if(!strcmp($buf,"}") && $in_host==true){
			
				$in_host=false;
				
				$hn=grab_array_var($hostarr,"host_name");
				// we have the right host
				if(!strcmp($hn,$hostname)){
					$have_host=true;
					break;
					}
				// wrong host, so clear variables
				else{
					unset($hostarr);
					$hostarr=array();
					}
				}
				
			// inside a host definition
			else if($in_host==true){
				$parts=explode("\t",$buf);
				$var="";
				$val="";
				//print_r($parts);
				foreach($parts as $pid => $pname){
					//echo "PID $pid = $pname<BR>";
					if($pid==0)
						$var=$pname;
					else if($pname!="")
						$val=$pname;
					}
				$hostarr[$var]=$val;
				}
			}
		fclose($fh);
		}
	
	if($have_host==true)
		return $hostarr;
	else
		return null;
	}
	
function nagiosql_read_service_config_from_file($hostname,$servicename){

	$servicearr=array();
	$have_service=false;
	$in_service=false;

	$fname="/usr/local/nagios/etc/services/".$hostname.".cfg";
	
	//echo "FNAME: $fname<BR>";
	
	$fh=fopen($fname,"r");
	if($fh){
		while(!feof($fh)){
			$buf=fgets($fh,4096);
			$buf=trim($buf);
			
			// skip blank lines and comments
			if(strstr($buf,'#')==$buf)
				continue;
			if($buf=="")
				continue;
				
			//echo "BUF: $buf<BR>";
			
			// start of service definition
			if(!strcmp($buf,"define service {")){
				$in_service=true;
				}
				
			// end of service definition
			else if(!strcmp($buf,"}") && $in_service==true){
			
				$in_host=false;
				
				$hn=grab_array_var($servicearr,"host_name");
				$sd=grab_array_var($servicearr,"service_description");
				// we have the right service
				if(!strcmp($hn,$hostname) && !strcmp($sd,$servicename)){
					$have_service=true;
					break;
					}
				// wrong service, so clear variables
				else{
					unset($servicearr);
					$servicearr=array();
					}
				}
				
			// inside a service definition
			else if($in_service==true){
				$parts=explode("\t",$buf);
				$var="";
				$val="";
				//print_r($parts);
				foreach($parts as $pid => $pname){
					//echo "PID $pid = $pname<BR>";
					if($pid==0)
						$var=$pname;
					else if($pname!="")
						$val=$pname;
					}
				$servicearr[$var]=$val;
				}
			}
		fclose($fh);
		}
	
	if($have_service==true)
		return $servicearr;
	else
		return null;
	}
?>