<?php
//
// Copyright (c) 2008-2011 Nagios Enterprises, LLC.  All rights reserved.
// 
// IMPORTANT: SOURCE CODE MAY NOT BE DISCLOSED OR DISTRIBUTED IN UNENCODED FORM
//            WITHOUT EXPLICIT PERMISSION FROM NAGIOS ENTERPRISES, AS IT CONTAINS
//			  CODE LICENSED FROM THIRD PARTIES.
//  
// $Id: dbauth.inc.php 497 2011-01-21 16:07:46Z egalstad $

require_once(dirname(__FILE__).'/../config.inc.php');
require_once(dirname(__FILE__).'/utils.inc.php');


$cached_perms=array();

$use_performance_improvements=true;


////////////////////////////////////////////////////////////////////////
// AUTHORIZATION FUNCTIONS
////////////////////////////////////////////////////////////////////////

function get_authorized_instance_ids($args=null){
	global $sqlquery;
	global $db_tables;
	global $use_performance_improvements;

	if(is_null($args))
		$args=array();
		
	// initialize array of instances
	$auth_instances=array();
	
	///////////////////////////////////////////
	// TWEAK - THERE IS ONLY 1 INSTANCE!
	///////////////////////////////////////////
	//if($use_performance_improvements==true){
	if(1){
		$auth_instances[]=1;
		return $auth_instances;
		}
	
	

	// use current user
	if(!isset($args["uid"]))
		$args["uid"]=$_SESSION["user_id"];
		
	// default to READ permissions if none specified
	$required_perms=P_READ;
	if(isset($args["instanceauthperms"]))
		$required_perms=$args["instanceauthperms"];
		
		
	/////////////////////////////////////
	// ADMINS/OTHERS WHO CAN ACCESS EVERYTHING
	/////////////////////////////////////
	$see_all=false;
	// admins can see everything
	if(is_admin($args["uid"]))
		$see_all=true;
	// necessary so user can read process information
	if(is_authorized_for_monitoring_system($args["uid"])==true)
		$see_all=true;
	// some users are configured for access to all objects
	if(is_authorized_for_all_objects($args["uid"])==true)
		$see_all=true;
	if($see_all==true){

		$fieldmap=array(
			"instance_id" => $db_tables[DB_NDOUTILS]['instances'].".instance_id"
			);
			
		$limitopts=array();

		// limit by instance
		if(isset($args["instances"])){
			if(is_array($args["instances"])){
				$limitopts["instance_id"]="in:";
				$current_instance=0;
				foreach($args["instances"] as $instance){
					$current_instance++;
					if($current_instance>1)
						$limitopts["instance_id"].=",";
					$limitopts["instance_id"].=$instance;
					}
				}
			else if(have_value($args["instances"])){
				$limitopts["instance_id"]=$args["instances"];
				}
			}
		
		$args=array(
			"sql" => $sqlquery['GetInstances'],
			"fieldmap" => $fieldmap,
			"useropts" => $limitopts,
			"limitrecords" => false
			);
		$sql=generate_sql_query(DB_NDOUTILS,$args);
		if(($rs=exec_sql_query(DB_NDOUTILS,$sql,false))){
			while(!$rs->EOF){
				$auth_instances[]=$rs->fields["instance_id"];
				$rs->MoveNext();
				}
			}
		}
		
	/////////////////////////////////////
	// NORMAL USERS
	/////////////////////////////////////
	// limit what users can see...
	else{
		
		$instance_perms=get_cached_instance_perms($args["uid"]);
		if(is_array($instance_perms)){
			foreach($instance_perms as $instance_id => $perms){
				// if user has proper permissions, add this instance id
				if(($required_perms & $perms)==$required_perms){
					$auth_instances[]=$instance_id;
					}
				}
			}
		}
		
	return $auth_instances;
	}
	
	
function get_authorized_instances($perms=P_READ,$sortby="instance_name"){

	$instances=array();

	// get a list of instance ids
	$args=array(
		"instanceauthperms"=>$perms
		);
	$instance_ids=get_authorized_instance_ids($args);
	
	foreach($instance_ids as $instance_id){
		$instances[$instance_id]=array();
		$instances[$instance_id]["instance_id"]=$instance_id;
		$instances[$instance_id]["instance_name"]=get_instance_attr($instance_id,'instance_name');
		}
		
	return $instances;
	}


function get_authorized_object_ids($args=null){
	global $sqlquery;
	global $db_tables;
	
	if(is_null($args))
		$args=array();
		
	// initialize array of objects
	$auth_objects=array();

	// use current user
	if(!isset($args["uid"]))
		$args["uid"]=$_SESSION["user_id"];
		
	// default to read permissions if none specified
	if(isset($args["objectauthperms"]))
		$required_perms=$args["objectauthperms"];
	else
		$required_perms=P_READ;
		
	/////////////////////////////////////
	// ADMINS/OTHER WHO SEE EVERYTHING
	/////////////////////////////////////
	$see_all=false;
	// admins can see everything
	if(is_admin($args["uid"]))
		$see_all=true;
	// some users are configured for access to all objects
	if(is_authorized_for_all_objects($args["uid"])==true && $required_perms==P_READ){
		//echo "3-AUTHALLOBJECTS<BR>";
		$see_all=true;
		}
	// some users are configured for control of all objects
	if(is_authorized_for_all_object_commands($args["uid"])==true && $required_perms==P_EXECUTE){
		//echo "3-AUTHALLOBJECTCOMMANDS<BR>";
		$see_all=true;
		}
	if($see_all==true){
	
		// DEBUG
		/*
		$fh=fopen("/tmp/xiperms","w+");
		$line="UPDATED @ ".time()."\n";
		fputs($fh,$line);
		fclose($fh);
		*/
	
		$fieldmap=array(
			"objecttype_id" => $db_tables[DB_NDOUTILS]['objects'].".objecttype_id"
			);
			
		$limitopts=array();

		// limit by object type
		if(isset($args["objecttypes"])){
			if(is_array($args["objecttypes"])){
				$limitopts["objecttype_id"]="in:";
				$current_objecttype=0;
				foreach($args["objecttypes"] as $objecttype){
					$current_objecttype++;
					if($current_objecttype>1)
						$limitopts["objecttype_id"].=",";
					$limitopts["objecttype_id"].=$objecttype;
					}
				}
			else if(have_value($args["objecttypes"])){
				$limitopts["objecttype_id"]=$args["objecttypes"];
				}
			}
			
		$sql_args=array(
			"sql" => $sqlquery['GetObjects'],
			"fieldmap" => $fieldmap,
			"useropts" => $limitopts,
			"limitrecords" => false
			);
		$sql=generate_sql_query(DB_NDOUTILS,$sql_args);
		if(($rs=exec_sql_query(DB_NDOUTILS,$sql,false))){
			while(!$rs->EOF){
				$auth_objects[]=$rs->fields["object_id"];
				$rs->MoveNext();
				}
			}
		}
		
	/////////////////////////////////////
	// NORMAL USERS
	/////////////////////////////////////
	// limit what users can see...
	else{

		$object_perms=get_cached_object_perms($args["uid"]);
		if(is_array($object_perms)){
			foreach($object_perms as $instance => $instance_perms){
				if(is_array($instance_perms)){
					foreach($instance_perms as $instance_object_id => $instance_object_perms){
						// if user has proper permissions, add this object id
						if(($required_perms & $instance_object_perms)==$required_perms)
							$auth_objects[]=$instance_object_id;
							}
					}
				}
			}
		}

	return $auth_objects;
	}
	

////////////////////////////////////////////////////////////////////////
// SQL-LIMITING FUNCTIONS
////////////////////////////////////////////////////////////////////////

function limit_sql_by_authorized_instance_ids($args){
	global $cfg;

	// bail out if no sql
	if(!isset($args["sql"]))
		return "";

	$newsql=$args["sql"];

	// use current user
	if(!isset($args["uid"]))
		$args["uid"]=$_SESSION["user_id"];
		
	// admins can see everything, so don't limit query
	if(is_admin($args["uid"])){
		// no-op
		}
		
	// limit what users see...
	// only limit if there are instance auth fields
	if(isset($args["instanceauthfields"])){
	
		if(isset($args["instanceauthperms"]))
			$perms=$args["instanceauthperms"];
		else
			$perms=P_READ;

		// first get authorized list
		$auth_args=array(
			"uid" => $args["uid"],
			"instanceauthperms" => $perms,
			);
		$instance_ids=get_authorized_instance_ids($auth_args);
		
		// loop over each auth-limited instance field
		foreach($args["instanceauthfields"] as $limit_field){
		
			// lookup the auth-limited field name in the field map
			if(array_key_exists($limit_field,$args["fieldmap"]))
				$limit_field_name=$args["fieldmap"][$limit_field];
			else
				$limit_field_name=$limit_field;
		
			$newsql.=" AND ".$limit_field_name." IN (";
			// add each each authorized instance id to the IN statement
			$current_instance=0;
			foreach($instance_ids as $instance_id){
				$current_instance++;
				if($current_instance>1)
					$newsql.=",";
				$newsql.="'".$instance_id."'";
				}
			$newsql.=")";
			}
		}
		
	return $newsql;
	}


function limit_sql_by_authorized_object_ids($args){

	// bail out if no sql
	if(!isset($args["sql"]))
		return "";

	$newsql=$args["sql"];

	// use current user
	if(!isset($args["uid"]))
		$args["uid"]=$_SESSION["user_id"];
		
	// admins and others can see everything, so don't limit query
	//if(is_admin($args["uid"])){
	if(is_authorized_for_all_objects($args["uid"])){
		// no-op
		}
		
	// limit what users see...
	// only limit if there are object auth fields
	else if(isset($args["objectauthfields"])){
	
		$auth_args=array(
			"uid" => $args["uid"],
			"objectauthperms" => $args["objectauthperms"]
			);
		$object_ids=get_authorized_object_ids($auth_args);
		
		// loop over each auth-limited object field
		foreach($args["objectauthfields"] as $limit_field){
		
			// lookup the auth-limited field name in the field map
			if(array_key_exists($limit_field,$args["fieldmap"]))
				$limit_field_name=$args["fieldmap"][$limit_field];
			else
				$limit_field_name=$limit_field;
		
			$newsql.=" AND ".$limit_field_name." IN (";
			// add each each authorized object id to the IN statement
			$current_object=0;
			foreach($object_ids as $object_id){
				$current_object++;
				if($current_object>1)
					$newsql.=",";
				$newsql.="'".$object_id."'";
				}
			$newsql.=")";
			}
		}
		
	return $newsql;
	}


////////////////////////////////////////////////////////////////////////
// AUTH CHECK FUNCTIONS
////////////////////////////////////////////////////////////////////////

function is_instance_admin($instance_id,$uid=0){

	// use current user
	if($uid==0)
		$uid=$_SESSION["user_id"];
		
	// TODO

	return false;
	}
	
	
	

////////////////////////////////////////////////////////////////////////
// AUTH CHECK FUNCTIONS
////////////////////////////////////////////////////////////////////////

function get_effective_instance_perms($instance_id,$uid=0){

	$perms=P_NONE;

	// use current user
	if($uid==0)
		$uid=$_SESSION["user_id"];
		
	// make sure instance exists
	if(!instance_exists($instance_id))
		return P_NONE;
		
	// global admin
	if(is_admin($uid)){
		$perms=P_ALL;
		//echo "ADMIN -".$uid;
		}

	// instance admin
	else if(is_instance_admin($instance_id,$uid)){
		//echo "INSTANCE ADMIN";
		$perms=P_ALL;
		}

	// normal user
	else{
		//echo "USER";
		$instance_perms=get_cached_instance_perms($uid);
		if(is_array($instance_perms)){
			if(array_key_exists($instance_id,$instance_perms))
				$perms=$instance_perms[$instance_id];
			}
		}
		
	return $perms;
	}


function get_effective_object_perms($object_id,$uid=0){

	$perms=P_NONE;

	// use current user
	if($uid==0)
		$uid=$_SESSION["user_id"];
		
	// make sure object exists
	if(!object_exists($object_id))
		return P_NONE;
		
	// global admin
	if(is_admin($uid))
		$perms=P_ALL;
		
	// non-global admin
	else{

		// what instance does this object belong to?
		$instance_id=get_object_instance($object_id);
	
		// instance admin
		if(is_instance_admin($instance_id,$uid))
			$perms=P_ALL;

		// normal user
		else{
			$object_perms=get_cached_object_perms($uid);
			if(is_array($object_perms)){
				foreach($object_perms as $instance => $instance_object_perms){
					if(array_key_exists($object_id,$instance_object_perms))
						$perms=$instance_object_perms[$object_id];
					}
				}
			}
		}
		
	return $perms;
	}



function can_view_object($object_id,$uid=0){

	// use current user
	if($uid==0)
		$uid=$_SESSION["user_id"];

	$perms=get_effective_object_perms($object_id,$uid);
	if($perms & P_READ)
		return true;
	return false;
	}

function can_modify_object($object_id,$uid=0){

	// use current user
	if($uid==0)
		$uid=$_SESSION["user_id"];

	$perms=get_effective_object_perms($object_id,$uid);
	if($perms & P_WRITE)
		return true;
	}

function can_execute_object($object_id,$uid=0){

	// use current user
	if($uid==0)
		$uid=$_SESSION["user_id"];

	$perms=get_effective_object_perms($object_id,$uid);
	if($perms & P_EXECUTE)
		return true;
	}

function can_list_object($object_id,$uid=0){

	// use current user
	if($uid==0)
		$uid=$_SESSION["user_id"];

	$perms=get_effective_object_perms($object_id,$uid);
	if(($perms & P_READ) || ($perms & P_LIST))
		return true;
	return false;
	}

function can_admin_object($object_id,$uid=0){

	// use current user
	if($uid==0)
		$uid=$_SESSION["user_id"];

	$perms=get_effective_object_perms($object_id,$uid);
	if($perms & P_ADMIN)
		return true;
	}

function can_view_instance($instance_id,$uid=0){

	// use current user
	if($uid==0)
		$uid=$_SESSION["user_id"];

	$perms=get_effective_instance_perms($instance_id,$uid);
	if($perms & P_READ)
		return true;
	return false;
	}

function can_modify_instance($instance_id,$uid=0){

	// use current user
	if($uid==0)
		$uid=$_SESSION["user_id"];

	$perms=get_effective_instance_perms($instance_id,$uid);
	if($perms & P_WRITE)
		return true;
	return false;
	}

function can_execute_instance($instance_id,$uid=0){

	// use current user
	if($uid==0)
		$uid=$_SESSION["user_id"];

	$perms=get_effective_instance_perms($instance_id,$uid);
	if($perms & P_EXECUTE)
		return true;
	return false;
	}

function can_list_instance($instance_id,$uid=0){

	// use current user
	if($uid==0)
		$uid=$_SESSION["user_id"];

	$perms=get_effective_instance_perms($instance_id,$uid);
	if(($perms & P_READ) | ($perms & P_LIST))
		return true;
	return false;
	}

function can_admin_instance($instance_id,$uid=0){

	// use current user
	if($uid==0)
		$uid=$_SESSION["user_id"];

	$perms=get_effective_instance_perms($instance_id,$uid);
	if($perms & P_ADMIN)
		return true;
	return false;
	}


	
////////////////////////////////////////////////////////////////////////
// CACHING FUNCTIONS
////////////////////////////////////////////////////////////////////////

// NOTE: Only users who are not admins and are not authorized for all objects have their perms cached...
function get_cached_object_perms($uid=0){
	global $cached_perms;

	$current_user=false;
	
	// use current user
	if($uid==0){
		$current_user=true;
		$uid=$_SESSION["user_id"];
		}
		
	// potentially re-generate cached perms
	generate_cached_user_perms($uid);

	// use cached lookup
	if(isset($cached_perms["object_perms"]) && $current_user==true)
		return $cached_perms["object_perms"];
		
	// else do a db lookup 
	else{
		$object_perm_str=get_user_meta($uid,'cached_object_perms');
		$object_perms=unserialize($object_perm_str);
		if(is_array($object_perms)){
			// cache results
			if($current_user==true){
				$cached_perms["object_perms"]=$object_perms;
				}
			return $object_perms;
			}
		}

	return null;
	}

function get_cached_instance_perms($uid=0){
	global $cached_perms;

	$current_user=false;
	
	// use current user
	if($uid==0){
		$current_user=true;
		$uid=$_SESSION["user_id"];
		}

	// potentially re-generate cached perms
	generate_cached_user_perms($uid);

	// use cached lookup
	if(isset($cached_perms["instance_perms"]) && $current_user==true)
		return $cached_perms["instance_perms"];
		
	// else do a db lookup
	else{
		$instance_perm_str=get_user_meta($uid,'cached_instance_perms');
		//print_r($instance_perm_str);
		if($instance_perm_str==null || $instance_perm_str=="" || $instance_perm_str=="NULL")
			$instance_perms=array();
		else
			$instance_perms=unserialize($instance_perm_str);
		if(is_array($instance_perms)){
			//cache results
			if($current_user==true){
				$cached_perms["instance_perms"]=$instance_perms;
				}
			
			return $instance_perms;
			}
		}

	return null;
	}


function user_perm_recache_needed($uid=0){

	// use current user
	if($uid==0)
		$uid=$_SESSION["user_id"];
	if(!is_valid_user_id($uid))
		return;
		
	$now=time();

	// get last permissions update time
	/*
	$last_perm_update=get_user_meta($uid,'last_perm_update_time');
	if(!isset($last_perm_update))
		return true;
	*/
	$last_perm_update=0;
	
	// get last permissions cache time
	$last_cache_update=get_user_meta($uid,'last_perm_cache_time');
	if(!isset($last_cache_update))
		return true;
	
	// perms were updated after last cache, so we must recache...
	if($last_cache_update<$last_perm_update)
		return true;
		
	// update occassionally - is this really necessary?
	$seconds=180; // every  3 minutes
	if(($now-$last_cache_update)>$seconds)
		return true;

	return false;
	}


function generate_cached_user_perms($uid=0,$forced=false){
	global $DB;
	global $cfg;
	global $sqlquery;
	global $db_tables;
	global $cached_perms;
	
	// use current user
	if($uid==0)
		$uid=$_SESSION["user_id"];
	if(!is_valid_user_id($uid))
		return;

	$current_user=false;
	if($uid==0 || $uid==$_SESSION["user_id"])
		$current_user=true;

	// don't regenerate perms if we don't need to
	if($forced==false && (user_perm_recache_needed($uid))==false)
		return;
		
	$start_time=get_timer();
	
	
	///////////////////////////////////////////////////////////////////
	// initialize instance perms 
	///////////////////////////////////////////////////////////////////
	$s=get_user_meta($uid,'instance_perms');
	
	if($s==null || $s==""){
	
		$instance_perms=array();
		
		// grant all users read rights on instances for the time being...
		$dsa=get_instances();
		foreach($dsa as $dsid => $dsname){
			$instance_perms[$dsid]=P_READ;
			}		
		
		// make sure there is at least one (bogus) instance id for sql queries
		$instance_perms[-1]=P_READ;
		
		$s=serialize($instance_perms);
		set_user_meta($uid,'instance_perms',$s);
		}
			


	///////////////////////////////////////////////////////////////////
	// cache instance perms 
	///////////////////////////////////////////////////////////////////
	$s=get_user_meta($uid,'instance_perms');
	//echo "SERIAL INSTANCE PERMS: ".$s."<BR>\n";
	set_user_meta($uid,'cached_instance_perms',$s);
	$instance_perms=unserialize($s);
	if(!is_array($instance_perms))
		$instance_perms=array();

	// save cached instance perms in memory so we can skip a db-lookup later	
	if($current_user==true)
		$cached_perms["instance_perms"]=$instance_perms;

	
	///////////////////////////////////////////////////////////////////
	// determine initial object permissions from methods
	///////////////////////////////////////////////////////////////////
	/*
	$s=get_user_meta($uid,'object_perm_methods');
	//echo "SERIAL OBJECT PERM METHODS: ".$s."<BR>\n";
	$object_perm_methods=unserialize($s);
	if(!is_array($object_perm_methods)){
		$object_perm_methods=array();
		}
	*/
	// FOR NOW, JUST GRANT NAGIOS PERMISSION METHODS FOR ALL INSTANCES
	$dsa=get_instances();
	foreach($dsa as $dsid => $dsname){
		$object_perm_methods[$dsid]=PM_NAGIOS;
		}
	$s=serialize($object_perm_methods);
	set_user_meta($uid,'object_perm_methods',$s);
		
	/*
	echo "UID: ".$uid."<BR>\n";
	echo "INSTANCE PERMS:<BR>\n";
	print_r($instance_perms);
	echo "<BR>\n";
	echo "OBJECT PERM METHODS:<BR>\n";
	print_r($object_perm_methods);
	echo "<BR>\n";
	*/
	
	$object_id_perms=array();
	
	foreach($object_perm_methods as $instance => $pm){
	
		$instance_host_perms=array();
		$instance_service_perms=array();
		$instance_hostgroup_perms=array();
		$instance_servicegroup_perms=array();
	
		//echo "==============================<BR>\n";
		//echo "INSTANCE ".$instance." => ";
		
		switch($pm){
		
			///////////////////////////////////////////////////////////////////
			// FULL/ADMIN RIGHTS
			///////////////////////////////////////////////////////////////////
			case PM_RXL:
			case PM_ADMIN:
				//echo "RXL/ADMIN<BR>\n";
				
				$perm=P_NONE;
				if($pm==PM_ADMIN)
					$perm=P_READ|P_WRITE|P_EXECUTE|P_LIST|P_ADMIN;
				else if($pm==PM_RXL)
					$perm=P_READ|P_EXECUTE|P_LIST;
				
				// generate query
				$fieldmap=array(
					"instance_id" => $db_tables[DB_NDOUTILS]["objects"].".instance_id",
					"object_id" => $db_tables[DB_NDOUTILS]["objects"].".object_id",
					"objecttype_id" => $db_tables[DB_NDOUTILS]["objects"].".objecttype_id",
					);
				$limitopts=array(
					"instance_id" => $instance,
					"objecttype_id" => "in:".OBJECTTYPE_HOST.",".OBJECTTYPE_SERVICE.",".OBJECTTYPE_HOSTGROUP.",".OBJECTTYPE_HOST
					);
				$args=array(
					"sql" => $sqlquery['GetObjects'],
					"fieldmap" => $fieldmap,
					"useropts" => $limitopts,
					"limitrecords" => false
					);
				$sql=generate_sql_query(DB_NDOUTILS,$args);
				//echo "SQL: $sql<BR>\n";
				
				if(!($rs=$DB[DB_NDOUTILS]->Execute($sql,false)))
					break;
				else{
					while(!$rs->EOF){
						switch($rs->fields["objecttype_id"]){
							case OBJECTTYPE_HOST:
								$instance_host_perms[$rs->fields["object_id"]]=$perm;
								break;
							case OBJECTTYPE_HOSTGROUP:
								$instance_hostgroup_perms[$rs->fields["object_id"]]=$perm;
								break;
							case OBJECTTYPE_SERVICE:
								$instance_service_perms[$rs->fields["object_id"]]=$perm;
								break;
							case OBJECTTYPE_SERVICEGROUP:
								$instance_servicegroup_perms[$rs->fields["object_id"]]=$perm;
								break;
							default:
								break;
							}
						$rs->MoveNext();
						}
					}
				break;
				
			///////////////////////////////////////////////////////////////////
			// NAGIOS RIGHTS
			///////////////////////////////////////////////////////////////////
			case PM_NAGIOS:
				//echo "PM_NAGIOS<BR>\n";
				
				$perm=P_READ|P_EXECUTE|P_WRITE|P_LIST;

				//////////////////////////////////////////////////////////////////////
				// PREP WORK
				//////////////////////////////////////////////////////////////////////

				// find this user's corresponding Nagios contact id
				$limitopts=array(
					"instance_id" => $instance,
					"objecttype_id" => OBJECTTYPE_CONTACT,
					"name1" => get_user_attr($uid,"username")
					//"name1" => "nagiosadmin"
					);
				$contact_id=get_nagios_object_id($limitopts);
				//echo "CONTACT ID: ".$contact_id."<BR>\n";
				// this user is not a Nagios contact
				if($contact_id<=0)
					break;
					
				// get all contactgroups this contact belongs to
				$fieldmap=array(
					"instance_id" => $db_tables[DB_NDOUTILS]["instances"].".instance_id",
					"contactgroup_id" => $db_tables[DB_NDOUTILS]['contactgroups'].".contactgroup_object_id",
					"contactgroup_name" => "obj1.name1",
					"contactgroup_alias" => $db_tables[DB_NDOUTILS]['contactgroups'].".alias",
					"contact_id" => $db_tables[DB_NDOUTILS]['contacts'].".contact_object_id",
					"contact_name" => "obj2.name1"
					);
				$limitopts=array(
					"instance_id" => $instance,
					"contact_id" => $contact_id
					);
				$args=array(
					"sql" => $sqlquery['GetContactGroupMemberships'],
					"fieldmap" => $fieldmap,
					"useropts" => $limitopts,
					"limitrecords" => false
					);
				$sql=generate_sql_query(DB_NDOUTILS,$args);
				//echo "GETCONTACTGROUPMEMBERSHIPS SQL: ".$sql."<BR>\n";
				$contactgroup_ids=array();
				$contactgroup_object_ids=array();
				if(($rs=$DB[DB_NDOUTILS]->Execute($sql,false))){
					while(!$rs->EOF){
						$contactgroup_ids[]=$rs->fields["contactgroup_id"];
						$contactgroup_object_ids[]=$rs->fields["contactgroup_object_id"];
						$rs->MoveNext();
						}
					}
					
				/*
				echo "CONTACT GROUP IDS:<BR>\n";
				print_r($contactgroup_ids);
				echo "<BR>\n";
				echo "CONTACT GROUP OBJECT IDS:<BR>\n";
				print_r($contactgroup_object_ids);
				echo "<BR>\n";
				*/
				
				// generate contactgroup query
				$contactgroup_id_query="in:";
				$record=0;
				foreach($contactgroup_object_ids as $cgid){
					$record++;
					if($record>1)
						$contactgroup_id_query.=",";
					$contactgroup_id_query.=$cgid;
					}
				//echo "CONTACT GROUP ID QUERY: ".$contactgroup_id_query."<BR>\n";
				
				//////////////////////////////////////////////////////////////////////
				// HOST CONTACT GROUPS
				//////////////////////////////////////////////////////////////////////
				$fieldmap=array(
					"host_id" => $db_tables[DB_NDOUTILS]['hosts'].".host_object_id",
					"instance_id" => $db_tables[DB_NDOUTILS]['hosts'].".instance_id",
					"contactgroup_id" => $db_tables[DB_NDOUTILS]['host_contactgroups'].".contactgroup_object_id"
					);
				$limitopts=array(
					"instance_id" => $instance,
					"contactgroup_id" => $contactgroup_id_query
					);
				$args=array(
					"sql" => $sqlquery['GetHostContactGroups'],
					"fieldmap" => $fieldmap,
					"useropts" => $limitopts,
					"limitrecords" => false
					);
				$sql=generate_sql_query(DB_NDOUTILS,$args);
				//echo "SQL: ".$sql."<BR>\n";
				if(($rs=$DB[DB_NDOUTILS]->Execute($sql,false))){
					while(!$rs->EOF){
						$instance_host_perms[$rs->fields["host_object_id"]]=$perm;
						$rs->MoveNext();
						}
					}

				/*
				echo "HOST PERMS [CG] (".count($instance_host_perms)."):<BR>\n";
				print_r($instance_host_perms);
				echo "<BR>\n";
				*/

				
				//////////////////////////////////////////////////////////////////////
				// HOST CONTACTS
				//////////////////////////////////////////////////////////////////////
				$fieldmap=array(
					"host_id" => $db_tables[DB_NDOUTILS]['hosts'].".host_object_id",
					"instance_id" => $db_tables[DB_NDOUTILS]['hosts'].".instance_id",
					"contact_id" => $db_tables[DB_NDOUTILS]['host_contacts'].".contact_object_id"
					);
				$limitopts=array(
					"instance_id" => $instance,
					"contact_id" => $contact_id
					);
				$args=array(
					"sql" => $sqlquery['GetHostContacts'],
					"fieldmap" => $fieldmap,
					"useropts" => $limitopts,
					"limitrecords" => false
					);
				$sql=generate_sql_query(DB_NDOUTILS,$args);
				//echo "SQL: ".$sql."<BR>\n";
				if(($rs=$DB[DB_NDOUTILS]->Execute($sql,false))){
					while(!$rs->EOF){
						$instance_host_perms[$rs->fields["host_object_id"]]=$perm;
						$rs->MoveNext();
						}
					}

				/*
				echo "HOST PERMS [C] (".count($instance_host_perms)."):<BR>\n";
				print_r($instance_host_perms);
				echo "<BR>\n";
				*/

				//////////////////////////////////////////////////////////////////////
				// HOST ESCALATION CONTACT GROUPS
				//////////////////////////////////////////////////////////////////////
				$fieldmap=array(
					"host_id" => $db_tables[DB_NDOUTILS]['hostescalations'].".host_object_id",
					"instance_id" => $db_tables[DB_NDOUTILS]['hostescalations'].".instance_id",
					"contactgroup_id" => $db_tables[DB_NDOUTILS]['hostescalation_contactgroups'].".contactgroup_object_id"
					);
				$limitopts=array(
					"instance_id" => $instance,
					"contactgroup_id" => $contactgroup_id_query
					);
				$args=array(
					"sql" => $sqlquery['GetHostEscalationContactGroups'],
					"fieldmap" => $fieldmap,
					"useropts" => $limitopts,
					"limitrecords" => false
					);
				$sql=generate_sql_query(DB_NDOUTILS,$args);
				//echo "SQL: ".$sql."<BR>\n";
				if(($rs=$DB[DB_NDOUTILS]->Execute($sql,false))){
					while(!$rs->EOF){
						$instance_host_perms[$rs->fields["host_object_id"]]=$perm;
						$rs->MoveNext();
						}
					}

				/*
				echo "HOST PERMS [ESCALATION CG] (".count($instance_host_perms)."):<BR>\n";
				print_r($instance_host_perms);
				echo "<BR>\n";
				*/

				//////////////////////////////////////////////////////////////////////
				// HOST ESCALATION CONTACTS
				//////////////////////////////////////////////////////////////////////
				$fieldmap=array(
					"host_id" => $db_tables[DB_NDOUTILS]['hostescalations'].".host_object_id",
					"instance_id" => $db_tables[DB_NDOUTILS]['hostescalations'].".instance_id",
					"contact_id" => $db_tables[DB_NDOUTILS]['hostescalation_contacts'].".contact_object_id"
					);
				$limitopts=array(
					"instance_id" => $instance,
					"contact_id" => $contact_id
					);
				$args=array(
					"sql" => $sqlquery['GetHostEscalationContacts'],
					"fieldmap" => $fieldmap,
					"useropts" => $limitopts,
					"limitrecords" => false
					);
				$sql=generate_sql_query(DB_NDOUTILS,$args);
				//echo "SQL: ".$sql."<BR>\n";
				if(($rs=$DB[DB_NDOUTILS]->Execute($sql,false))){
					while(!$rs->EOF){
						$instance_host_perms[$rs->fields["host_object_id"]]=$perm;
						$rs->MoveNext();
						}
					}
					
				/*
				echo "HOST PERMS [HOST ESCALATION C] (".count($instance_host_perms)."):<BR>\n";
				print_r($instance_host_perms);
				echo "<BR>\n";
				*/

				//////////////////////////////////////////////////////////////////////
				// DETERMINE HOSTGROUP PERMISSIONS
				//////////////////////////////////////////////////////////////////////
				// generate host query
				$host_id_query="in:";
				$record=0;
				foreach($instance_host_perms as $oid => $op){
					$record++;
					if($record>1)
						$host_id_query.=",";
					$host_id_query.=$oid;
					}
				//echo "HOST ID QUERY: ".$host_id_query."<BR>\n";

				$fieldmap=array(
					"instance_id" => $db_tables[DB_NDOUTILS]['hostgroups'].".instance_id",
					"hostgroup_id" => $db_tables[DB_NDOUTILS]['hostgroups'].".hostgroup_object_id",
					"host_id" => $db_tables[DB_NDOUTILS]['hostgroup_members'].".host_object_id",
					);
				$limitopts=array(
					"instance_id" => $instance,
					"host_id" => $host_id_query
					);
				$args=array(
					"sql" => $sqlquery['GetHostGroupMembers'],
					"fieldmap" => $fieldmap,
					"useropts" => $limitopts,
					"limitrecords" => false
					);
				$sql=generate_sql_query(DB_NDOUTILS,$args);
				//echo "SQL: ".$sql."<BR>\n";
				if(($rs=$DB[DB_NDOUTILS]->Execute($sql,false))){
					while(!$rs->EOF){
						$instance_hostgroup_perms[$rs->fields["hostgroup_object_id"]]=$perm;
						$rs->MoveNext();
						}
					}

				/*
				echo "HOSTGROUP PERMS [HOSTGROUPS] (".count($instance_hostgroup_perms)."):<BR>\n";
				print_r($instance_hostgroup_perms);
				echo "<BR>\n";
				*/


				//////////////////////////////////////////////////////////////////////
				// SERVICES ON ALREADY AUTHORIZED HOSTS
				//////////////////////////////////////////////////////////////////////
				$fieldmap=array(
					"service_id" => $db_tables[DB_NDOUTILS]['services'].".service_object_id",
					"host_id" => $db_tables[DB_NDOUTILS]['services'].".host_object_id",
					"instance_id" => $db_tables[DB_NDOUTILS]['services'].".instance_id",
					);
				$limitopts=array(
					"instance_id" => $instance,
					"host_id" => $host_id_query
					);
				$args=array(
					"sql" => $sqlquery['GetServices'],
					"fieldmap" => $fieldmap,
					"useropts" => $limitopts,
					"limitrecords" => false
					);
				$sql=generate_sql_query(DB_NDOUTILS,$args);
				//echo "SQL: ".$sql."<BR>\n";
				if(($rs=$DB[DB_NDOUTILS]->Execute($sql,false))){
					while(!$rs->EOF){
						$instance_service_perms[$rs->fields["service_object_id"]]=$perm;
						$rs->MoveNext();
						}
					}

				/*
				echo "SERVICE PERMS [HOSTS] (".count($instance_service_perms)."):<BR>\n";
				print_r($instance_service_perms);
				echo "<BR>\n";
				*/

				
				//////////////////////////////////////////////////////////////////////
				// SERVICE CONTACT GROUPS
				//////////////////////////////////////////////////////////////////////
				$fieldmap=array(
					"service_id" => $db_tables[DB_NDOUTILS]['services'].".service_object_id",
					"instance_id" => $db_tables[DB_NDOUTILS]['services'].".instance_id",
					"contactgroup_id" => $db_tables[DB_NDOUTILS]['service_contactgroups'].".contactgroup_object_id"
					);
				$limitopts=array(
					"instance_id" => $instance,
					"contactgroup_id" => $contactgroup_id_query
					);
				$args=array(
					"sql" => $sqlquery['GetServiceContactGroups'],
					"fieldmap" => $fieldmap,
					"useropts" => $limitopts,
					"limitrecords" => false
					);
				$sql=generate_sql_query(DB_NDOUTILS,$args);
				//echo "SQL: ".$sql."<BR>\n";
				if(($rs=$DB[DB_NDOUTILS]->Execute($sql,false))){
					while(!$rs->EOF){
						$instance_service_perms[$rs->fields["service_object_id"]]=$perm;
						$rs->MoveNext();
						}
					}

				/*
				echo "SERVICE PERMS [CG] (".count($instance_service_perms)."):<BR>\n";
				print_r($instance_service_perms);
				echo "<BR>\n";
				*/
				
				//////////////////////////////////////////////////////////////////////
				// SERVICE CONTACTS
				//////////////////////////////////////////////////////////////////////
				$fieldmap=array(
					"service_id" => $db_tables[DB_NDOUTILS]['services'].".service_object_id",
					"instance_id" => $db_tables[DB_NDOUTILS]['services'].".instance_id",
					"contact_id" => $db_tables[DB_NDOUTILS]['service_contacts'].".contact_object_id"
					);
				$limitopts=array(
					"instance_id" => $instance,
					"contact_id" => $contact_id
					);
				$args=array(
					"sql" => $sqlquery['GetServiceContacts'],
					"fieldmap" => $fieldmap,
					"useropts" => $limitopts,
					"limitrecords" => false
					);
				$sql=generate_sql_query(DB_NDOUTILS,$args);
				//echo "SQL: ".$sql."<BR>\n";
				if(($rs=$DB[DB_NDOUTILS]->Execute($sql,false))){
					while(!$rs->EOF){
						$instance_service_perms[$rs->fields["service_object_id"]]=$perm;
						$rs->MoveNext();
						}
					}

				/*
				echo "SERVICE PERMS [C] (".count($instance_service_perms)."):<BR>\n";
				print_r($instance_service_perms);
				echo "<BR>\n";
				*/
				
				//////////////////////////////////////////////////////////////////////
				// SERVICE ESCALATION CONTACT GROUPS
				//////////////////////////////////////////////////////////////////////
				$fieldmap=array(
					"service_id" => $db_tables[DB_NDOUTILS]['serviceescalations'].".service_object_id",
					"instance_id" => $db_tables[DB_NDOUTILS]['serviceescalations'].".instance_id",
					"contactgroup_id" => $db_tables[DB_NDOUTILS]['serviceescalation_contactgroups'].".contactgroup_object_id"
					);
				$limitopts=array(
					"instance_id" => $instance,
					"contactgroup_id" => $contactgroup_id_query
					);
				$args=array(
					"sql" => $sqlquery['GetServiceEscalationContactGroups'],
					"fieldmap" => $fieldmap,
					"useropts" => $limitopts,
					"limitrecords" => false
					);
				$sql=generate_sql_query(DB_NDOUTILS,$args);
				//echo "SQL: ".$sql."<BR>\n";
				if(($rs=$DB[DB_NDOUTILS]->Execute($sql,false))){
					while(!$rs->EOF){
						$instance_service_perms[$rs->fields["service_object_id"]]=$perm;
						$rs->MoveNext();
						}
					}

				/*
				echo "SERVICE PERMS [ESCALATION CG] (".count($instance_service_perms)."):<BR>\n";
				print_r($instance_service_perms);
				echo "<BR>\n";
				*/

				//////////////////////////////////////////////////////////////////////
				// SERVICE ESCALATION CONTACTS
				//////////////////////////////////////////////////////////////////////
				$fieldmap=array(
					"service_id" => $db_tables[DB_NDOUTILS]['serviceescalations'].".service_object_id",
					"instance_id" => $db_tables[DB_NDOUTILS]['serviceescalations'].".instance_id",
					"contact_id" => $db_tables[DB_NDOUTILS]['serviceescalation_contacts'].".contact_object_id"
					);
				$limitopts=array(
					"instance_id" => $instance,
					"contact_id" => $contact_id
					);
				$args=array(
					"sql" => $sqlquery['GetServiceEscalationContacts'],
					"fieldmap" => $fieldmap,
					"useropts" => $limitopts,
					"limitrecords" => false
					);
				$sql=generate_sql_query(DB_NDOUTILS,$args);
				//echo "SQL: ".$sql."<BR>\n";
				if(($rs=$DB[DB_NDOUTILS]->Execute($sql,false))){
					while(!$rs->EOF){
						$instance_service_perms[$rs->fields["service_object_id"]]=$perm;
						$rs->MoveNext();
						}
					}

				/*
				echo "SERVICE PERMS [ESCALATION C] (".count($instance_service_perms)."):<BR>\n";
				print_r($instance_service_perms);
				echo "<BR>\n";
				*/
				

				//////////////////////////////////////////////////////////////////////
				// DETERMINE SERVICEGROUP PERMISSIONS
				//////////////////////////////////////////////////////////////////////
				// generate service query
				$service_id_query="in:";
				$record=0;
				foreach($instance_service_perms as $oid => $op){
					$record++;
					if($record>1)
						$service_id_query.=",";
					$service_id_query.=$oid;
					}
				//echo "SERVICE ID QUERY: ".$service_id_query."<BR>\n";

				$fieldmap=array(
					"instance_id" => $db_tables[DB_NDOUTILS]['servicegroups'].".instance_id",
					"servicegroup_id" => $db_tables[DB_NDOUTILS]['servicegroups'].".servicegroup_object_id",
					"service_id" => $db_tables[DB_NDOUTILS]['servicegroup_members'].".service_object_id",
					);
				$limitopts=array(
					"instance_id" => $instance,
					"service_id" => $service_id_query
					);
				$args=array(
					"sql" => $sqlquery['GetServiceGroupMembers'],
					"fieldmap" => $fieldmap,
					"useropts" => $limitopts,
					"limitrecords" => false
					);
				$sql=generate_sql_query(DB_NDOUTILS,$args);
				//echo "SQL: ".$sql."<BR>\n";
				if(($rs=$DB[DB_NDOUTILS]->Execute($sql,false))){
					while(!$rs->EOF){
						$instance_servicegroup_perms[$rs->fields["servicegroup_object_id"]]=$perm;
						$rs->MoveNext();
						}
					}

				/*
				echo "SERVICEGROUP PERMS [SERVICEGROUPS] (".count($instance_servicegroup_perms)."):<BR>\n";
				print_r($instance_servicegroup_perms);
				echo "<BR>\n";
				*/


				break;

			///////////////////////////////////////////////////////////////////
			// AS-OF-YET UNSUPPORT INSTANCE OBJECT PERM METHOD
			///////////////////////////////////////////////////////////////////
			default:
				//echo "NON/OTHER<BR>\n";
				break;
			}
			
		// save the perms for objects in this instance
		foreach($instance_host_perms as $oid => $op)
			$object_id_perms[$instance][$oid]=$op;
		foreach($instance_hostgroup_perms as $oid => $op)
			$object_id_perms[$instance][$oid]=$op;
		foreach($instance_service_perms as $oid => $op)
			$object_id_perms[$instance][$oid]=$op;
		foreach($instance_servicegroup_perms as $oid => $op)
			$object_id_perms[$instance][$oid]=$op;
			
		// make sure there is at least one object id...
		$object_id_perms[$instance][-1]=$perm;

		//echo "==============================<BR>\n";
		//echo "==============================<BR>\n";
		//echo "INSTANCE OBJECT ID PERMS (".count($object_id_perms[$instance])."):<BR>\n";
		//print_r($object_id_perms[$instance]);
		//echo "<BR>\n";
		
		/*
		echo "HOSTS: ".count($instance_host_perms)."<BR>\n";
		echo "HOSTGROUPS: ".count($instance_hostgroup_perms)."<BR>\n";
		echo "SERVICES: ".count($instance_service_perms)."<BR>\n";
		echo "SERVICEGROUPS: ".count($instance_servicegroup_perms)."<BR>\n";
		*/
		}
	

	///////////////////////////////////////////////////////////////////
	// apply custom object perms
	///////////////////////////////////////////////////////////////////

	/* FUTURE IMPLEMENTATION - CUSTOM PERMS SHOULD REPLACE AUTO-DETERMINED PERMS WHEN COLLISIONS OCCUR....*/
	
	///////////////////////////////////////////////////////////////////
	// cache object perms
	///////////////////////////////////////////////////////////////////
	//$object_perms=array();
	//$object_id_perms[0]=$object_id_perms[1];
	//unset($object_id_perms[1]);
	//$object_perms=$object_id_perms;
	//$s=serialize($object_perms);
	$s=serialize($object_id_perms);
	set_user_meta($uid,'cached_object_perms',$s);
	//echo "SERIAL OBJECT ID PERMS: ".$s."<BR>\n";

	// save cached object perms in memory so we can skip a db-lookup later	
	if($current_user==true)
		$cached_perms["object_perms"]=$object_id_perms;

	// record last permissions cache time
	$now=time();
	set_user_meta($uid,'last_perm_cache_time',$now);
	
	$end_time=get_timer();
	$total_time=get_timer_diff($start_time,$end_time);
	//echo "TIME: ".$total_time." sec<BR>\n";
	
	//exit();
	}
	


////////////////////////////////////////////////////////////////////////
// MISC FUNCTIONS
////////////////////////////////////////////////////////////////////////

function get_perm_string($perms){

	$out="";
	
	if($perms & P_READ)
		$out.="R";
	if($perms & P_WRITE)
		$out.="W";
	if($perms & P_EXECUTE)
		$out.="X";
	if($perms & P_LIST)
		$out.="L";
	if($perms & P_ADMIN)
		$out.="A";
		
	if($perms==P_NONE)
		$out="N";
	
	return $out;
	}


	


?>