<?php
//
// Copyright (c) 2008-2009 Nagios Enterprises, LLC.  All rights reserved.
//
// Development Started 03/22/2008
// $Id: utils-backend.inc.php 644 2011-05-03 22:04:17Z mguthrie $

//require_once(dirname(__FILE__).'/common.inc.php');

////////////////////////////////////////////////////////////////////////
// BACKEND FUNCTIONS
////////////////////////////////////////////////////////////////////////


function get_backend_xml_data($args){

	//$t1=get_timer();

	// get raw xml result from backend
	$r=get_backend_data($args,true);
	if($r==null)
		return null;
	
	//$t2=get_timer();

	// load the backend results in an xml object
	$x=simplexml_load_string($r);
	if($x==null)
		return null;
		
	//$t3=get_timer();
	
	//echo "BACKEND TIMES: FETCH=".get_timer_diff($t1,$t2).", LOAD=".get_timer_diff($t2,$t3)."<BR>";

	return $x;
	}

	
function get_backend_data($args,$internal_call=true){


	$raw_result=get_raw_backend_data($args,$internal_call);
	
//	echo "ARGS: $args<BR>";
//	echo "RAW: $raw_result<BR>";
//	return $raw_result;

	if($raw_result["info"]["http_code"]==200 || $raw_result["info"]["http_code"]==302)
		$result=$raw_result["body"];
	else
		$result=null;
	
	return $result;
	}

function get_raw_backend_data($args,$internal_call=true){
	global $cfg;
	

	// get user's backend ticket info
	$uid=$_SESSION["user_id"];
	
	// admins can request another user's info
	if(is_admin() && isset($args["uid"]))
		$uid=$args["uid"];
		
	// we are running as a subsystem cron job
	if(defined("SUBSYSTEM")==true){
	
		// subsystem can override user info
		if(isset($args["uid"]))
			$uid=$args["uid"];
			
		// add subsystem ticket info to args
		$args["subsystem"]=get_subsystem_ticket();
		}
		
	// get the user's backend ticket
	$backend_ticket=get_user_attr($uid,"backend_ticket");
	
	// add backend ticket info to args
	$args["uid"]=$uid;
	$args["ticket"]=$backend_ticket;
	
	//echo "BACKEND ARGS:\n";
	//print_r($args);

	// determine base url to access backend
	$base_url=get_backend_url($internal_call);

	// build url from array of arguments
	$theurl=$base_url."?".http_build_query($args);
	
	//echo "<BR>BACKEND URL: $theurl<BR>\n";
	
	$options = array(
		'return_info'	=> true,
		'method'	=> 'post'
		);
		
	// fetch the url
	//$t1=get_timer();
	$result=load_url($theurl,$options);
	//$t2=get_timer();
	//echo "LOAD URL TIME: FETCH=".get_timer_diff($t1,$t2)."<BR>";
	
	return $result;
	}
	
function get_backend_url($internal_call=false){
	global $cfg;

	// determine base url to access backend
	$url="";
	
	// a function is executing on the server, so use localhost...
	if($internal_call==true){
//		$url="http://";   //CANNOT BE HARDCODED http 
		if(isset($_SERVER["HTTPS"]) && $_SERVER["HTTPS"]=="on") $proto="https";
		else $proto = "http"; 
		$url .= $proto.'://'; 
		
		// add credentials if basic authentication is enabled
			$ba=grab_array_var($cfg,'use_basic_authentication');
			if($ba==true){
				$url.=$cfg['subsystem_basic_auth_username'];
				$url.=":";
				$url.=$cfg['subsystem_basic_auth_password'];
				$url.="@";
				}
		
	//	$url.="localhost";		//hardcoded localhost breaks strict SSL 
		$url .= $_SERVER['SERVER_ADDR'];    
		if(($proto=="http" && $_SERVER["SERVER_PORT"]!="80") || ($proto=="https" && $_SERVER["SERVER_PORT"]!="443")) {
			$port=":".$_SERVER["SERVER_PORT"];
			$url.= $port; 
		}
			
		$url.=get_base_url(false);
		$url.="backend/";
		}

	// else client-side call, so use base url
	else{
		$url=get_current_url();
		}

	return $url;
	}
	

function get_backend_sortorder_arg($sortorder="desc",$sortby=""){

	// generate sort order argument for backend calls
	$orderby_arg="";
	if($sortorder=="desc")
		$sortorder_arg="d";
	else
		$sortorder_arg="a";
	$orderargs=explode(",",$sortby);
	$current_order=0;
	foreach($orderargs as $orderarg){
		$current_order++;
		if($current_order>1)
			$orderby_arg.=",";
		$orderby_arg.=$orderarg;
		$orderby_arg.=":".$sortorder_arg;
		}
		
	return $orderby_arg;
	}

////////////////////////////////////////////////////////////////////////
// BACKEND AUTHENTICATION FUNCTIONS
////////////////////////////////////////////////////////////////////////

// checks if user is authenticated
function is_backend_authenticated(){
	global $request;
	global $cfg;
	
	$uid=grab_request_var("uid","");
	$username=grab_request_var("username","");
	
	// get uid from username
	if($username!="")
		$uid=get_user_id($username);
		
	// proxy request from server-side frontend must contain a uid and ticket number or password MD5 hash
	if($uid!=""){
	
		//echo "UID=".$uid."\n";

		// see if user passed MD5 hash of password instead of ticket
		if(isset($request["password"])){
		
			//echo "CHECKING MD5 HASH...\n";
		
			// MD5 hash matches, so set session variable
			if($request["password"]==get_user_attr($uid,"password")){
				$_SESSION["user_id"]=$uid;
				$_SESSION["username"]=get_user_attr($uid,"username");
				return true;
				}
			}

		// check ticket
		else if(isset($request["ticket"])){

			//echo "CHECKING TICKET...\n";
		
			$backend_ticket=get_user_attr($uid,"backend_ticket");
		
			//echo "BACKEND TICKET=$backend_ticket\n";
		
			// correct ticket and uid was passed, so set session variable
			if($request["ticket"]==$backend_ticket){
				$_SESSION["user_id"]=$uid;
				$_SESSION["username"]=get_user_attr($uid,"username");
				return true;
				}
			}
			
		// subsystem ticket was passed
		else if(isset($request["subsystem"]) && $request["subsystem"]==get_subsystem_ticket()){
			$_SESSION["user_id"]=$uid;
			// tell db authentication limiters to ignore some restrictions...
			define("SUBSYSTEM_CALL",true);
			//echo "SUBSYSTEM CALL, UID=".$request["uid"]."\n";
			}
			
		// bad or no ticket
		else{
			return false;
			}
		}
		
	// session variable is set, so this must be a direct or ajax-based call
	if(isset($_SESSION["user_id"]))
		return true;
		
	//echo "DIDN'T CHECK ANYTHING...\n";

	return false;
	}
	
?>