<?php
//
// Copyright (c) 2008-2011 Nagios Enterprises, LLC.  All rights reserved.
//
// IMPORTANT: SOURCE CODE MAY NOT BE DISCLOSED OR DISTRIBUTED IN UNENCODED FORM
//            WITHOUT EXPLICIT PERMISSION FROM NAGIOS ENTERPRISES, AS IT CONTAINS
//			  CODE LICENSED FROM THIRD PARTIES.
//
// Development Started 03/22/2008
// $Id: utilsl.inc.php 650 2011-05-24 15:44:16Z mguthrie $

require_once(dirname(__FILE__).'/constants.inc.php');
require_once(dirname(__FILE__).'/utils.inc.php');


////////////////////////////////////////////////////////////////////////
// BUILD ID FUNCTIONS
////////////////////////////////////////////////////////////////////////

function get_build_id() {
	return "20110524";
	}


////////////////////////////////////////////////////////////////////////
// PRODUCT FUNCTIONS
////////////////////////////////////////////////////////////////////////

function get_product_name($short=false){
	$txt="";
	if($short==true)
		$txt="nagiosxi";
	else
		$txt="Nagios XI";
	return $txt;
	}

function get_product_version($type=""){
	
	$major="2011";
	$minor="R1.3";
	
	switch($type){
		case "major":
			return $major;
			break;
		case "minor":
			return $minor;
			break;
		default:
			return $major.$minor;
			break;
		}

	return $major.$minor;
	}

function get_product_release(){
	return 203;
	}

function get_product_build(){

	return get_build_id();
	}
	
function use_new_features(){
	global $cfg;
	
	$use_new=grab_array_var($cfg,"use_2011_features",1);
	
	if($use_new==1)
		return true;
	
	return false;
	}
	

////////////////////////////////////////////////////////////////////////
// SESSION PROTECTION
////////////////////////////////////////////////////////////////////////

function get_nagios_session_protector_id(){

	$nsp=md5(session_id());
	
	return $nsp;
	}
	
function get_nagios_session_protector(){
	$html="<input type='hidden' name='nsp' value='".get_nagios_session_protector_id()."'>";
	//$html.="<input type='hidden' name='sess' value='".session_id()."'>";
	return $html;
	}
	
function check_nagios_session_protector(){

	// the id we should have
	$nsp=get_nagios_session_protector_id();
	
	// get id passed from user - must be sent as a POST variable
	$user_nsp=0;
	//$user_nsp=grab_request_var("nsp",0);
	$user_nsp=grab_request_var("nsp");
	//if(isset($_POST['nsp']))
		//$user_nsp=$_POST['nsp'];
	
	// ids didn't match, so bail out
	if(strval($user_nsp)!=strval($nsp)){
		echo "NSP: Sorry Dave, I can't let you do that";
		//echo "<BR>NSP=$nsp, USER=$user_nsp<BR>";
		exit();
		}
		
	//echo "NSP: OK TO GO!  NSP=$nsp, USER=$user_nsp<BR>";
	//exit();
	}



////////////////////////////////////////////////////////////////////////
// MISC PRODUCT FUNCTIONS
////////////////////////////////////////////////////////////////////////

function get_product_portal_backend_url(){
	$url="http://www.nagios.com/backend/portal/?product=".get_product_name(true)."&version=".get_product_version();
	return $url;
	}

	
////////////////////////////////////////////////////////////////////////
// PAGE INIT FUNCTIONS
////////////////////////////////////////////////////////////////////////

// page pre-initialization
function pre_init(){
	global $page_start_time;
	
	// initialize page timer
	$page_start_time=get_timer();
	
	// initialize menus
	init_menus();
	}


// check prerequisites
function check_prereqs($iu_error=true){
	
	// make database connections
	$dbok=db_connect_all();
	if($dbok==false)
		exit();
		
	// read language files
	$langok=init_language();
	
	// handle language problem
	//if($langok==false)
	//	handle_missing_language_file($_SESSION["language"]);
	
	// load user meta session variables
	get_user_meta_session_vars();
	
	// user must change password	
	$page=$_SERVER['PHP_SELF'];
	if(isset($_SESSION["forcepasswordchange"]) && !strstr($page,PAGEFILE_LOGIN)){
		if($iu_error==true)
			header("Location: ".get_base_url().PAGEFILE_LOGIN."?forcepasswordchange");
		}
		
	// user must agree to license
	if(isset($_SESSION["agreelicense"]) && !strstr($page,PAGEFILE_LOGIN)){
		if($iu_error==true)
			header("Location: ".get_base_url().PAGEFILE_LOGIN."?showlicense");
		}

	// handle installs
	if(install_needed()==true && !strstr($page,PAGEFILE_INSTALL)){
		if($iu_error==true){
			//echo "PAGE: $page";
			//exit();
			header("Location: ".get_base_url().PAGEFILE_INSTALL);
			}
		}

	// do callbacks
	$args=array();
	do_callbacks(CALLBACK_PREREQS_PASSED,$args);
	}




////////////////////////////////////////////////////////////////////////
// DATE/NUMBER FORMAT FUNCTIONS
////////////////////////////////////////////////////////////////////////

function get_formatted_number($num=0,$dec=-1,$format=NF_AUTO){

//	$str="($num) ";
	$str="";
	
	// auto-determine decimal places
	if($dec<0){
		if(is_string($num)){
			$parts=explode(".",$num);
			$full=intval($parts[0]);
			$part=intval($parts[1]);
			$half=$part/pow(10,strlen($part));
			$num=($full + $half);
			$dec=strlen($part);
			}
		else if(is_numeric($num))
			$dec=0;
		else if(is_float($num))
			$dec=4;
		else
			$dec=0;
		}
	if($format==NF_AUTO){
		if(isset($_SESSION['number_format']))
			$format=$_SESSION['number_format'];
		else{
			if(is_null($format=get_user_meta(0,'number_format')))
				$format=get_option('default_number_format');
			}
		}
	$format=intval($format);
	
//	$str.="{";
					//added floatval() to $num variables to ensure proper format for php5.3.3+ - MG 1/10/11 
	switch($format){
		case NF_1:	// English (no commas)
			$str.=number_format(floatval($num),$dec,'.','');
			break;
		case NF_3:	// German
			$str.=number_format(floatval($num),$dec,',','.');
			break;
		case NF_4:	// French
			$str.=number_format(floatval($num),$dec,',',' ');
			break;
		case NF_5:	// Swiss
			$str.=number_format(floatval($num),$dec,',','\'');
			break;
		// default to English (w/ commas)
		default:
			$str.=number_format(floatval($num),$dec);
			break;
		}
	
//	$str.="}";
	return $str;
	}
	
	
function get_number_formats(){
	global $lstr;

	$formats=array();

	$formats[NF_1]=$lstr['NumberFormat1Text'];
	$formats[NF_2]=$lstr['NumberFormat2Text'];
	$formats[NF_3]=$lstr['NumberFormat3Text'];
	$formats[NF_4]=$lstr['NumberFormat4Text'];
	$formats[NF_5]=$lstr['NumberFormat5Text'];

	return $formats;
	}

	
// used by the reports - turns a (potential) unix timestamp into a date/time string
function get_datetime_from_timestring($t){

	// see if we can parse the date time
	$timestr=strtotime($t);
	
	// if we can't, its a unix timestamp, so convert it
	if($timestr===false)
		return get_datetime_string($t);
		
	// otherwise return the original date/time string
	return $t;
	}
	
function get_datetime_string_from_datetime($str,$timezone="",$type=DT_SHORT_DATE_TIME,$format=DF_AUTO,$zerostring=""){

	if(have_value($timezone)==true)
		date_default_timezone_set($timezone);
	$ts=strtotime($str);
	//return $ts;
	//return "TZ: ".date_default_timezone_get()."TS: $ts";
	return get_datetime_string($ts,$type,$format,$zerostring);
	}
	

function get_datetime_string($ts=0,$type=DT_SHORT_DATE_TIME,$format=DF_AUTO,$zerostring=""){

	$str="";
	$strfmt="%Y-%m-%d %T";
	if($format==DF_AUTO){
		if(isset($_SESSION['date_format']))
			$format=$_SESSION['date_format'];
		else{
			if(is_null($format=get_user_meta(0,'date_format')))
				$format=get_option('default_date_format');
			}
		}
	$format=intval($format);
	
	switch($type){
		case DT_LONG_DATE_TIME:
			// currently unsupported
			break;
		case DT_SHORT_DATE:
			switch($format){
				case DF_US:
					$strfmt="%m/%d/%Y";
					break;
				case DF_EURO:
					$strfmt="%d/%m/%Y";
					break;
				default:
					$strfmt="%Y-%m-%d";
					break;
				}
			break;
		case DT_SQL_DATE:
			$strfmt="%Y-%m-%d";
			break;
		case DT_SHORT_TIME:
		case DT_SQL_TIME:
			$strfmt="%T";
			break;
		case DT_SQL_DATE_TIME:
			$strfmt="%Y-%m-%d %T";
			break;
		case DT_UNIX:
			$strfmt="%s";
			break;
		case DT_HTTP_DATE_TIME:
			// currently unsupported
			break;
		// default to short date/time
		default:
			switch($format){
				case DF_US:
					$strfmt="%m/%d/%Y %T";
					break;
				case DF_EURO:
					$strfmt="%d/%m/%Y %T";
					break;
				default:
					$strfmt="%Y-%m-%d %T";
					break;
				}
			break;
		}

	if($ts==0)
		$str=$zerostring;
	else
		$str=strftime($strfmt,$ts);
	//$str="TS: $ts, STRFMT: '$strfmt'";
	return $str;
	}


function get_date_formats(){
	global $lstr;

	$formats=array();

	$formats[DF_ISO8601]=$lstr['DateFormatISO8601Text'];
	$formats[DF_US]=$lstr['DateFormatUSText'];
	$formats[DF_EURO]=$lstr['DateFormatEuroText'];

	return $formats;
	}
	
	
function get_duration_string($s,$nullval=null,$zeroval=null){

	$str="";
	$instr=false;
	
	if(is_null($s) || $s==""){
		if($nullval==null)
			$str="0s";
		else
			$str=$nullval;
		}
	else{
		$si=intval($s);
		if($si==0){
			if($zeroval==null)
				$str="0s";
			else
				$str=$zeroval;
			}
		else{
			$days=intval($si/86400);
			$si-=$days*86400;
			$hours=intval($si/3600);
			$si-=$hours*3600;
			$minutes=intval($si/60);
			$si-=$minutes*60;
			$seconds=$si;
		
			if($days>0){
				$str.=$days."d";
				$instr=true;
				}
			if($hours>0 || $instr==true){
				if($instr==true)
					$str.=" ";
				$str.=$hours."h";
				$instr=true;
				}
			if($minutes>0 || $instr==true){
				if($instr==true)
					$str.=" ";
				$str.=$minutes."m ";
				$instr=true;
				}

			if($instr==true)
				$str.=" ";
			$str.=$seconds."s";
			}
		}

	return $str;
	}

	
////////////////////////////////////////////////////////////////////////
// ACTIVATION FUNCTIONS
////////////////////////////////////////////////////////////////////////
	
function is_valid_license_activation_key($key,$justinstalled=false){

	//echo "TESTING ACT KEY: $key<BR>";

	$myip=trim($_SERVER['SERVER_ADDR']);
	$license_key=trim(get_license_key());
	
	$md5_ip=md5($myip);
	$md5_lk=md5($license_key);

	/*
	echo "MYIP: '$myip'<BR>";
	echo "LICENSE KEY: '$license_key'<BR>";
	echo "MD5IP: $md5_ip<BR>";
	echo "MD5LK: $md5_lk<BR>";
	*/

	$mkey1="A6";
	$mkey2=strtoupper(substr($md5_ip,0,5));
	$mkey3="299";
	$mkey4=strtoupper(substr($md5_lk,0,6));

	// key matches exactly...
	$matchkey=$mkey1.$mkey2.$mkey3.$mkey4;
	//echo "MATCHKEY: $matchkey<BR>";
	if($matchkey==$key){
		//echo "EXACT MATCH!<BR><BR>";
		return true;
		}
		
	// server ip might change in the future, so only require a partial match (everything but ip portion)
	if($justinstalled===false){
		$tkey1=substr($key,0,2);
		$tkey2=""; // ignored
		$tkey3=substr($key,7,3);
		$tkey4=substr($key,10);
		
		//echo "TKEY1: $tkey1, TKEY3: $tkey3, TKEY4: $tkey4<BR>";
		
		if($tkey1==$mkey1 && $tkey3==$mkey3 && $tkey4==$mkey4){
			//echo "PARTIAL MATCH!<BR><BR>";
			return true;
			}
		}
	
	//echo "MATCH FAILURE.<BR><BR>";

	return false;
	}
	
function is_license_activated(){

	//return true;

	// free licenses don't require activation
	if(is_free_license()==true)
		return true;

	// trial licenses don't require activation
	if(is_trial_license()==true)
		return true;

	// make sure key is valid
	//set_option("activation_key","A6E8561299C9BB0E");
	//set_option("activation_key","");
	$key=get_option("activation_key");
	if(is_valid_license_activation_key($key)==false)
		return false;
		
	return true;
	}
	
	
////////////////////////////////////////////////////////////////////////
// LICENSE CHECK FUNCTIONS
////////////////////////////////////////////////////////////////////////

register_callback(CALLBACK_CONTENT_START,'license_check_content_header');



////////////////////////////////////////////////////////////////////////
// LICENSE FUNCTIONS
////////////////////////////////////////////////////////////////////////

function get_license_key(){
	$key=get_option("license_key");
	if($key==null){
		$key="";
		set_option("license_key",$key);
		}		
	return $key;
	}

function is_trial_license(){
	$key=get_option("license_key");
	// no key - limitied time trial
	if($key==null || $key=="")
		return true;
	return false;
	}
	
function is_free_license(){
	$key=get_option("license_key");
	if($key=="FREE")
		return true;
	return false;
	}
	
function is_trial_expired(){
	$daysleft=get_trial_days_left();
	if($daysleft>0)
		return false;
	return true;
	}
	
function get_trial_days_left(){

	$trial_days=60;

	$daysleft=0;
	$start=get_trial_start();
	$now=time();
	$diff=$now-$start;
	$daysleft=number_format(ceil($trial_days-($diff/(24*60*60))),0);
	//echo "START: $start, NOW: $now, DIFF: $diff, DAYSLEFT: $daysleft<BR>";
	if($daysleft<0)
		$daysleft=0;
	//$daysleft=0;
	return $daysleft;
	}

	
function get_trial_start(){

	// product is being re-installed, so clear install time
	if(file_exists("/tmp/nagiosxi.forceinstall")){
		// only clear if it they have 7 hosts or fewer
		$ah=get_active_host_license_count();
		if($ah<=7)
			set_option("subsystem_homi","");
		}
			
	$tsraw=get_option("subsystem_homi");
	if($tsraw==null || $tsraw==""){
	
		// set now as trial start time
		$trial_start=time();
		$tsraw=base64_encode($trial_start);
		set_option("subsystem_homi",$tsraw);
		}
	else{
		$trial_start=base64_decode($tsraw);
		}
		
	// fix for trial start errors (introduced in 20091.3)
	$sd=strtotime("2010-08-17");
	$ed=strtotime("2010-08-19");
	if($trial_start > $sd && $trial_start < $ed){
		//echo "START: $sd<BR>";
		//echo "END: $ed<BR>";
		//echo "RESETTING TRIAL DATE!<BR>";
		
		// set now as trial start time
		$trial_start=time();
		$tsraw=base64_encode($trial_start);
		set_option("subsystem_homi",$tsraw);
		}
	//echo "TRIAL START=$trial_start<br>";

	return $trial_start;
	}
	
	
// resets trial days
function reset_homi($days=30){
	$daysraw=grab_request_var("days",$days);
	$days=intval($daysraw);
	if($days>60)
		$days=60;
	$trial_start=time();
	echo "NOW: $trial_start<BR>";
	$trial_start=strtotime("now -".$days." day");
	echo "END: $trial_start<BR>";
	$tsraw=base64_encode($trial_start);	
	set_option("subsystem_homi",$tsraw);
	echo "DAYS: $days<BR>";
	exit();
	}

	
function is_valid_license_key($key){
	$result=decode_license_key($key);
	if($result["valid_key"]==true)
		return true;
	sleep(3);
	return false;
	}
	
function get_active_host_license_count(){
	global $db_tables;
	
	// get host count
	$current_hosts=0;
	
	$sql="SELECT COUNT(*) as active_hosts FROM ".$db_tables[DB_NDOUTILS]['hosts']."
 LEFT JOIN ".$db_tables[DB_NDOUTILS]['objects']." ON ".$db_tables[DB_NDOUTILS]['hosts'].".host_object_id=".$db_tables[DB_NDOUTILS]['objects'].".object_id
 WHERE ".$db_tables[DB_NDOUTILS]['objects'].".is_active='1'";
 	if(($rs=exec_sql_query(DB_NDOUTILS,$sql,false))){
		if($rs->MoveFirst()){
			$current_hosts=intval($rs->fields["active_hosts"]);
			}
		}

	return $current_hosts;
	}
	
	
function get_free_licensed_host_count(){
	$free_hosts=7;
	return $free_hosts;
	}

	
function is_license_exceeded(){

	// check trial license expiration
	if(is_trial_license()==true){
		//echo "TRIAL";
		if(is_trial_expired()==true)
			return true;
		else
			return false;
		}
	// check free license limits
	else if(is_free_license()==true){

		// get host count
		$current_hosts=get_active_host_license_count();
		
		$max_hosts=get_free_licensed_host_count();
		
		if($current_hosts>$max_hosts)
			return true;
		}
	else{
		//echo "NON-TRIAL";
		$key=get_license_key();
		$result=decode_license_key($key);

		// license key is invalid
		if($result["valid_key"]==false)
			return true;
			
		$max_hosts=$result["max_hosts"];
		
		// unlimited hosts
		if($max_hosts==0)
			return false;
			
		// get host count
		$current_hosts=get_active_host_license_count();
			
		//echo "CURRENT: $current_hosts, MAX: $max_hosts";
		
		if($current_hosts>$max_hosts)
			return true;
		}
		
	return false;
	}

function licensed_feature_check($showpage=true,$trialonly=false){
	global $lstr;
	
	if(is_license_exceeded()==true){
	
		// this feature should only be prevented if its an expired trial or free version(licensed customers just get bugged)
		if($trialonly==true && (is_free_license()==false && is_trial_license()==false)){
			//echo "BYPASS";
			return true;
			}
			
		if($showpage==true){
			do_page_start(array("page_title"=>$lstr['LicenseExceededPageTitle']),true);
?>
			<h1><?php echo $lstr['LicenseExceededPageHeader'];?></h1>		
		
<?php		
			$keyurl=get_base_url()."admin/license.php";
			echo "You have exceeded your <a href='".$keyurl."'>license limits</a>.  <a href='http://www.nagios.com/products/nagiosxi/pricing/' target='_blank'>Upgrade your license</a> to access this feature and obtain support services.";
			
			do_page_end(true);
			}
			
		// stop!
		exit();
		}
		
	return true;
	}
	
	
function license_check_content_header($cbtype,$args=null){

	$restrict_activation=false;
	$output="";

	if($args["child"]==false)
		return;

	$keyurl=get_base_url()."admin/license.php";
	
	// imitied time trial
	if(is_trial_license()==true){
		$daysleft=get_trial_days_left();
		if($daysleft>=1){
			if(!isset($_SESSION["ignore_trial_notice"]))
				//$output="<div class='contentheadernotice'><div style='float: right;'><a href='#' id='closetrialnotice'>[X]</a></div>You have ".$daysleft." days left in your trial.  <a href='http://www.nagios.com/products/nagiosxi/' target='_blank'>Purchase a License</a> or <a href='".$keyurl."'>Enter your license key</a>.</div>";
				$output="<div class='contentheadernotice'><div style='float: right;'><a href='#' id='closetrialnotice'>[X]</a></div>Notice: This trial copy of Nagios XI will expire in ".$daysleft." days.  <a href='http://www.nagios.com/products/nagiosxi/pricing/' target='_blank'>Purchase a License Now</a> or <a href='".$keyurl."'>Enter your license key</a>.</div>";
			}
		else{
			//$output="<div class='contentheadernotice'>Your trial has expired.  Don't let your IT infrastructure go unmonitored - <a href='http://www.nagios.com/products/nagiosxi/' target='_blank'>Purchase a License Now</a> or <a href='".$keyurl."'>Enter your license key</a>.</div>";
			$output="<div class='contentheadernotice'>This trial copy of Nagios XI has expired.  <a href='http://www.nagios.com/products/nagiosxi/pricing/' target='_blank'>Purchase a License Now</a> or <a href='".$keyurl."'>Enter your license key</a>.</div>";
			}
		echo $output;
		}
	else{
		//$key=get_license_key();
		
		// make sure the license key is valid
		/*
		if(is_valid_license_key($key)==false){
			$output="<div class='contentheadernotice'>Your license key is invalid.   <a href='".$keyurl."'>Enter a new license key</a> or <a href='http://www.nagios.com/products/nagiosxi/' target='_blank'>Buy a license</a>.</div>";
			echo $output;
			}
		*/
		
		// see if the license is exceeded
		if(is_license_exceeded()==true){
			$output="<div class='contentheadernotice'>You have exceeded your license limits. <a href='http://www.nagios.com/products/nagiosxi/pricing/' target='_blank'>Upgrade Your License</a> or <a href='".$keyurl."'>Enter your new license key</a>.</div>";
			echo $output;
			}
			
		// free version notices
		else if(is_free_license()==true){
			if(!isset($_SESSION["ignore_free_notice"])){
				$output="<div class='contentheadernotice'><div style='float: right;'><a href='#' id='closefreenotice'>[X]</a></div><a href='http://www.nagios.com/products/nagiosxi/pricing/' target='_blank'>Upgrade to a  licensed version</a> of Nagios XI and get support and upgrade benefits.</div>";
				echo $output;
				}
			}
			
		// activation
		if(is_license_activated()==false){
			$restrict_activation=true;
			$activateurl=get_base_url()."admin/activate.php";
			$output="<div class='contentheadernotice'>Your license has not yet been activated.  Access to certain features of Nagios XI are restricted or limited.  <a href='".$activateurl."'>Activate your license now</a>.</div>";
			echo $output;
			}
		}
		
	// activation restricted pages....
	if($restrict_activation==true){
	
		$page=$_SERVER['PHP_SELF'];
		$page_dir=substr($page,0,strrpos($page,"/"));
		
		//echo "PAGE: $page<BR>";
		//echo "PAGEDIR: $page_dir<BR>";
		
		$page_match=false;
		
		// restrict by page dir
		switch($page_dir){
			// new reports
			case "/nagiosxi/reports":
				$page_match=true;
				break;
			// new components
			case "/nagiosxi/includes/components/hypermap":
			case "/nagiosxi/includes/components/hypermap_replay":
			case "/nagiosxi/includes/components/autodiscovery":
			case "/nagiosxi/includes/components/alertcloud":
			case "/nagiosxi/includes/components/alertstream":
			case "/nagiosxi/includes/components/similetimeline":
				$page_match=true;
				break;
			default:
				break;
			}
			
		// restrict by page
		switch($page){
			default:
				break;
			};
			
		if($page_match==true){
			echo "This feature is not available until you <a href='".$activateurl."'>activate your license</a>.";
			exit();
			}
		}
	}


////////////////////////////////////////////////////////////////////////
// LICENSE KEY FUNCTIONS
////////////////////////////////////////////////////////////////////////
	
// CONSTANTS
define("RESTRICT_NONE",0);
define("RESTRICT_USERS",1);
define("RESTRICT_HOSTS",2);
define("RESTRICT_SERVICES",4);
define("RESTRICT_TIME",8);


function get_license_info($key=""){

	// get host count
	$current_hosts=get_active_host_license_count();

	$output="";

	if(is_trial_license()==true){
	
		$trial_status="";
		if(is_trial_expired()==true)
			$trial_status="(Expired)";
		$output.="<tr><td>License Type:</td><td>Trial  ".$trial_status." - <a href='http://www.nagios.com/products/nagiosxi/pricing/' target='_blank'>Purchase a license</a> and receive support and upgrade benefits!</td></tr>\n";
		$output.="<tr><td>Number of Licensed Hosts:</td><td>Unlimited</td></tr>\n";
		$output.="<tr><td>Current Hosts:</td><td>".$current_hosts."</td></tr>\n";
		}
		
	else if(is_free_license()==true){
	
		$max_hosts=get_free_licensed_host_count();
		
		$output.="<tr><td>License Type:</td><td>Free - <a href='http://www.nagios.com/products/nagiosxi/pricing/' target='_blank'>Purchase a license</a> and receive support and upgrade benefits!</td></tr>\n";
		$output.="<tr><td>Number of Licensed Hosts:</td><td>".$max_hosts."</td></tr>\n";
		$output.="<tr><td>Current Hosts:</td><td>".$current_hosts."</td></tr>\n";
		$output.="<tr><td>License Usage:</td><td>".get_formatted_number((($current_hosts/$max_hosts)*100),0)."%</td></tr>\n";
		}
		
	else{
		$decoded_key=decode_license_key($key);
		if($decoded_key["valid_key"]==true){
			$output.="<tr><td>License Type:</td><td>Host-Based</td></tr>\n";
			$max_hosts=$decoded_key["max_hosts"];
			if($max_hosts==0)
				$licensed_hosts="Unlimited";
			else
				$licensed_hosts=$max_hosts;
			$output.="<tr><td>Number of Licensed Hosts:</td><td>".$licensed_hosts."</td></tr>\n";
			$output.="<tr><td>Current Hosts:</td><td>".$current_hosts."</td></tr>\n";
			if($max_hosts!=0)
				$output.="<tr><td>License Usage:</td><td>".get_formatted_number((($current_hosts/$max_hosts)*100),0)."%    <a href='http://www.nagios.com/products/nagiosxi/pricing/' target='_blank'>Upgrade your License</a></td></tr>\n";
			}
		else{
			$output.="<tr><td>License Type:</td><td>Invalid License Key  <a href='http://www.nagios.com/products/nagiosxi/pricing/' target='_blank'>Purchase a License</a></td></tr>\n";
			$output.="<tr><td>Current Hosts:</td><td>".$current_hosts."</td></tr>\n";
			}
		}
	return $output;
	}
	

function decode_license_key($key){

	$decoded_key=array();

	// covert string to digits
	$decoded=decode_license_chars($key);
	//echo "DECODED: $decoded\n";
	
	$key_version=intval(substr($decoded,0,1));
	//echo "KEY_VERSION: $key_version\n";
	
	$key_restriction_type=intval(substr($decoded,1,1));
	//echo "KEY_RESTRICTION_TYPE: $key_restriction_type\n";
	
	$rlen=intval(substr($decoded,2,1));
	//echo "RLEN: $rlen\n";
	
	$rstr="";
	for($x=0;$x<$rlen;$x++){
		$rstr.=substr($decoded,3+($x*2),1);
		}
	//echo "RSTR: $rstr\n";
	
	$restriction_number=intval($rstr);
	//echo "RESTRICTION_NUMBER: $restriction_number\n";

	
	$mi=$restriction_number >> 24;
	//echo "DINSTANCES: $mi\n";
	$restriction_number-=($mi << 24);
	$mu=$restriction_number >> 16;
	//echo "DUSERS: $mu\n";
	$restriction_number-=($mu << 16);
	$ms=$restriction_number >> 8;
	$ms=$ms*5;
	//echo "DSERVICES: ".$ms."\n";
	$restriction_number-=($ms << 8);
	$mh=$restriction_number;
	$mh=$mh*5;
	//echo "DHOSTS: ".$mh."\n";
	
	// check key validity
	$key_valid=false;
	if(strlen($key)==27){
		$echk=substr($decoded,23,1);
		$ichk=$echk;
		$key2=substr($key,0,26);
		$cchk=get_license_checksum($key2);
		//echo "CHK: KEY2=$key2, E=$echk, INLINE=$ichk, COMPUTED=$cchk\n";
		$key_valid=false;
		if($ichk==$cchk)
			$key_valid=true;	
		}
				
	$decoded_key["key_version"]=$key_version;
	$decoded_key["key_restriction_type"]=$key_restriction_type;
	$decoded_key["valid_key"]=$key_valid;
	$decoded_key["max_instances"]=$mi;
	$decoded_key["max_users"]=$mu;
	$decoded_key["max_services"]=$ms;
	$decoded_key["max_hosts"]=$mh;
	
	//print_r($decoded_key);
	
	return $decoded_key;
	}
	
	
function get_license_checksum($key){
	$len=strlen($key);
	$checksum=0;
	$total=0;
	for($x=0;$x<$len;$x++){
		$total+=ord(substr($key,$x,1));
		}
	//echo "TOTAL: $total\n";
	$checksum=$total%10;
	return $checksum;
	} 


function convert_license_char_to_digit($ch){
	$chnum=ord($ch)-ord('M');
	$num=$chnum;
	return $num;
	}


function decode_license_chars($str){
	$buf="";
	$len=strlen($str);
	for($x=0;$x<$len;$x++){
		$ch=substr($str,$x,1);
		if($ch=='-')
			continue;
		$buf.=strval(convert_license_char_to_digit($ch));
		}
	return $buf;
	}

	
////////////////////////////////////////////////////////////////////////
// CALLBACK FUNCTIONS
////////////////////////////////////////////////////////////////////////

//function do_callbacks($cbtype,$args=null){
function do_callbacks($cbtype,&$args){
	global $callbacks;
	
	$total_callbacks=0;
	
	if(array_key_exists($cbtype,$callbacks)){
		foreach($callbacks[$cbtype] as $cb){
			$cb($cbtype,$args);
			$total_callbacks++;
			}
		}
		
	return $total_callbacks;
	}
	
	
function count_callbacks($cbtype){
	global $callbacks;
	
	$total_callbacks=0;
	
	if(array_key_exists($cbtype,$callbacks)){
		$total_callbacks=count($callbacks[$cbtype]);
		}
		
	return $total_callbacks;
	}	
	
	
function register_callback($cbtype,$func){
	global $callbacks;
	
	$callbacks[$cbtype][]=$func;
	}



////////////////////////////////////////////////////////////////////////
// LICENSE FUNCTIONS
////////////////////////////////////////////////////////////////////////

$current_license_version=1;

function user_has_agreed_to_license($userid=0){
	global $current_license_version;
	$ulo=get_user_meta($userid,"license_version");
	if($ulo==$current_license_version)
		return true;
	return false;
	}
	
function set_user_has_agreed_to_license($userid=0){
	global $current_license_version;
	set_user_meta($userid,"license_version",$current_license_version,false);
	}
	
function get_raw_license_text(){
	global $license_text;
	
	$text=$license_text;
	return $text;
	}
	
function get_formatted_license_text(){
	
	$text=get_raw_license_text();
	$text=str_replace("\n","<p>",$text);
	
	return $text;
	}

$license_text="
Nagios Software License Terms and Conditions


PLEASE READ THIS AGREEMENT CAREFULLY BEFORE PURCHASING OR USING NAGIOS SOFTWARE.  BY PURCHASING OR USING NAGIOS ENTERPRISES' SOFTWARE, YOU SIGNIFY YOUR ASSENT TO THIS AGREEMENT.  IF YOU ARE ACTING ON BEHALF OF AN ENTITY, THEN YOU REPRESENT THAT YOU HAVE THE AUTHORITY TO ENTER INTO THIS AGREEMENT ON BEHALF OF THAT ENTITY.  IF YOU DO NO ACCEPT THE TERMS OF THIS AGREEMENT, THEN YOU MUST NOT PURCHASE OR USE NAGIOS SOFTWARE.

This Software License Terms and Conditions Agreement (\"Agreement\") is a legal agreement between Nagios Enterprises, LLC (\"Nagios Enterprises\") and the purchaser or user of Nagios Software (\"Customer\").  The effective date of this Agreement (\"Effective Date\") is the earlier of the date that Customer signs or accepts this Agreement or the date that Customer purchases or begins using Nagios Software.

 1 DEFINITIONS

For the purposes of this Agreement, the following terms shall have the following meanings:

1.1 Nagios Software.  All commercial and proprietary software programs, configurations, scripts, images, and intellectual property contained in Nagios Enterprises' commercial products and developed by, owned by, or licensed to Nagios Enterprises, with the exclusion of Third Party Software.

1.2 Third Party Software. Any software programs, configurations, scripts, images, and intellectual property contained in or distributed with Nagios Enterprises' products, with the exclusion of Nagios Software, made available in source code, object code form, or other format.  Licenses for each Third Party Software component is subject to a separate license that accompanies, is embedded in, or is referenced by such component.

1.3 Licensed System. Configurations and installations of Nagios Software on computer hardware, computer systems, operating systems, embedded devices, and virtual appliances for which Customer has paid all applicable License Fees, and has agreed to be bound to the terms of this Agreement.

1.4 Derivative Product.  Any product or service that results from the incorporation of, modification of, or integration with Nagios Software, whereby Nagios Software or the functionality of any part of Nagios Software becomes an integral part of the resulting product or service.

1.5 Permitted Use.  The use of Nagios Software on Licensed Systems by Customer for internal business purposes only, without use in a Derivative Product, as a hosted service, or in any product or service intended for resale.

1.6 Support Plan.  An annual, renewable phone or email support service subscription to which the Customer may optionally subscribe for Nagios Software by entering into a separate agreement with Nagios Enterprises.

1.7 Support Services.  Technical support services provided to Customer under the terms of a Support Plan.

1.8 Software Update.  Any enhancement to the current version of the Nagios Software that Nagios Enterprises generally releases or generally makes available to Nagios Enterprises' other customers. A Software Update is any new version of the Nagios Software denoted by a change in the version number (e.g. 2009R1 to 2009R2). Customer is responsible for acquiring, at their own cost, any updated or additional hardware, network resources, and software necessary to implement or use any Software Update.

1.9 License Fee. The then-current list price for the applicable Nagios Software purchased. All License Fees are due in advance of Permitted Use.



 2 LICENSE GRANT

Subject to the terms of this Agreement and full payment of License Fees as set forth in Section 4 of this Agreement, Nagios Enterprises hereby grants Customer a perpetual, non-exclusive, non-transferable, non-assignable, non-sublicensable right to use the Nagios Software for Permitted Use on the Licensed Systems.



 3 EXCEPTIONS TO LICENSE

 3.1 Unless expressly provided by mutual agreement of Nagios Enterprises and Customer in writing, Nagios Software does not include support which is necessitated as a result of the following causes:

 3.1.1 accident, neglect, misuse, abuse or default of or by the Customer, Customer's employees or agents, or any third party; or

 3.1.2 any fault in attachments or associated products, components, hardware, or software (whether or not supplied by Nagios Enterprises or its affiliates) which do not form part of the supported system covered by this Agreement and/or under a relevant Support Plan; or

 3.1.3 Customer's failure to abide by Section 5 of this Agreement; or

 3.1.4 Customer's failure to install the most recent Software Update made available to Customer, which Nagios Enterprises affirms to Customer resolves the failure reported by Customer; or

 3.1.5 any fault in the Nagios Software caused by the failure of any products or components not supplied by Nagios Enterprises or its affiliates; or

 3.1.6 any fault in Nagios Software which has been modified or damaged in any manner by any person of entity other than Nagios Enterprises; or

 3.1.7 an act of God, lightning, fire, flood, war, act of violence or any similar occurrence.

 3.2 Unless expressly provided by mutual agreement of Nagios Enterprises and Customer in writing and/or by the terms of a Support Plan, Support Services do not include:

 3.2.1 the support of non-Supported Software (\"Other Software\"), Third Party Software and non-Supported Systems (\"Other Systems\"), even though they may have been supplied by Nagios Enterprises or its affiliates; or

 3.2.2 customization or integration of new version or updates of the Nagios Software; or

 3.2.3 the support of any modified of customized version of the Nagios Software; or 

 3.2.4 the support of any attachments or associated products which do not form part of the Nagios Software and Licensed Systems.



 4 PAYMENT

4.1 Fees and Expenses. License Fees are stated in United States Dollars, must be paid in United States Dollars, and are exclusive of out-of-pocket expenses. Customer will reimburse Nagios Enterprises for reasonable expenses incurred in connection with the performance of additional services involving travel. Unless otherwise stated in this Agreement, any renewal of this Agreement will be at the same price per Licensed System paid during the initial term.  The parties agree that the terms of this Agreement will govern future purchases by Customer of additional units of any or all of the Licensed Systems listed herein. Unless otherwise agreed by the parties in writing, during the term of this Agreement, such additional units can be purchased and renewed at the rates set forth herein, exclusive of expenses, if any.

4.2 Invoices. If Customer is paying by credit card, Customer authorizes Nagios Enterprises to bill Customer's credit card for the License Fees for the Initial Term and for the amount due at the time of renewal. If Nagios Enterprises has approved Customer to be invoiced, Nagios Enterprises will invoice Customer for the Fees at the time of execution of this Agreement and upon the submission of any future purchase order. Any and all payments made by Customer pursuant to this Agreement are non-refundable. Customer will make payment within thirty (30) days of the date of the invoice; provided, however, that License Fees for Nagios Software are due prior to the delivery of such Nagios Software. Nagios Enterprises reserves the right to suspend or cancel performance of all or part of the Licensed Systems and/or change its credit terms if actual payment has not been received within sixty (60) days of the invoice date.

4.3 Taxes. All Support Fees are exclusive of any Taxes. Customer will pay to Nagios Enterprises an amount equal to any Taxes arising from or relating to this Agreement, including without limitation, sales, service, use or value added taxes, which are paid by or are payable by Nagios Enterprises. \"Taxes\" means any form of taxation, levy, duty, customs fee, charge, contribution or impost of whatever nature and by whatever authority imposed (including without limitation any fine, penalty, surcharge or interest), excluding, however, any taxes based solely on the net income of Nagios Enterprises. If Customer is required under any applicable law or regulation, domestic or foreign, to withhold or deduct any portion of the payments due to Nagios Enterprises, then the sum payable to Nagios Enterprises will be increased by the amount necessary so that Nagios Enterprises receives an amount equal to the sum it would have received had Customer made no withholdings or deductions.



 5 INTELLECTUAL PROPERTY

 5.1 Ownership. Notwithstanding anything to the contrary in this Agreement, and except for the limited license rights expressly provided herein, Customer acknowledges that Nagios Enterprises and is suppliers have and will retain all rights, title and interest in and to the Nagios Software, Derivative Products, and all copies, modifications, and derivative works of the Nagios Software, including, without limitation, all patent, copyright, trademark, trade secret, trade dress, and other intellectual property rights.  Customer acknowledges that it is obtaining only a limited license right to the Nagios Software and that no ownership rights are being conveyed to Customer under this Agreement or notice.  Customer agrees not to register or attempt to register, directly or indirectly and intellectual property rights of Nagios Enterprises or its suppliers.

 5.2 Build Exceptions.  Notwithstanding anything to the contrary in this Agreement, Nagios Enterprises grants Customer the right to build, develop, produce, sell, and distribute addons and extensions for Nagios Software (each a \"Nagios Addon\") that utilize, interface with, or make use of the Nagios Software APIs, so long as each Nagios Addon is designed to operate, and functionally operates, as an integral part of the Nagios Software.

 5.3 Confidentiality.  Neither the Customer nor its employes or agents shall cause or allow the Nagios Software or any information or data identified as Nagios confidential, trade secret, or proprietary information to be disclosed to third parties, duplicated, or used except as expressly permitted in this Agreement.  Customer shall take all reasonable steps, both during and after the term of this Agreement, to ensure that no authorized parties or persons will have access to Nagios Software and that no unauthorized copy, distribution or disclosure, whether in whole or in part, is made in any form.

 5.4 Reverse Engineering.  Portions of the Nagios Software may contain intellectual property which is licensed to or from Nagios Enterprises or its suppliers and may be protected by means of encryption, encoding, license management, obfuscation, or other means of intellectual property protection (collectively \"Rights Licensing Mechanisms\").  Customer acknowledges that it will not reverse engineering, attempt to reverse engineer, or disclose, in any manner, directly or indirectly, any portions of the Nagios Software protected by such Rights Licensing Mechanisms.

 5.5 Marks and Notices.  All copies of the Nagios Software, whether in altered or unaltered form, must include all trademarks, servicemarks, and copyright notices (collectively the \"Visible Marks\") - including size, location, color, and visibility characteristics of the Visible Marks - that appear in the unaltered, original copies of the Nagios Software.

 5.6 Trademarks.  No right, license, or permission to use any of Nagios Enterprises' trademarks, servicemarks, registered trademarks, or registered servicemarks (collectively the \"Trade Names\") is granted by this Agreement.  Customer acknowledges and agrees that it will not use any Trade Names in any manner not explicitly granted by Nagios Enterprises.

 5.7 Prior Incidents.  Customer agrees and acknowledges that in the event that it, or any of its employees or agents, violated, or allegedly violated, any terms of this Section 5 of the Agreement prior to the Effective Date (each violation or alleged violation a \"Pre-Term Incident\"), any and all Pre-Term Incidents will be considered to be subject to, and actionable under, the terms of this Section 5 of the Agreement.

 5.8 Remuneration.  Customers agrees that acknowledges that in the event that it, or any of its employees or agents, violates or allegedly violates any terms of this Section 5 of the Agreement (each violation or alleged violation an \"Actionable Breach\"), Customer shall be held directly accountable and responsible to Nagios Enterprises for all damages, financial, and otherwise, for said Actionable Breach. Customer acknowledges and agrees to pay all attorney, prosecution, arbitration, and other fees incurred or realized by Nagios Enterprises, whether actual or estimated, in Nagios Enterprises' course of action against Customer for Actionable Breaches.  Customer acknowledges that Nagios Enterprises, at its sole discretion, may choose to forgo or delay any action against Customer in relation to Customer's Actionable Breach.  Customer acknowledges that such delays or foregoings on Nagios Enterprises' part shall have no ill effect on Nagios Enterprises' rights, or on further remedies from Customer for violation or alleged violation of one or more terms of this Section 5.  This Section 5 of the Agreement shall survive the termination of this Agreement.



 6 CUSTOMER'S OBLIGATIONS

 6.1 During the continuance of this Agreement, the Customer shall:

 6.1.1 Facilities.

 6.1.1.a Provide Nagios Enterprises with full, safe and prompt access to the Nagios Software, Licensed Systems, and other Customer information, systems, and software (\"Customer Information\") as reasonably requested by Nagios Enterprises to enable Nagios Enterprises to carry out its obligations under this Agreement.  Customer understands and agrees that the completeness and accuracy of and extent of access to the Customer Information provided to Nagios Enterprises may affect Nagios Enterprises' ability to provide Support Services.  Customer will obtain any third party consents necessary to grant Nagios Enterprises access to Customer Information that is subject to proprietary right of, or controlled by, any third party.  Customer may, for legitimate security concerns, deny Nagios Enterprises certain access to Customer Information and the Licensed Systems, provided, however, that Nagios Enterprises shall be relieved from performing Support Services which reasonably require such access.

 6.1.1.b Make available to Nagios Enterprises, free of charge, all facilities and services reasonably required by Nagios Enterprises to enable Nagios Enterprises to provide the Support Services as defined under a separate agreement.

 6.1.1.c Provide such telecommunication facilities as are reasonably required.

 6.1.2 Use and Care.

 6.1.2.a Save for discrete additions generally recognized as being compatible with the Nagios Software and Licensed Systems, not make any modifications to the Nagios Software or Licensed Systems without Nagios Enterprises' prior consent.

 6.1.2.b Ensure that Nagios Software and Licensed Systems are used in a proper manner, in accordance with the Nagios Software user manuals and by competent trained employees only or by persons under their supervision.

 6.1.2.c Test all updates and modifications to the Nagios Software and Licensed Systems prior to implementing them in Customer's environment in accordance with best computing practices.  NAGIOS ENTERPRISES WILL NOT BE RESPONSIBLE FOR LOSS OF OR DAMAGE TO DATA OR LOSS OF USE OF ANY OF THE CUSTOMER'S COMPUTER  OR NETWORK SYSTEMS.

 6.1.3 Notification and Information.

 6.1.3.a Make available to Nagios Enterprises, free of charge, such information as may be necessary to enable Nagios Enterprises properly to conduct email and telephone diagnosis as part of the Support Service, and in addition, such programs, operating manuals and information to enable Nagios Enterprises properly to perform its obligations under this Agreement .

 6.1.3.b Use its best endeavors to provide staff familiar with the Customer's programs and operations, which staff shall co-operate fully with Nagios Enterprises personnel operating the Support Service (the \"Technicians\") in the diagnosis of any malfunction of the Supported Software or Supported Systems.

 6.1.3.c Keep full backups and copies of any of the Supported Software, Supported Systems, databases, configuration, and computer records in accordance with best computing practices before requesting Support Services from Nagios Enterprises.  Customer acknowledges they are responsible for re-loading their own application software, computer data, and records after any such Support Services have been provided.  It is the Customer's responsibility to backup data on the Supported Systems.  NAGIOS ENTERPRISES WILL NOT BE RESPONSIBLE FOR LOSS OF OR DAMAGE TO DATA OR LOSS OF USE OF ANY OF THE CUSTOMER'S COMPUTER  OR NETWORK SYSTEMS.

 6.2 To receive Support Service, the Customer is responsible for complying with the following:

 6.2.1 Conform to the Support Guidelines.  Conform to any and all guidelines specified in the Support Guidelines, which may be updated from time to time.  Customer is responsible for ensuring they are aware of and follow the latest Support Guidelines published on Nagios Enterprises' web site.

 6.2.2 Prepare for the Support Request.  The Customer can help the Support Team serve them better if the Customer has the following information when the Support Request is made: the Customer's customer number; and the current version of the Supported Software being used.

 6.2.3 Explain the problem to the Support Team.  The Customer should describe the problem the Customer is having with the Supported Software or Supported System.  Let the Support Team know what errors occurred and when they occurred; what was being done when the errors occurred; and what steps have already been taken to solve the problem.

 6.2.4 Cooperate with the Support Technician.  Pay careful attention to the Support Technician and follow the Support Technician's directions.

 6.2.5 If the Support Technician is unable to resolve the problem over the phone or via email, the Support Technician will recommend to the Customer the next course of action to be taken.

UNTIL THE CUSTOMER HAS COMPLIED WITH THE ABOVE PROCEDURES, NAGIOS ENTERPRISES CANNOT PROVIDE THE CUSTOMER WITH SERVICE.



 7 TERM AND TERMINATION

 7.1 Term.  The term of this Agreement and the provision of Support Services hereunder begins on the Effective Date and continues for the period of one (1) year.  Thereafter, the the term for the Support Services will renew for successive one (1) year terms, unless either party gives written notice to the other of its intention not to renew at least thirty (30) days before commencement of the next term. 

 7.2 Termination.  If Customer or Nagios Enterprises materially breaches the terms of this Agreement, and such breach is not cured or remedied within thirty (30) days after written notice of the breach is given to the breaching party, then the other party, by giving written notice of termination to the breaching party, may terminate this Agreement; provided, however, that no cure period will be required for a breach of Section 11 hereof. Nagios Enterprises reserves the right to terminate this Agreement at any time within thirty (30) days after written notice to Customer.  Without prejudice to any other right or remedy of Nagios Enterprises, in the event either party terminates this Agreement, Customer will pay Nagios Enterprises for all Nagios Software provided up to the effective date of termination. 

 7.3 Effect of Termination.  If this Agreement is terminated for any reason, Sections 4, 5, 7.3, 9, 10.2, 11, 12, 13.2, 14, 15, and 16 of this Agreement will survive such termination. 



 8 CONTINUING BUSINESS

Nothing in this Agreement will be understood to preclude or limit Nagios Enterprises from providing software, materials, or services for itself or other clients, irrespective of the possible similarity of such software, materials or services to those which might be delivered to Customer.



 9 LIMITION OF LIABILITY AND DISCLAIMER OF DAMAGES

 9.1 Limitation of Liability. FOR ALL EVENTS AND CIRCUMSTANCES, NAGIOS ENTERPRISES AND ITS AFFILIATES' AGGREGATE AND CUMULATIVE LIABILITY ARISING OUT OF OR RELATING TO THIS AGREEMENT, INCLUDING WITHOUT LIMITATION ON ACCOUNT OF PERFORMANCE OR NON-PERFORMANCE OF OBLIGATIONS, REGARDLESS OF THE FORM OF THE CAUSE OF ACTION, WHETHER IN CONTRACT, TORT (INCLUDING WITHOUT LIMITATION NEGLIGENCE), STATUTE OR OTHERWISE WILL BE LIMITED TO DIRECT DAMAGES AND WILL NOT TO EXCEED THE AMOUNT THAT CUSTOMER PAID TO NAGIOS ENTERPRISES UNDER THIS AGREEMENT DURING THE TWELVE (12) MONTHS IMMEDIATELY PRECEDING THE FIRST EVENT GIVING RISE TO LIABILITY.

 9.2 Disclaimer of Damages. NOTWITHSTANDING ANYTHING TO THE CONTRARY CONTAINED IN THIS AGREEMENT, IN NO EVENT WILL NAGIOS ENTERPRISES OR ITS AFFILIATES BE LIABLE TO CUSTOMER OR ITS AFFILIATES FOR: ANY CLAIM BASED UPON A THIRD PARTY CLAIM; ANY INCIDENTAL, CONSEQUENTIAL, SPECIAL, INDIRECT, EXEMPLARY OR PUNITIVE DAMAGES, WHETHER ARISING IN TORT, CONTRACT, OR OTHERWISE; OR FOR ANY DAMAGES ARISING OUT OF OR IN CONNECTION WITH ANY MALFUNCTIONS, DELAYS, LOSS OF DATA, LOST PROFITS, LOST SAVINGS, INTERRUPTION OF SERVICE, LOSS OF BUSINESS OR ANTICIPATORY PROFITS, EVEN IF NAGIOS ENTERPRISES OR ITS AFFILIATES HAVE BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.



 10 REPRESENTATIONS AND WARRANTIES

 10.1 General Representations and Warranties.  Nagios Enterprises represents and warrants that it has the authority to enter into this Agreement with Customer. 

 10.2 Disclaimer of Warranty.  EXCEPT AS EXPRESSLY PROVIDED IN THIS SECTION 10, THE NAGIOS SOFTWARE IS PROVIDED \"AS IS\" AND WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, INCLUDING THE IMPLIED WARRANTIES OF MERCHANTABILITY, NON-INFRINGEMENT, AND FITNESS FOR A PARTICULAR PURPOSE. THE WARRANTIES IN THIS SECTION 10 ARE THE SOLE AND EXCLUSIVE WARRANTIES (EXPRESS OR IMPLIED) WITH RESPECT TO THE SUBJECT MATTER OF THIS AGREEMENT. NO ORAL OR WRITTEN INFORMATION OR ADVICE GIVEN BY NAGIOS ENTERPRISES, ITS AFFILIATES, DEALERS, DISTRIBUTORS, AGENTS OR EMPLOYEES WILL CREATE A WARRANTY OR IN ANY WAY INCREASE THE SCOPE OF ANY WARRANTY PROVIDED HEREIN. NAGIOS ENTERPRISES DOES NOT GUARANTEE OR WARRANT THAT THE USE OF THE SERVICES OR SOFTWARE WILL BE UNINTERRUPTED OR ERROR FREE.



 11 LICENSE AND OWNERSHIP

 11.1 Marks. No right or license, express or implied, is granted hereunder for the use of any of Nagios Enterprises' trade names, service marks or trademarks.  Customer hereby grants Nagios Enterprises a non-exclusive, perpetual, royalty-free license to use Customer's name, Customer's logo artwork, and the name of any product or service that results from the Customers' use of Nagios Software covered by the Agreement in Nagios Enterprises' advertising, press, promotion, and similar public disclosures.  This provision will survive the termination and or completion of this Agreement subject to the confidentiality provisions set forth in Section 12.

 11.2 Freedom to Use Ideas. The ideas, methods, concepts, know-how, structures, techniques, inventions, developments, processes, discoveries, improvements and other information and materials developed in and during the course of this Agreement may be used by either party, without an obligation to account, in any way that party deems appropriate, including by or for itself or its clients or customers, notwithstanding the provisions set forth in Section 5 or anything to the contrary contained in this Agreement.



 12 CONFIDENTIALITY

Customer and Nagios Enterprises agree to maintain the confidentiality of Nagios Enterprises' pricing and product roadmap as well as other proprietary information received by the other party that is marked confidential, including non-public technical and business information for a period of two (2) years after the termination of this Agreement. This section shall not apply to any publicly available or independently developed information.



 13 REPORTING AND INSPECTION

 13.1 Reporting. Customer will promptly notify Nagios Enterprises if the number of Licensed Systems exceeds the number of Licensed Systems for which Customer has paid the applicable Licensing Fees. In its notice, Customer will include both the number of additional Licensed Systems and the date(s) on which such Licensed Systems were put into use. Nagios Enterprises will invoice Customer for the applicable Nagios Software for such Licensed Systems on a pro-rata basis and Customer will pay for such Nagios Software in accordance with this Agreement. 

 13.2 Inspection.  During the term of this Agreement and for one (1) year thereafter, Nagios Enterprises or its designated agent may inspect and review Customer's facilities and records in order to verify Customer's compliance with this Agreement. Any such inspection and review will take place only during Customer's normal business hours and upon no less than ten (10) days prior written notice from Nagios Enterprises. Nagios Enterprises will give Customer written notice of any non-compliance, including the number of underreported Licensed Systems, and Customer will have fifteen (15) days from the date of such notice to make payment to Nagios Enterprises for the applicable Nagios Software provided to the underreported Licensed Systems. If Customer had underreported the number of Licensed Systems by more than ten percent (10%), Customer will also pay Nagios Enterprises for the cost of such inspection.



 14 EXPORT RESTRICTIONS

Customer acknowledges that Nagios Enterprises may supply Customer with technical data, technology, and software (collectively \"Deliverables\") that are not only subject to the export control laws and regulations of the United States (\"U.S.\"), but may also be subject to the export control laws and regulations of the country in which the Support Services are purchased.  Customer agrees to abide by all applicable export control laws and regulations.  

Under such laws and regulations, the Nagios Software purchased may not be sold, leased or otherwise transferred to restricted end-users or to restricted countries. In addition, the Nagios Software may not be sold, leased or otherwise transferred to, or utilized by, an end-user engaged in activities related to weapons of mass destruction, including but not necessarily limited to, activities related to the design, development, production or use of nuclear materials, nuclear facilities, or nuclear weapons, missiles or support of missile projects, or chemical or biological weapons. The Customer understands that applicable requirements or restrictions may vary depending on the Nagios Software delivered and may change over time and that, to determine the precise controls applicable to the Nagios Software acquired, it may be necessary to refer to relevant laws and regulations.

Nagios Enterprises will not be responsible for compliance by Customer with applicable export obligations or requirements for such Deliverables.  Clients agrees to defend and indemnify Nagios Enterprises against any demands, notices, fines, penalties, sanctions, claims, liabilities and costs, including attorneys fees, which result from Customer's breach of any representation or warranty herein.  The indemnification provisions of this Section shall survive the expiration or termination of this Agreement.  In the event that Customer breaches this Section 14, Nagios Enterprises may terminate this Agreements and its obligations hereunder without liability to Customer.



 15 GOVERNING LAW

This Agreement is made in and shall be governed in all respects by the laws of the United States and of the State of Minnesota without regard to its conflict of laws provisions.  The parties agree that any controversy or claim arising out of or relating to this Agreement, or the breach thereof, shall be venued in the state or federal courts located in the State of Minnesota and the parties consent to the exclusive jurisdiction of said courts.  In the event the Uniform Computer Information Transactions Act (UCITA) or any similar federal or state laws or regulations are enacted, it will not apply to this Agreement, and the governing law will remain as if such law or regulation had not been enacted.



 16 MISCELLANEOUS

 16.1 Notices.  Notices must be in English, in writing, and will be deemed given when delivered by hand or five (5) days after being sent to the respective addresses indicated on the first page hereof or to the facsimile numbers set forth below, using a method that provides for positive confirmation of delivery; provided that any notice from Customer to Nagios Enterprises includes a copy sent to: Nagios Enterprises, P.O. Box 8154, Saint Paul, MN 55126; Facsimile: (651) 204-9103.

 16.2 Right To Refusal.  Nagios Enterprises reserves the right to refuse any Customer access to Nagios Software for any reason, including, but not limited to Customer's use of  Nagios Software in a manner prohibited by Section 14 of this Agreement. In the event that Nagios Enterprises refuses to provide Customer with Nagios Software, Nagios Enterprises agrees to refund Customer License Fees paid by Customer to Nagios Enterprises, less any fees incurred by Nagios Enterprises at the times the License Fees were collected from and/or refunded to Customer.

 16.3 Assignment.  This Agreement is binding on the parties to this Agreement, and nothing in this Agreement confers upon any other person or entity any right, benefit or remedy of any nature whatsoever, save for the parties' affiliates as expressly provided in this Agreement. This Agreement is assignable by either party only with the other party's prior written consent, which will not be unreasonably withheld. Notwithstanding the foregoing, Nagios Enterprises may assign this Agreement to its affiliate, subsidiary or pursuant to a merger or a sale of all or substantially all of such party's assets or stock upon written notice and without the prior approval of Customer.

 16.4 Force Majeur.  Except with respect to the payment of Fees owing under this Agreement, neither party will be liable for nonperformance or delays of its obligations under this Agreement caused by acts of God, wars, riots, strikes, fires, floods, earthquakes, government restrictions, terrorist acts or other causes beyond its reasonable control.  If such delay is caused by circumstances beyond the reasonable control of the party so delaying, the party shall be entitled to a reasonable extension of time for the performance of such obligations.

 16.5 Independent Contractor.  Nagios Enterprises is an independent contractor and nothing in this Agreement will be construed to create an employee relationship between Customer (or any Customer personnel) and Nagios Enterprises (or any Nagios Enterprises personnel).  Each party shall be solely responsible for the payment of all federal, state or local taxes payable with respect to all amounts paid to Nagios Enterprises under this Agreement.  Nothing contained in this Agreement shall be construed or applied to create a partnership.

 16.6 Non-solicitation.  Customer agrees not to solicit or hire any personnel of Nagios Enterprises with whom Customer has had contact in connection with this Agreement; provided that Customer may hire an individual employed by Nagios Enterprises who, without other solicitation, responds to advertisements or solicitations aimed at the general public.

 16.7 Dispute Resolution.  If Customer is not satisfied with the Nagios Software provided by Nagios Enterprises, Customer agrees to give Nagios Enterprises a written description of the problem(s) and to make a good faith effort to amicably resolve the problem with Nagios Enterprises before commencing any proceeding. Nagios Enterprises also agrees to make a good faith effort to amicably resolve any problem with Customer before commencing any proceeding. No claim or action, regardless of form, arising out of this Agreement may be brought by either party more than one (1) year after the cause of action has accrued.

 16.8 Headings.  All headings contained in this Agreement are inserted for identification and convenience, and will not be deemed part of this Agreement for purposes of interpretation.

 16.9 Severability.  If any provision of this Agreement is for any reason declared to be invalid or unenforceable, the validity and enforceability of the remaining provisions shall not be affected thereby. Such invalid or unenforceable provision shall be deemed modified to the extent necessary to render it valid and enforceable, and if no modification shall render it valid and enforceable, this Agreement shall be construed as if not containing such provision and the rights and obligations of the parties shall be construed and enforced accordingly; provided, however, that if Sections 4, 9, 11 and 14 cannot be modified to be valid and enforceable, this Agreement will be deemed invalid in it entirety.

 16.10 Waiver.  The delay or failure of either party to exercise any rights hereunder will not constitute or be deemed a waiver or forfeiture of such rights. No waiver will be valid unless in writing and signed by an authorized representative of the party against whom such waiver is sought to be enforced.

 16.11 Blue M&Ms.  Nagios Enterprises reserves the right to limit Customers' intake of blue M&Ms in an effort to preserve the sanctity of both chocolate candy and Nagios Enterprises' products that utilize the color blue.  M&Ms is a registered trademark of Mars Inc., and Nagios Enterprises places no claim of ownership over Mars' trademarks, nor any affiliation with or endorsement from Mars.  We just happen to like both M&Ms and the color blue.

 16.12 Complete Agreement.  This Agreement constitutes the exclusive terms and conditions with respect to the subject matter hereof, notwithstanding any different or additional terms that may be contained in the form of purchase order or other document used by Customer to place orders or otherwise effect transactions hereunder. This Agreement represents the final, complete and exclusive statement of the agreement between the parties with respect to subject matter hereof and all prior written agreements and all prior and contemporaneous oral agreements with respect to the subject matter hereof are merged therein. Any claim relating to the provision of the Nagios Software by Nagios Enterprises, its affiliates and their personnel will be made against Nagios Enterprises alone.

 16.13 Amendment.  This Agreement may not be amended, supplemented or modified except by a written instrument signed by the parties hereto, which instrument makes specific reference to this Agreement.

 16.14 Counterparts and Facsimile Signature.  This Agreement may be executed in counterparts, each of which will be deemed an original and all of which will constitute one and the same instrument. The parties may exchange signature pages by facsimile and such signatures will be effective to bind the parties.

 16.15 Waiver of Trial Jury.  TO THE FULLEST EXTENT PERMITTED BY APPLICABLE LAW, EACH PARTY WAIVES THE RIGHT TO TRIAL BY JURY IN ANY LEGAL PROCEEDING ARISING OUT OF OR RELATING TO THIS AGREEMENT OR THE TRANSACTIONS CONTEMPLATED UNDER THIS AGREEMENT.




";
	
?>